Module: Google::Apis::DatamanagerV1
- Defined in:
- lib/google/apis/datamanager_v1.rb,
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/service.rb,
lib/google/apis/datamanager_v1/gem_version.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Data Manager API
A unified ingestion API for data partners, agencies and advertisers to connect first-party data across Google advertising products.
Defined Under Namespace
Classes: AdEvent, AdIdentifiers, AddressInfo, AudienceMember, AwsWrappedKeyInfo, Baseline, CartData, CompositeData, Consent, ContactIdInfo, CoordinatorKeyInfo, CustomVariable, DataManagerService, DataTypeCount, Destination, DeviceInfo, Empty, EncryptedUserId, EncryptionInfo, ErrorCount, ErrorInfo, Event, EventLocation, EventParameter, ExperimentalField, GcpWrappedKeyInfo, IngestAdEventsRequest, IngestAdEventsResponse, IngestAudienceMembersRequest, IngestAudienceMembersResponse, IngestAudienceMembersStatus, IngestCompositeDataStatus, IngestEventsRequest, IngestEventsResponse, IngestEventsStatus, IngestMobileDataStatus, IngestPairDataStatus, IngestPpidDataStatus, IngestUserDataStatus, IngestUserIdDataStatus, IngestedUserListInfo, IpData, Item, ItemCustomVariable, ItemParameter, ListUserListDirectLicensesResponse, ListUserListGlobalLicenseCustomerInfosResponse, ListUserListGlobalLicensesResponse, ListUserListsResponse, Location, MarketingDataInsight, MarketingDataInsightsAttribute, MobileData, MobileIdInfo, PairData, PairIdInfo, PartnerAudienceInfo, PartnerCustomerAccount, PartnerLink, PartnerLinkMetadata, PpidData, ProductAccount, PseudonymousIdInfo, RemoveAudienceMembersRequest, RemoveAudienceMembersResponse, RemoveAudienceMembersStatus, RemoveCompositeDataStatus, RemoveMobileDataStatus, RemovePairDataStatus, RemovePpidDataStatus, RemoveUserDataStatus, RemoveUserIdDataStatus, RequestStatusPerDestination, RetrieveInsightsRequest, RetrieveInsightsResponse, RetrieveRequestStatusResponse, SearchPartnerLinksResponse, SizeInfo, Status, TargetNetworkInfo, TermsOfService, UserData, UserIdData, UserIdInfo, UserIdentifier, UserList, UserListDirectLicense, UserListGlobalLicense, UserListGlobalLicenseCustomerInfo, UserListLicenseMetrics, UserListLicensePricing, UserProperties, UserProperty, ViewabilityInfo, WarningCount, WarningInfo
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-datamanager_v1 gem
"0.10.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260605"- VERSION =
Version of the Data Manager API this client connects to. This is NOT the gem version.
'V1'- AUTH_DATAMANAGER =
See, edit, create, import, or delete your customer data in Google Ads, Google Marketing Platform (Campaign Manager 360, Search Ads 360, Display & Video 360), and Google Analytics
'https://www.googleapis.com/auth/datamanager'- AUTH_DATAMANAGER_PARTNERLINK =
View, create, or delete your partner links in Google Ads, Marketing Platform (Campaign Manager 360, Search Ads 360, Display & Video 360), and Analytics
'https://www.googleapis.com/auth/datamanager.partnerlink'