Class: Google::Apis::DatamanagerV1::AdEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

An ad event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdEvent

Returns a new instance of AdEvent.



201
202
203
# File 'lib/google/apis/datamanager_v1/classes.rb', line 201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_formatString

Enum value for ad format. Corresponds to the JSON property adFormat

Returns:

  • (String)


32
33
34
# File 'lib/google/apis/datamanager_v1/classes.rb', line 32

def ad_format
  @ad_format
end

#ad_format_stringString

String value for ad format. Corresponds to the JSON property adFormatString

Returns:

  • (String)


37
38
39
# File 'lib/google/apis/datamanager_v1/classes.rb', line 37

def ad_format_string
  @ad_format_string
end

#ad_group_idString

Optional. The ID of the associated ad group. Corresponds to the JSON property adGroupId

Returns:

  • (String)


42
43
44
# File 'lib/google/apis/datamanager_v1/classes.rb', line 42

def ad_group_id
  @ad_group_id
end

#ad_heightFixnum

Optional. The height of the ad in pixels. Corresponds to the JSON property adHeight

Returns:

  • (Fixnum)


47
48
49
# File 'lib/google/apis/datamanager_v1/classes.rb', line 47

def ad_height
  @ad_height
end

#ad_idString

Optional. The ID of the associated ad within the group. Corresponds to the JSON property adId

Returns:

  • (String)


52
53
54
# File 'lib/google/apis/datamanager_v1/classes.rb', line 52

def ad_id
  @ad_id
end

#ad_placementString

Enum value for ad placement. Corresponds to the JSON property adPlacement

Returns:

  • (String)


57
58
59
# File 'lib/google/apis/datamanager_v1/classes.rb', line 57

def ad_placement
  @ad_placement
end

#ad_placement_stringString

String value for ad placement. Corresponds to the JSON property adPlacementString

Returns:

  • (String)


62
63
64
# File 'lib/google/apis/datamanager_v1/classes.rb', line 62

def ad_placement_string
  @ad_placement_string
end

#ad_typeString

Enum value for ad type. Corresponds to the JSON property adType

Returns:

  • (String)


67
68
69
# File 'lib/google/apis/datamanager_v1/classes.rb', line 67

def ad_type
  @ad_type
end

#ad_type_stringString

String value for ad type. Corresponds to the JSON property adTypeString

Returns:

  • (String)


72
73
74
# File 'lib/google/apis/datamanager_v1/classes.rb', line 72

def ad_type_string
  @ad_type_string
end

#ad_widthFixnum

Optional. The width of the ad in pixels. Corresponds to the JSON property adWidth

Returns:

  • (Fixnum)


77
78
79
# File 'lib/google/apis/datamanager_v1/classes.rb', line 77

def ad_width
  @ad_width
end

#advertiser_idString

Required. The ID of the advertiser for the ad event. This must match the ID sent in the linking flow. Corresponds to the JSON property advertiserId

Returns:

  • (String)


83
84
85
# File 'lib/google/apis/datamanager_v1/classes.rb', line 83

def advertiser_id
  @advertiser_id
end

#attribution_hintString

Optional. The partner-assumed attribution status for this ad event. This acts only as a signal for how the partner assumed attribution played out, and does not force an end result in final reports. Corresponds to the JSON property attributionHint

Returns:

  • (String)


90
91
92
# File 'lib/google/apis/datamanager_v1/classes.rb', line 90

def attribution_hint
  @attribution_hint
end

#campaign_idString

Required. The ID of the associated campaign. Corresponds to the JSON property campaignId

Returns:

  • (String)


95
96
97
# File 'lib/google/apis/datamanager_v1/classes.rb', line 95

def campaign_id
  @campaign_id
end

#campaign_nameString

Required. The name of the associated campaign. Corresponds to the JSON property campaignName

Returns:

  • (String)


100
101
102
# File 'lib/google/apis/datamanager_v1/classes.rb', line 100

def campaign_name
  @campaign_name
end

#device_infoGoogle::Apis::DatamanagerV1::DeviceInfo

Information about the device being used (if any) when the event happened. Corresponds to the JSON property deviceInfo



105
106
107
# File 'lib/google/apis/datamanager_v1/classes.rb', line 105

def device_info
  @device_info
end

#event_idString

Optional. An ID created and managed by the caller that uniquely identifies this event. Required if you want to deduplicate ad events that are included in multiple requests. Otherwise, this field is optional. Corresponds to the JSON property eventId

Returns:

  • (String)


112
113
114
# File 'lib/google/apis/datamanager_v1/classes.rb', line 112

def event_id
  @event_id
end

#event_subtypeString

Enum value for event subtype. Corresponds to the JSON property eventSubtype

Returns:

  • (String)


117
118
119
# File 'lib/google/apis/datamanager_v1/classes.rb', line 117

def event_subtype
  @event_subtype
end

#event_subtype_stringString

String value for event subtype. Corresponds to the JSON property eventSubtypeString

Returns:

  • (String)


122
123
124
# File 'lib/google/apis/datamanager_v1/classes.rb', line 122

def event_subtype_string
  @event_subtype_string
end

#event_typeString

Required. The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


127
128
129
# File 'lib/google/apis/datamanager_v1/classes.rb', line 127

def event_type
  @event_type
end

#measurement_allowedBoolean Also known as: measurement_allowed?

Optional. Represents if the row is allowed to be used for measurement purposes, as governed by applicable privacy laws within regional jurisdiction. Corresponds to the JSON property measurementAllowed

Returns:

  • (Boolean)


133
134
135
# File 'lib/google/apis/datamanager_v1/classes.rb', line 133

def measurement_allowed
  @measurement_allowed
end

#mediumString

Required. The medium of the ad, akin to the Google Analytics medium. Corresponds to the JSON property medium

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/datamanager_v1/classes.rb', line 139

def medium
  @medium
end

#mobile_device_idString

Optional. The device ID of the device that the ad was served to. Corresponds to the JSON property mobileDeviceId

Returns:

  • (String)


144
145
146
# File 'lib/google/apis/datamanager_v1/classes.rb', line 144

def mobile_device_id
  @mobile_device_id
end

#platformString

Enum value for platform. Corresponds to the JSON property platform

Returns:

  • (String)


149
150
151
# File 'lib/google/apis/datamanager_v1/classes.rb', line 149

def platform
  @platform
end

#platform_stringString

String value for platform. Corresponds to the JSON property platformString

Returns:

  • (String)


154
155
156
# File 'lib/google/apis/datamanager_v1/classes.rb', line 154

def platform_string
  @platform_string
end

#platform_typeString

Enum value for platform type. Corresponds to the JSON property platformType

Returns:

  • (String)


159
160
161
# File 'lib/google/apis/datamanager_v1/classes.rb', line 159

def platform_type
  @platform_type
end

#platform_type_stringString

String value for platform type. Corresponds to the JSON property platformTypeString

Returns:

  • (String)


164
165
166
# File 'lib/google/apis/datamanager_v1/classes.rb', line 164

def platform_type_string
  @platform_type_string
end

#region_codeString

Required. The ISO 3166-2 country plus subdivision. Corresponds to the JSON property regionCode

Returns:

  • (String)


169
170
171
# File 'lib/google/apis/datamanager_v1/classes.rb', line 169

def region_code
  @region_code
end

#sourceString

Required. The platform source of the ad, akin to the Google Analytics source. Corresponds to the JSON property source

Returns:

  • (String)


174
175
176
# File 'lib/google/apis/datamanager_v1/classes.rb', line 174

def source
  @source
end

#targeting_typeString

Enum value for targeting type. Corresponds to the JSON property targetingType

Returns:

  • (String)


179
180
181
# File 'lib/google/apis/datamanager_v1/classes.rb', line 179

def targeting_type
  @targeting_type
end

#targeting_type_stringString

String value for targeting type. Corresponds to the JSON property targetingTypeString

Returns:

  • (String)


184
185
186
# File 'lib/google/apis/datamanager_v1/classes.rb', line 184

def targeting_type_string
  @targeting_type_string
end

#timestampString

Required. The time the event occurred. Corresponds to the JSON property timestamp

Returns:

  • (String)


189
190
191
# File 'lib/google/apis/datamanager_v1/classes.rb', line 189

def timestamp
  @timestamp
end

#user_dataGoogle::Apis::DatamanagerV1::UserData

Data that identifies the user. At least one identifier is required. Corresponds to the JSON property userData



194
195
196
# File 'lib/google/apis/datamanager_v1/classes.rb', line 194

def user_data
  @user_data
end

#viewability_infoGoogle::Apis::DatamanagerV1::ViewabilityInfo

Details of the viewability of the ad served. Corresponds to the JSON property viewabilityInfo



199
200
201
# File 'lib/google/apis/datamanager_v1/classes.rb', line 199

def viewability_info
  @viewability_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/google/apis/datamanager_v1/classes.rb', line 206

def update!(**args)
  @ad_format = args[:ad_format] if args.key?(:ad_format)
  @ad_format_string = args[:ad_format_string] if args.key?(:ad_format_string)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @ad_height = args[:ad_height] if args.key?(:ad_height)
  @ad_id = args[:ad_id] if args.key?(:ad_id)
  @ad_placement = args[:ad_placement] if args.key?(:ad_placement)
  @ad_placement_string = args[:ad_placement_string] if args.key?(:ad_placement_string)
  @ad_type = args[:ad_type] if args.key?(:ad_type)
  @ad_type_string = args[:ad_type_string] if args.key?(:ad_type_string)
  @ad_width = args[:ad_width] if args.key?(:ad_width)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @attribution_hint = args[:attribution_hint] if args.key?(:attribution_hint)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @campaign_name = args[:campaign_name] if args.key?(:campaign_name)
  @device_info = args[:device_info] if args.key?(:device_info)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_subtype = args[:event_subtype] if args.key?(:event_subtype)
  @event_subtype_string = args[:event_subtype_string] if args.key?(:event_subtype_string)
  @event_type = args[:event_type] if args.key?(:event_type)
  @measurement_allowed = args[:measurement_allowed] if args.key?(:measurement_allowed)
  @medium = args[:medium] if args.key?(:medium)
  @mobile_device_id = args[:mobile_device_id] if args.key?(:mobile_device_id)
  @platform = args[:platform] if args.key?(:platform)
  @platform_string = args[:platform_string] if args.key?(:platform_string)
  @platform_type = args[:platform_type] if args.key?(:platform_type)
  @platform_type_string = args[:platform_type_string] if args.key?(:platform_type_string)
  @region_code = args[:region_code] if args.key?(:region_code)
  @source = args[:source] if args.key?(:source)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
  @targeting_type_string = args[:targeting_type_string] if args.key?(:targeting_type_string)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @user_data = args[:user_data] if args.key?(:user_data)
  @viewability_info = args[:viewability_info] if args.key?(:viewability_info)
end