Class: Google::Apis::DatamanagerV1::AudienceMember

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The audience member to be operated on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AudienceMember

Returns a new instance of AudienceMember.



446
447
448
# File 'lib/google/apis/datamanager_v1/classes.rb', line 446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#composite_dataGoogle::Apis::DatamanagerV1::CompositeData

Composite data holding identifiers and associated data for a user. At least one of user_data or ip_data is required. Corresponds to the JSON property compositeData



393
394
395
# File 'lib/google/apis/datamanager_v1/classes.rb', line 393

def composite_data
  @composite_data
end

Digital Markets Act (DMA) consent settings for the user. Corresponds to the JSON property consent



399
400
401
# File 'lib/google/apis/datamanager_v1/classes.rb', line 399

def consent
  @consent
end

#destination_referencesArray<String>

Optional. Defines which Destination to send the audience member to. Corresponds to the JSON property destinationReferences

Returns:

  • (Array<String>)


404
405
406
# File 'lib/google/apis/datamanager_v1/classes.rb', line 404

def destination_references
  @destination_references
end

#google_user_id_dataGoogle::Apis::DatamanagerV1::GoogleUserIdData

Google user id data holding encrypted google user IDs. At least one google user ID is required. Corresponds to the JSON property googleUserIdData



410
411
412
# File 'lib/google/apis/datamanager_v1/classes.rb', line 410

def google_user_id_data
  @google_user_id_data
end

#mobile_dataGoogle::Apis::DatamanagerV1::MobileData

Mobile IDs for the audience. At least one mobile ID is required. Corresponds to the JSON property mobileData



415
416
417
# File 'lib/google/apis/datamanager_v1/classes.rb', line 415

def mobile_data
  @mobile_data
end

#pair_dataGoogle::Apis::DatamanagerV1::PairData

PAIR IDs for the audience. At least one PAIR ID is required. This feature is only available to data partners. Corresponds to the JSON property pairData



422
423
424
# File 'lib/google/apis/datamanager_v1/classes.rb', line 422

def pair_data
  @pair_data
end

#partner_provided_id_dataGoogle::Apis::DatamanagerV1::PartnerProvidedIdData

Partner-provided data holding the partner-provided identifiers. At least one partner-provided identifier is required. Corresponds to the JSON property partnerProvidedIdData



428
429
430
# File 'lib/google/apis/datamanager_v1/classes.rb', line 428

def partner_provided_id_data
  @partner_provided_id_data
end

#ppid_dataGoogle::Apis::DatamanagerV1::PpidData

Publisher provided identifiers data holding the ppids. At least one ppid is required. This feature is only available to data partners. Corresponds to the JSON property ppidData



434
435
436
# File 'lib/google/apis/datamanager_v1/classes.rb', line 434

def ppid_data
  @ppid_data
end

#user_dataGoogle::Apis::DatamanagerV1::UserData

Data that identifies the user. At least one identifier is required. Corresponds to the JSON property userData



439
440
441
# File 'lib/google/apis/datamanager_v1/classes.rb', line 439

def user_data
  @user_data
end

#user_id_dataGoogle::Apis::DatamanagerV1::UserIdData

User id data holding the user id. Corresponds to the JSON property userIdData



444
445
446
# File 'lib/google/apis/datamanager_v1/classes.rb', line 444

def user_id_data
  @user_id_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/google/apis/datamanager_v1/classes.rb', line 451

def update!(**args)
  @composite_data = args[:composite_data] if args.key?(:composite_data)
  @consent = args[:consent] if args.key?(:consent)
  @destination_references = args[:destination_references] if args.key?(:destination_references)
  @google_user_id_data = args[:google_user_id_data] if args.key?(:google_user_id_data)
  @mobile_data = args[:mobile_data] if args.key?(:mobile_data)
  @pair_data = args[:pair_data] if args.key?(:pair_data)
  @partner_provided_id_data = args[:partner_provided_id_data] if args.key?(:partner_provided_id_data)
  @ppid_data = args[:ppid_data] if args.key?(:ppid_data)
  @user_data = args[:user_data] if args.key?(:user_data)
  @user_id_data = args[:user_id_data] if args.key?(:user_id_data)
end