Class: Google::Apis::DatamanagerV1::EncryptedUserId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user identifier issued to be used for attribution. All fields are required if this is used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptedUserId

Returns a new instance of EncryptedUserId.



928
929
930
# File 'lib/google/apis/datamanager_v1/classes.rb', line 928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_idString

Required. The alphanumeric encrypted id. Corresponds to the JSON property encryptedId

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/datamanager_v1/classes.rb', line 908

def encrypted_id
  @encrypted_id
end

#entity_idFixnum

Required. The encryption entity ID. This should match the encryption configuration for ad serving or Data Transfer. Corresponds to the JSON property entityId

Returns:

  • (Fixnum)


914
915
916
# File 'lib/google/apis/datamanager_v1/classes.rb', line 914

def entity_id
  @entity_id
end

#entity_typeString

Required. The encryption entity type. This should match the encryption configuration for ad serving or Data Transfer. Corresponds to the JSON property entityType

Returns:

  • (String)


920
921
922
# File 'lib/google/apis/datamanager_v1/classes.rb', line 920

def entity_type
  @entity_type
end

#sourceString

Required. Describes whether the encrypted cookie was received from ad serving ( the %m macro) or from Data Transfer. Corresponds to the JSON property source

Returns:

  • (String)


926
927
928
# File 'lib/google/apis/datamanager_v1/classes.rb', line 926

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



933
934
935
936
937
938
# File 'lib/google/apis/datamanager_v1/classes.rb', line 933

def update!(**args)
  @encrypted_id = args[:encrypted_id] if args.key?(:encrypted_id)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @source = args[:source] if args.key?(:source)
end