Class: Google::Apis::DatamanagerV1::ErrorInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::ErrorInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Error counts for each type of error.
Instance Attribute Summary collapse
-
#error_counts ⇒ Array<Google::Apis::DatamanagerV1::ErrorCount>
A list of errors and counts per error reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorInfo
constructor
A new instance of ErrorInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorInfo
Returns a new instance of ErrorInfo.
600 601 602 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_counts ⇒ Array<Google::Apis::DatamanagerV1::ErrorCount>
A list of errors and counts per error reason. May not be populated in all
cases.
Corresponds to the JSON property errorCounts
598 599 600 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 598 def error_counts @error_counts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
605 606 607 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 605 def update!(**args) @error_counts = args[:error_counts] if args.key?(:error_counts) end |