Class: Google::Apis::DatamanagerV1::EventLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The location where the event occurred.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventLocation

Returns a new instance of EventLocation.



1218
1219
1220
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cityString

Optional. The name of the city where the event occurred. Corresponds to the JSON property city

Returns:

  • (String)


1190
1191
1192
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1190

def city
  @city
end

#continent_codeString

Optional. The continent code in UN M49 format where the event occurred. Corresponds to the JSON property continentCode

Returns:

  • (String)


1195
1196
1197
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1195

def continent_code
  @continent_code
end

#region_codeString

Optional. The 2-letter CLDR region code of the user's address. Corresponds to the JSON property regionCode

Returns:

  • (String)


1200
1201
1202
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1200

def region_code
  @region_code
end

#store_idString

Optional. Required for Store Sales. The identifier to represent a physical store where the event happened. Corresponds to the JSON property storeId

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1206

def store_id
  @store_id
end

#subcontinent_codeString

Optional. The subcontinent code in UN M49 format where the event occurred. Corresponds to the JSON property subcontinentCode

Returns:

  • (String)


1211
1212
1213
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1211

def subcontinent_code
  @subcontinent_code
end

#subdivision_codeString

Optional. The ISO 3166-2 subdivision code where the event occurred. Corresponds to the JSON property subdivisionCode

Returns:

  • (String)


1216
1217
1218
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1216

def subdivision_code
  @subdivision_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1223
1224
1225
1226
1227
1228
1229
1230
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1223

def update!(**args)
  @city = args[:city] if args.key?(:city)
  @continent_code = args[:continent_code] if args.key?(:continent_code)
  @region_code = args[:region_code] if args.key?(:region_code)
  @store_id = args[:store_id] if args.key?(:store_id)
  @subcontinent_code = args[:subcontinent_code] if args.key?(:subcontinent_code)
  @subdivision_code = args[:subdivision_code] if args.key?(:subdivision_code)
end