Class: Google::Apis::DatamanagerV1::GcpWrappedKeyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Information about the Google Cloud Platform wrapped key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpWrappedKeyInfo

Returns a new instance of GcpWrappedKeyInfo.



1344
1345
1346
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_dekString

Required. The base64 encoded encrypted data encryption key. Corresponds to the JSON property encryptedDek

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1322

def encrypted_dek
  @encrypted_dek
end

#kek_uriString

Required. Google Cloud Platform Cloud Key Management Service resource ID. Should be in the format of projects/project/locations/location/keyRings/key_ring/cryptoKeys/key or `gcp-kms://projects/`project`/locations/`location`/keyRings/`key_ring`/ cryptoKeys/`key Corresponds to the JSON property kekUri

Returns:

  • (String)


1331
1332
1333
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1331

def kek_uri
  @kek_uri
end

#key_typeString

Required. The type of algorithm used to encrypt the data. Corresponds to the JSON property keyType

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1336

def key_type
  @key_type
end

#wip_providerString

Required. The Workload Identity pool provider required to use KEK. Corresponds to the JSON property wipProvider

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1342

def wip_provider
  @wip_provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1349
1350
1351
1352
1353
1354
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1349

def update!(**args)
  @encrypted_dek = args[:encrypted_dek] if args.key?(:encrypted_dek)
  @kek_uri = args[:kek_uri] if args.key?(:kek_uri)
  @key_type = args[:key_type] if args.key?(:key_type)
  @wip_provider = args[:wip_provider] if args.key?(:wip_provider)
end