Class: Google::Apis::DatamanagerV1::IngestCompositeDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestCompositeDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the composite data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#data_type_counts ⇒ Array<Google::Apis::DatamanagerV1::DataTypeCount>
The total count of data types sent in the upload request for the destination, broken down by data type.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the destination.
-
#upload_match_rate_range ⇒ String
The match rate range of the upload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestCompositeDataStatus
constructor
A new instance of IngestCompositeDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestCompositeDataStatus
Returns a new instance of IngestCompositeDataStatus.
1606 1607 1608 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_type_counts ⇒ Array<Google::Apis::DatamanagerV1::DataTypeCount>
The total count of data types sent in the upload request for the destination,
broken down by data type. Includes all data types in the request, regardless
of whether they were successfully ingested or not.
Corresponds to the JSON property dataTypeCounts
1592 1593 1594 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1592 def data_type_counts @data_type_counts end |
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the
destination. Includes all audience members in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1599 1600 1601 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1599 def record_count @record_count end |
#upload_match_rate_range ⇒ String
The match rate range of the upload.
Corresponds to the JSON property uploadMatchRateRange
1604 1605 1606 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1604 def upload_match_rate_range @upload_match_rate_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1611 1612 1613 1614 1615 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1611 def update!(**args) @data_type_counts = args[:data_type_counts] if args.key?(:data_type_counts) @record_count = args[:record_count] if args.key?(:record_count) @upload_match_rate_range = args[:upload_match_rate_range] if args.key?(:upload_match_rate_range) end |