Class: Google::Apis::DatamanagerV1::IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Request to upload audience members to the provided destinations. Returns an IngestEventsResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestEventsRequest

Returns a new instance of IngestEventsRequest.



1656
1657
1658
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Digital Markets Act (DMA) consent settings for the user. Corresponds to the JSON property consent



1620
1621
1622
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1620

def consent
  @consent
end

#destinationsArray<Google::Apis::DatamanagerV1::Destination>

Required. The list of destinations to send the events to. Corresponds to the JSON property destinations



1625
1626
1627
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1625

def destinations
  @destinations
end

#encodingString

Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored. Corresponds to the JSON property encoding

Returns:

  • (String)


1636
1637
1638
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1636

def encoding
  @encoding
end

#encryption_infoGoogle::Apis::DatamanagerV1::EncryptionInfo

Encryption information for the data being ingested. Corresponds to the JSON property encryptionInfo



1641
1642
1643
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1641

def encryption_info
  @encryption_info
end

#eventsArray<Google::Apis::DatamanagerV1::Event>

Required. The list of events to send to the specified destinations. At most 2000 Event resources can be sent in a single request. Corresponds to the JSON property events



1647
1648
1649
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1647

def events
  @events
end

#validate_onlyBoolean Also known as: validate_only?

Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1653
1654
1655
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1653

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1661

def update!(**args)
  @consent = args[:consent] if args.key?(:consent)
  @destinations = args[:destinations] if args.key?(:destinations)
  @encoding = args[:encoding] if args.key?(:encoding)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @events = args[:events] if args.key?(:events)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end