Class: Google::Apis::DatamanagerV1::IngestEventsStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the events ingestion to the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestEventsStatus

Returns a new instance of IngestEventsStatus.



1706
1707
1708
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of events sent in the upload request. Includes all events in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1704
1705
1706
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1704

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1711
1712
1713
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1711

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
end