Class: Google::Apis::DatamanagerV1::IngestGoogleUserIdDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestGoogleUserIdDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the google user id data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#google_user_id_count ⇒ Fixnum
The total count of google user ids sent in the upload request for the destination.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestGoogleUserIdDataStatus
constructor
A new instance of IngestGoogleUserIdDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestGoogleUserIdDataStatus
Returns a new instance of IngestGoogleUserIdDataStatus.
1735 1736 1737 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_user_id_count ⇒ Fixnum
The total count of google user ids sent in the upload request for the
destination. Includes all google user ids in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property googleUserIdCount
1726 1727 1728 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1726 def google_user_id_count @google_user_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the
destination. Includes all audience members in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1733 1734 1735 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1733 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1740 1741 1742 1743 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1740 def update!(**args) @google_user_id_count = args[:google_user_id_count] if args.key?(:google_user_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |