Class: Google::Apis::DatamanagerV1::IngestUserDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestUserDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the user data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the destination.
-
#upload_match_rate_range ⇒ String
The match rate range of the upload.
-
#user_identifier_count ⇒ Fixnum
The total count of user identifiers sent in the upload request for the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestUserDataStatus
constructor
A new instance of IngestUserDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestUserDataStatus
Returns a new instance of IngestUserDataStatus.
1890 1891 1892 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the
destination. Includes all audience members in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1876 1877 1878 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1876 def record_count @record_count end |
#upload_match_rate_range ⇒ String
The match rate range of the upload.
Corresponds to the JSON property uploadMatchRateRange
1881 1882 1883 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1881 def upload_match_rate_range @upload_match_rate_range end |
#user_identifier_count ⇒ Fixnum
The total count of user identifiers sent in the upload request for the
destination. Includes all user identifiers in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property userIdentifierCount
1888 1889 1890 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1888 def user_identifier_count @user_identifier_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1895 1896 1897 1898 1899 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1895 def update!(**args) @record_count = args[:record_count] if args.key?(:record_count) @upload_match_rate_range = args[:upload_match_rate_range] if args.key?(:upload_match_rate_range) @user_identifier_count = args[:user_identifier_count] if args.key?(:user_identifier_count) end |