Class: Google::Apis::DatamanagerV1::IngestUserIdDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestUserIdDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the user id data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the destination.
-
#user_id_count ⇒ Fixnum
The total count of user ids sent in the upload request for the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestUserIdDataStatus
constructor
A new instance of IngestUserIdDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestUserIdDataStatus
Returns a new instance of IngestUserIdDataStatus.
1921 1922 1923 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the
destination. Includes all audience members in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1912 1913 1914 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1912 def record_count @record_count end |
#user_id_count ⇒ Fixnum
The total count of user ids sent in the upload request for the destination.
Includes all user ids in the request, regardless of whether they were
successfully ingested or not.
Corresponds to the JSON property userIdCount
1919 1920 1921 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1919 def user_id_count @user_id_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1926 1927 1928 1929 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1926 def update!(**args) @record_count = args[:record_count] if args.key?(:record_count) @user_id_count = args[:user_id_count] if args.key?(:user_id_count) end |