Class: Google::Apis::DatamanagerV1::ItemCustomVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Item-level custom variable for ads conversions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemCustomVariable

Returns a new instance of ItemCustomVariable.



2130
2131
2132
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_referencesArray<String>

Optional. Reference string used to determine which of the Event. destination_references the custom variable should be sent to. If empty, the Event.destination_references will be used. Corresponds to the JSON property destinationReferences

Returns:

  • (Array<String>)


2117
2118
2119
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2117

def destination_references
  @destination_references
end

#valueString

Optional. The value to store for the custom variable. Corresponds to the JSON property value

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2122

def value
  @value
end

#variableString

Optional. The name of the custom variable to set. If the variable is not found for the given destination, it will be ignored. Corresponds to the JSON property variable

Returns:

  • (String)


2128
2129
2130
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2128

def variable
  @variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2135
2136
2137
2138
2139
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2135

def update!(**args)
  @destination_references = args[:destination_references] if args.key?(:destination_references)
  @value = args[:value] if args.key?(:value)
  @variable = args[:variable] if args.key?(:variable)
end