Class: Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Response from the ListUserListDirectLicensesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#user_list_direct_licenses ⇒ Array<Google::Apis::DatamanagerV1::UserListDirectLicense>
The licenses for the given user list in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUserListDirectLicensesResponse
constructor
A new instance of ListUserListDirectLicensesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUserListDirectLicensesResponse
Returns a new instance of ListUserListDirectLicensesResponse.
2014 2015 2016 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
2007 2008 2009 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2007 def next_page_token @next_page_token end |
#user_list_direct_licenses ⇒ Array<Google::Apis::DatamanagerV1::UserListDirectLicense>
The licenses for the given user list in the request.
Corresponds to the JSON property userListDirectLicenses
2012 2013 2014 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2012 def user_list_direct_licenses @user_list_direct_licenses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2019 2020 2021 2022 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2019 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @user_list_direct_licenses = args[:user_list_direct_licenses] if args.key?(:user_list_direct_licenses) end |