Class: Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Response from the ListUserListGlobalLicensesCustomerInfoRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUserListGlobalLicenseCustomerInfosResponse

Returns a new instance of ListUserListGlobalLicenseCustomerInfosResponse.



2040
2041
2042
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2033
2034
2035
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2033

def next_page_token
  @next_page_token
end

#user_list_global_license_customer_infosArray<Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo>

The customer information for the given license in the request. Corresponds to the JSON property userListGlobalLicenseCustomerInfos



2038
2039
2040
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2038

def user_list_global_license_customer_infos
  @user_list_global_license_customer_infos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2045
2046
2047
2048
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2045

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @user_list_global_license_customer_infos = args[:user_list_global_license_customer_infos] if args.key?(:user_list_global_license_customer_infos)
end