Class: Google::Apis::DatamanagerV1::MarketingDataInsightsAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Insights for a collection of related attributes of the same dimension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MarketingDataInsightsAttribute

Returns a new instance of MarketingDataInsightsAttribute.



2351
2352
2353
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeString

Age range of the audience for which the lift is provided. Corresponds to the JSON property ageRange

Returns:

  • (String)


2333
2334
2335
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2333

def age_range
  @age_range
end

#genderString

Gender of the audience for which the lift is provided. Corresponds to the JSON property gender

Returns:

  • (String)


2338
2339
2340
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2338

def gender
  @gender
end

#liftFloat

Measure of lift that the audience has for the attribute value as compared to the baseline. Range [0-1]. Corresponds to the JSON property lift

Returns:

  • (Float)


2344
2345
2346
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2344

def lift
  @lift
end

#user_interest_idFixnum

The user interest ID. Corresponds to the JSON property userInterestId

Returns:

  • (Fixnum)


2349
2350
2351
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2349

def user_interest_id
  @user_interest_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
2360
2361
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2356

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @gender = args[:gender] if args.key?(:gender)
  @lift = args[:lift] if args.key?(:lift)
  @user_interest_id = args[:user_interest_id] if args.key?(:user_interest_id)
end