Class: Google::Apis::DatamanagerV1::PairIdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Additional information when PAIR_ID is one of the upload_key_types. This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PairIdInfo

Returns a new instance of PairIdInfo.



2474
2475
2476
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_identifier_countFixnum

Optional. The count of the advertiser's first party data records that have been uploaded to a clean room provider. This does not signify the size of a PAIR user list. Corresponds to the JSON property advertiserIdentifierCount

Returns:

  • (Fixnum)


2445
2446
2447
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2445

def advertiser_identifier_count
  @advertiser_identifier_count
end

#clean_room_identifierString

Required. Immutable. Identifies a unique advertiser to publisher relationship with one clean room provider or across multiple clean room providers. Corresponds to the JSON property cleanRoomIdentifier

Returns:

  • (String)


2451
2452
2453
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2451

def clean_room_identifier
  @clean_room_identifier
end

#match_rate_percentageFixnum

Required. This field denotes the percentage of membership match of this user list with the corresponding publisher's first party data. Must be between 0 and 100 inclusive. Corresponds to the JSON property matchRatePercentage

Returns:

  • (Fixnum)


2458
2459
2460
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2458

def match_rate_percentage
  @match_rate_percentage
end

#publisher_idFixnum

Required. Immutable. Identifies the publisher that the Publisher Advertiser Identity Reconciliation user list is reconciled with. This field is provided by the cleanroom provider and is only unique in the scope of that cleanroom. This cannot be used as a global identifier across multiple cleanrooms. Corresponds to the JSON property publisherId

Returns:

  • (Fixnum)


2466
2467
2468
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2466

def publisher_id
  @publisher_id
end

#publisher_nameString

Required. Descriptive name of the publisher to be displayed in the UI for a better targeting experience. Corresponds to the JSON property publisherName

Returns:

  • (String)


2472
2473
2474
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2472

def publisher_name
  @publisher_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2479
2480
2481
2482
2483
2484
2485
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2479

def update!(**args)
  @advertiser_identifier_count = args[:advertiser_identifier_count] if args.key?(:advertiser_identifier_count)
  @clean_room_identifier = args[:clean_room_identifier] if args.key?(:clean_room_identifier)
  @match_rate_percentage = args[:match_rate_percentage] if args.key?(:match_rate_percentage)
  @publisher_id = args[:publisher_id] if args.key?(:publisher_id)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
end