Class: Google::Apis::DatamanagerV1::PartnerCustomerAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Represents a customer account in the partner's system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerCustomerAccount

Returns a new instance of PartnerCustomerAccount.



2362
2363
2364
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

Required. The identifier of the customer account in the partner's ID space. Corresponds to the JSON property accountId

Returns:

  • (String)


2349
2350
2351
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2349

def 
  @account_id
end

#account_nameString

Optional. The name of the account. Corresponds to the JSON property accountName

Returns:

  • (String)


2354
2355
2356
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2354

def 
  @account_name
end

#account_typeString

Optional. The type of the account. Can be used to distinguish between advertiser accounts and business level accounts, for example. Corresponds to the JSON property accountType

Returns:

  • (String)


2360
2361
2362
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2360

def 
  @account_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2367
2368
2369
2370
2371
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2367

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @account_name = args[:account_name] if args.key?(:account_name)
  @account_type = args[:account_type] if args.key?(:account_type)
end