Class: Google::Apis::DatamanagerV1::PartnerLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A partner link between an owning account and a partner account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerLink

Returns a new instance of PartnerLink.



2589
2590
2591
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_setString

Optional. Immutable. The set of features supported for the partner link. If not specified, the system behavior defaults to FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT. Corresponds to the JSON property featureSet

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2556

def feature_set
  @feature_set
end

#nameString

Identifier. The name of the partner link. Format: accountTypes/account_type/ accounts/account/partnerLinks/partner_link Corresponds to the JSON property name

Returns:

  • (String)


2562
2563
2564
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2562

def name
  @name
end

#owning_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property owningAccount



2567
2568
2569
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2567

def 
  @owning_account
end

#partner_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property partnerAccount



2572
2573
2574
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2572

def 
  @partner_account
end

#partner_customer_accountGoogle::Apis::DatamanagerV1::PartnerCustomerAccount

Represents a customer account in the partner's system. Corresponds to the JSON property partnerCustomerAccount



2577
2578
2579
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2577

def 
  @partner_customer_account
end

Output only. The partner link ID. Corresponds to the JSON property partnerLinkId

Returns:

  • (String)


2582
2583
2584
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2582

def partner_link_id
  @partner_link_id
end

Represents metadata associated with a partner link. Corresponds to the JSON property partnerLinkMetadata



2587
2588
2589
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2587

def 
  @partner_link_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2594

def update!(**args)
  @feature_set = args[:feature_set] if args.key?(:feature_set)
  @name = args[:name] if args.key?(:name)
  @owning_account = args[:owning_account] if args.key?(:owning_account)
  @partner_account = args[:partner_account] if args.key?(:partner_account)
  @partner_customer_account = args[:partner_customer_account] if args.key?(:partner_customer_account)
  @partner_link_id = args[:partner_link_id] if args.key?(:partner_link_id)
  @partner_link_metadata = args[:partner_link_metadata] if args.key?(:partner_link_metadata)
end