Class: Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the remove audience members request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveAudienceMembersStatus

Returns a new instance of RemoveAudienceMembersStatus.



2901
2902
2903
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#composite_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveCompositeDataStatus

The status of the composite data removal from the destination. Corresponds to the JSON property compositeDataRemovalStatus



2864
2865
2866
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2864

def composite_data_removal_status
  @composite_data_removal_status
end

#google_user_id_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveGoogleUserIdDataStatus

The status of the google user id data removal from the destination. Corresponds to the JSON property googleUserIdDataRemovalStatus



2869
2870
2871
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2869

def google_user_id_data_removal_status
  @google_user_id_data_removal_status
end

#mobile_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveMobileDataStatus

The status of the mobile data removal from the destination. Corresponds to the JSON property mobileDataRemovalStatus



2874
2875
2876
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2874

def mobile_data_removal_status
  @mobile_data_removal_status
end

#pair_data_removal_statusGoogle::Apis::DatamanagerV1::RemovePairDataStatus

The status of the pair data removal from the destination. Corresponds to the JSON property pairDataRemovalStatus



2879
2880
2881
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2879

def pair_data_removal_status
  @pair_data_removal_status
end

#partner_provided_id_data_removal_statusGoogle::Apis::DatamanagerV1::RemovePartnerProvidedIdDataStatus

The status of the partner provided id data removal from the destination. Corresponds to the JSON property partnerProvidedIdDataRemovalStatus



2884
2885
2886
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2884

def partner_provided_id_data_removal_status
  @partner_provided_id_data_removal_status
end

#ppid_data_removal_statusGoogle::Apis::DatamanagerV1::RemovePpidDataStatus

The status of the ppid data removal from the destination. Corresponds to the JSON property ppidDataRemovalStatus



2889
2890
2891
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2889

def ppid_data_removal_status
  @ppid_data_removal_status
end

#user_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveUserDataStatus

The status of the user data removal from the destination. Corresponds to the JSON property userDataRemovalStatus



2894
2895
2896
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2894

def user_data_removal_status
  @user_data_removal_status
end

#user_id_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveUserIdDataStatus

The status of the user id data removal from the destination. Corresponds to the JSON property userIdDataRemovalStatus



2899
2900
2901
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2899

def user_id_data_removal_status
  @user_id_data_removal_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2906

def update!(**args)
  @composite_data_removal_status = args[:composite_data_removal_status] if args.key?(:composite_data_removal_status)
  @google_user_id_data_removal_status = args[:google_user_id_data_removal_status] if args.key?(:google_user_id_data_removal_status)
  @mobile_data_removal_status = args[:mobile_data_removal_status] if args.key?(:mobile_data_removal_status)
  @pair_data_removal_status = args[:pair_data_removal_status] if args.key?(:pair_data_removal_status)
  @partner_provided_id_data_removal_status = args[:partner_provided_id_data_removal_status] if args.key?(:partner_provided_id_data_removal_status)
  @ppid_data_removal_status = args[:ppid_data_removal_status] if args.key?(:ppid_data_removal_status)
  @user_data_removal_status = args[:user_data_removal_status] if args.key?(:user_data_removal_status)
  @user_id_data_removal_status = args[:user_id_data_removal_status] if args.key?(:user_id_data_removal_status)
end