Class: Google::Apis::DatamanagerV1::RemoveMobileDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveMobileDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the mobile data removal from the destination.
Instance Attribute Summary collapse
-
#mobile_id_count ⇒ Fixnum
The total count of mobile Ids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveMobileDataStatus
constructor
A new instance of RemoveMobileDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveMobileDataStatus
Returns a new instance of RemoveMobileDataStatus.
2994 2995 2996 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mobile_id_count ⇒ Fixnum
The total count of mobile Ids sent in the removal request. Includes all mobile
ids in the request, regardless of whether they were successfully removed or
not.
Corresponds to the JSON property mobileIdCount
2985 2986 2987 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2985 def mobile_id_count @mobile_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2992 2993 2994 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2992 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2999 3000 3001 3002 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2999 def update!(**args) @mobile_id_count = args[:mobile_id_count] if args.key?(:mobile_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |