Class: Google::Apis::DatamanagerV1::RemovePairDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the pair data removal from the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemovePairDataStatus

Returns a new instance of RemovePairDataStatus.



3022
3023
3024
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pair_id_countFixnum

The total count of pair ids sent in the removal request. Includes all pair ids in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property pairIdCount

Returns:

  • (Fixnum)


3013
3014
3015
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3013

def pair_id_count
  @pair_id_count
end

#record_countFixnum

The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


3020
3021
3022
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3020

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3027
3028
3029
3030
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3027

def update!(**args)
  @pair_id_count = args[:pair_id_count] if args.key?(:pair_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end