Class: Google::Apis::DatamanagerV1::RemovePpidDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the ppid data removal from the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemovePpidDataStatus

Returns a new instance of RemovePpidDataStatus.



3079
3080
3081
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ppid_countFixnum

The total count of ppids sent in the removal request. Includes all ppids in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property ppidCount

Returns:

  • (Fixnum)


3070
3071
3072
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3070

def ppid_count
  @ppid_count
end

#record_countFixnum

The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


3077
3078
3079
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3077

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3084
3085
3086
3087
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3084

def update!(**args)
  @ppid_count = args[:ppid_count] if args.key?(:ppid_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end