Class: Google::Apis::DatamanagerV1::RequestStatusPerDestination
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RequestStatusPerDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A request status per destination.
Instance Attribute Summary collapse
-
#audience_members_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
The status of the ingest audience members request.
-
#audience_members_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
The status of the remove audience members request.
-
#destination ⇒ Google::Apis::DatamanagerV1::Destination
The Google product you're sending data to.
-
#error_info ⇒ Google::Apis::DatamanagerV1::ErrorInfo
Error counts for each type of error.
-
#events_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestEventsStatus
The status of the events ingestion to the destination.
-
#remove_all_audience_members_status ⇒ Google::Apis::DatamanagerV1::RemoveAllAudienceMembersStatus
The status of the remove all audience members request.
-
#request_status ⇒ String
The request status of the destination.
-
#warning_info ⇒ Google::Apis::DatamanagerV1::WarningInfo
Warning counts for each type of warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestStatusPerDestination
constructor
A new instance of RequestStatusPerDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestStatusPerDestination
Returns a new instance of RequestStatusPerDestination.
3191 3192 3193 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_members_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
The status of the ingest audience members request.
Corresponds to the JSON property audienceMembersIngestionStatus
3154 3155 3156 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3154 def audience_members_ingestion_status @audience_members_ingestion_status end |
#audience_members_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
The status of the remove audience members request.
Corresponds to the JSON property audienceMembersRemovalStatus
3159 3160 3161 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3159 def audience_members_removal_status @audience_members_removal_status end |
#destination ⇒ Google::Apis::DatamanagerV1::Destination
The Google product you're sending data to. For example, a Google Ads account.
Corresponds to the JSON property destination
3164 3165 3166 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3164 def destination @destination end |
#error_info ⇒ Google::Apis::DatamanagerV1::ErrorInfo
Error counts for each type of error.
Corresponds to the JSON property errorInfo
3169 3170 3171 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3169 def error_info @error_info end |
#events_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestEventsStatus
The status of the events ingestion to the destination.
Corresponds to the JSON property eventsIngestionStatus
3174 3175 3176 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3174 def events_ingestion_status @events_ingestion_status end |
#remove_all_audience_members_status ⇒ Google::Apis::DatamanagerV1::RemoveAllAudienceMembersStatus
The status of the remove all audience members request.
Corresponds to the JSON property removeAllAudienceMembersStatus
3179 3180 3181 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3179 def remove_all_audience_members_status @remove_all_audience_members_status end |
#request_status ⇒ String
The request status of the destination.
Corresponds to the JSON property requestStatus
3184 3185 3186 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3184 def request_status @request_status end |
#warning_info ⇒ Google::Apis::DatamanagerV1::WarningInfo
Warning counts for each type of warning.
Corresponds to the JSON property warningInfo
3189 3190 3191 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3189 def warning_info @warning_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3196 3197 3198 3199 3200 3201 3202 3203 3204 3205 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3196 def update!(**args) @audience_members_ingestion_status = args[:audience_members_ingestion_status] if args.key?(:audience_members_ingestion_status) @audience_members_removal_status = args[:audience_members_removal_status] if args.key?(:audience_members_removal_status) @destination = args[:destination] if args.key?(:destination) @error_info = args[:error_info] if args.key?(:error_info) @events_ingestion_status = args[:events_ingestion_status] if args.key?(:events_ingestion_status) @remove_all_audience_members_status = args[:remove_all_audience_members_status] if args.key?(:remove_all_audience_members_status) @request_status = args[:request_status] if args.key?(:request_status) @warning_info = args[:warning_info] if args.key?(:warning_info) end |