Class: Google::Apis::DatamanagerV1::UserListDirectLicense

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user list direct license. This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserListDirectLicense

Returns a new instance of UserListDirectLicense.



3685
3686
3687
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_account_display_nameString

Output only. Name of client customer which the user list is being licensed to. This field is read-only. Corresponds to the JSON property clientAccountDisplayName

Returns:

  • (String)


3636
3637
3638
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3636

def 
  @client_account_display_name
end

#client_account_idFixnum

Immutable. ID of client customer which the user list is being licensed to. Corresponds to the JSON property clientAccountId

Returns:

  • (Fixnum)


3641
3642
3643
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3641

def 
  @client_account_id
end

#client_account_typeString

Immutable. Account type of client customer which the user list is being licensed to. Corresponds to the JSON property clientAccountType

Returns:

  • (String)


3647
3648
3649
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3647

def 
  @client_account_type
end

#historical_pricingsArray<Google::Apis::DatamanagerV1::UserListLicensePricing>

Output only. Pricing history of this user list license. This field is read- only. Corresponds to the JSON property historicalPricings



3653
3654
3655
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3653

def historical_pricings
  @historical_pricings
end

#metricsGoogle::Apis::DatamanagerV1::UserListLicenseMetrics

Metrics related to a user list license. Corresponds to the JSON property metrics



3658
3659
3660
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3658

def metrics
  @metrics
end

#nameString

Identifier. The resource name of the user list direct license. Corresponds to the JSON property name

Returns:

  • (String)


3663
3664
3665
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3663

def name
  @name
end

#pricingGoogle::Apis::DatamanagerV1::UserListLicensePricing

A user list license pricing. Corresponds to the JSON property pricing



3668
3669
3670
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3668

def pricing
  @pricing
end

#statusString

Optional. Status of UserListDirectLicense - ENABLED or DISABLED. Corresponds to the JSON property status

Returns:

  • (String)


3673
3674
3675
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3673

def status
  @status
end

#user_list_display_nameString

Output only. Name of the user list being licensed. This field is read-only. Corresponds to the JSON property userListDisplayName

Returns:

  • (String)


3678
3679
3680
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3678

def user_list_display_name
  @user_list_display_name
end

#user_list_idFixnum

Immutable. ID of the user list being licensed. Corresponds to the JSON property userListId

Returns:

  • (Fixnum)


3683
3684
3685
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3683

def user_list_id
  @user_list_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3690

def update!(**args)
  @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name)
  @client_account_id = args[:client_account_id] if args.key?(:client_account_id)
  @client_account_type = args[:client_account_type] if args.key?(:client_account_type)
  @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @pricing = args[:pricing] if args.key?(:pricing)
  @status = args[:status] if args.key?(:status)
  @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name)
  @user_list_id = args[:user_list_id] if args.key?(:user_list_id)
end