Class: Google::Apis::DatamanagerV1::UserListLicenseMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Metrics related to a user list license.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserListLicenseMetrics

Returns a new instance of UserListLicenseMetrics.



3887
3888
3889
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#click_countFixnum

Output only. The number of clicks for the user list license. Corresponds to the JSON property clickCount

Returns:

  • (Fixnum)


3857
3858
3859
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3857

def click_count
  @click_count
end

#end_dateFixnum

Output only. The end date (inclusive) of the metrics in the format YYYYMMDD. For example, 20260102 represents January 2, 2026. If start_date is used in the filter, end_date is also required. If neither start_date nor end_date are included in the filter, the UserListLicenseMetrics fields will not be populated in the response. Corresponds to the JSON property endDate

Returns:

  • (Fixnum)


3866
3867
3868
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3866

def end_date
  @end_date
end

#impression_countFixnum

Output only. The number of impressions for the user list license. Corresponds to the JSON property impressionCount

Returns:

  • (Fixnum)


3871
3872
3873
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3871

def impression_count
  @impression_count
end

#revenue_usd_microsFixnum

Output only. The revenue for the user list license in USD micros. Corresponds to the JSON property revenueUsdMicros

Returns:

  • (Fixnum)


3876
3877
3878
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3876

def revenue_usd_micros
  @revenue_usd_micros
end

#start_dateFixnum

Output only. The start date (inclusive) of the metrics in the format YYYYMMDD. For example, 20260102 represents January 2, 2026. If end_date is used in the filter, start_date is also required. If neither start_date nor end_date are included in the filter, the UserListLicenseMetrics fields will not be populated in the response. Corresponds to the JSON property startDate

Returns:

  • (Fixnum)


3885
3886
3887
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3885

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3892
3893
3894
3895
3896
3897
3898
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3892

def update!(**args)
  @click_count = args[:click_count] if args.key?(:click_count)
  @end_date = args[:end_date] if args.key?(:end_date)
  @impression_count = args[:impression_count] if args.key?(:impression_count)
  @revenue_usd_micros = args[:revenue_usd_micros] if args.key?(:revenue_usd_micros)
  @start_date = args[:start_date] if args.key?(:start_date)
end