Class: Google::Apis::DatamanagerV1::UserProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Advertiser-assessed information about the user at the time that the event happened. See https://support.google.com/google-ads/answer/14007601 for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserProperties

Returns a new instance of UserProperties.



2826
2827
2828
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_user_propertiesArray<Google::Apis::DatamanagerV1::UserProperty>

Optional. A bucket of any additional user properties for the user associated with this event. Corresponds to the JSON property additionalUserProperties



2814
2815
2816
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2814

def additional_user_properties
  @additional_user_properties
end

#customer_typeString

Optional. Type of the customer associated with the event. Corresponds to the JSON property customerType

Returns:

  • (String)


2819
2820
2821
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2819

def customer_type
  @customer_type
end

#customer_value_bucketString

Optional. The advertiser-assessed value of the customer. Corresponds to the JSON property customerValueBucket

Returns:

  • (String)


2824
2825
2826
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2824

def customer_value_bucket
  @customer_value_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2831
2832
2833
2834
2835
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2831

def update!(**args)
  @additional_user_properties = args[:additional_user_properties] if args.key?(:additional_user_properties)
  @customer_type = args[:customer_type] if args.key?(:customer_type)
  @customer_value_bucket = args[:customer_value_bucket] if args.key?(:customer_value_bucket)
end