Class: Google::Apis::DatamanagerV1::WarningInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::WarningInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Warning counts for each type of warning.
Instance Attribute Summary collapse
-
#warning_counts ⇒ Array<Google::Apis::DatamanagerV1::WarningCount>
A list of warnings and counts per warning reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WarningInfo
constructor
A new instance of WarningInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WarningInfo
Returns a new instance of WarningInfo.
3130 3131 3132 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#warning_counts ⇒ Array<Google::Apis::DatamanagerV1::WarningCount>
A list of warnings and counts per warning reason.
Corresponds to the JSON property warningCounts
3128 3129 3130 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3128 def warning_counts @warning_counts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3135 3136 3137 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3135 def update!(**args) @warning_counts = args[:warning_counts] if args.key?(:warning_counts) end |