Class: Google::Apis::DatamanagerV1::AdIdentifiers
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::AdIdentifiers
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
Instance Attribute Summary collapse
-
#dclid ⇒ String
Optional.
-
#encrypted_user_ids ⇒ Array<Google::Apis::DatamanagerV1::EncryptedUserId>
Optional.
-
#gbraid ⇒ String
Optional.
-
#gclid ⇒ String
Optional.
-
#impression_id ⇒ String
Optional.
-
#landing_page_device_info ⇒ Google::Apis::DatamanagerV1::DeviceInfo
Information about the device being used (if any) when the event happened.
-
#match_id ⇒ String
Optional.
-
#mobile_device_id ⇒ String
Optional.
-
#session_attributes ⇒ String
Optional.
-
#wbraid ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdIdentifiers
constructor
A new instance of AdIdentifiers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdIdentifiers
Returns a new instance of AdIdentifiers.
301 302 303 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dclid ⇒ String
Optional. The display click ID associated with this event.
Corresponds to the JSON property dclid
251 252 253 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 251 def dclid @dclid end |
#encrypted_user_ids ⇒ Array<Google::Apis::DatamanagerV1::EncryptedUserId>
Optional. Any number of encrypted user IDs.
Corresponds to the JSON property encryptedUserIds
256 257 258 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 256 def encrypted_user_ids @encrypted_user_ids end |
#gbraid ⇒ String
Optional. The click identifier for clicks associated with app events and
originating from iOS devices starting with iOS14.
Corresponds to the JSON property gbraid
262 263 264 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 262 def gbraid @gbraid end |
#gclid ⇒ String
Optional. The Google click ID (gclid) associated with this event.
Corresponds to the JSON property gclid
267 268 269 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 267 def gclid @gclid end |
#impression_id ⇒ String
Optional. The impression ID associated with this event.
Corresponds to the JSON property impressionId
272 273 274 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 272 def impression_id @impression_id end |
#landing_page_device_info ⇒ Google::Apis::DatamanagerV1::DeviceInfo
Information about the device being used (if any) when the event happened.
Corresponds to the JSON property landingPageDeviceInfo
277 278 279 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 277 def landing_page_device_info @landing_page_device_info end |
#match_id ⇒ String
Optional. The match ID field used to join this event with a previous event.
Corresponds to the JSON property matchId
282 283 284 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 282 def match_id @match_id end |
#mobile_device_id ⇒ String
Optional. The mobile identifier for advertisers. This would be IDFA on iOS,
AdID on Android, or other platforms’ identifiers for advertisers.
Corresponds to the JSON property mobileDeviceId
288 289 290 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 288 def mobile_device_id @mobile_device_id end |
#session_attributes ⇒ String
Optional. Session attributes for event attribution and modeling.
Corresponds to the JSON property sessionAttributes
293 294 295 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 293 def session_attributes @session_attributes end |
#wbraid ⇒ String
Optional. The click identifier for clicks associated with web events and
originating from iOS devices starting with iOS14.
Corresponds to the JSON property wbraid
299 300 301 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 299 def wbraid @wbraid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 306 def update!(**args) @dclid = args[:dclid] if args.key?(:dclid) @encrypted_user_ids = args[:encrypted_user_ids] if args.key?(:encrypted_user_ids) @gbraid = args[:gbraid] if args.key?(:gbraid) @gclid = args[:gclid] if args.key?(:gclid) @impression_id = args[:impression_id] if args.key?(:impression_id) @landing_page_device_info = args[:landing_page_device_info] if args.key?(:landing_page_device_info) @match_id = args[:match_id] if args.key?(:match_id) @mobile_device_id = args[:mobile_device_id] if args.key?(:mobile_device_id) @session_attributes = args[:session_attributes] if args.key?(:session_attributes) @wbraid = args[:wbraid] if args.key?(:wbraid) end |