Class: Google::Apis::DatamanagerV1::AdIdentifiers

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdIdentifiers

Returns a new instance of AdIdentifiers.



57
58
59
# File 'lib/google/apis/datamanager_v1/classes.rb', line 57

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gbraidString

Optional. The click identifier for clicks associated with app events and originating from iOS devices starting with iOS14. Corresponds to the JSON property gbraid

Returns:

  • (String)


34
35
36
# File 'lib/google/apis/datamanager_v1/classes.rb', line 34

def gbraid
  @gbraid
end

#gclidString

Optional. The Google click ID (gclid) associated with this event. Corresponds to the JSON property gclid

Returns:

  • (String)


39
40
41
# File 'lib/google/apis/datamanager_v1/classes.rb', line 39

def gclid
  @gclid
end

#landing_page_device_infoGoogle::Apis::DatamanagerV1::DeviceInfo

Information about the device being used (if any) when the event happened. Corresponds to the JSON property landingPageDeviceInfo



44
45
46
# File 'lib/google/apis/datamanager_v1/classes.rb', line 44

def landing_page_device_info
  @landing_page_device_info
end

#session_attributesString

Optional. Session attributes for event attribution and modeling. Corresponds to the JSON property sessionAttributes

Returns:

  • (String)


49
50
51
# File 'lib/google/apis/datamanager_v1/classes.rb', line 49

def session_attributes
  @session_attributes
end

#wbraidString

Optional. The click identifier for clicks associated with web events and originating from iOS devices starting with iOS14. Corresponds to the JSON property wbraid

Returns:

  • (String)


55
56
57
# File 'lib/google/apis/datamanager_v1/classes.rb', line 55

def wbraid
  @wbraid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62
63
64
65
66
67
68
# File 'lib/google/apis/datamanager_v1/classes.rb', line 62

def update!(**args)
  @gbraid = args[:gbraid] if args.key?(:gbraid)
  @gclid = args[:gclid] if args.key?(:gclid)
  @landing_page_device_info = args[:landing_page_device_info] if args.key?(:landing_page_device_info)
  @session_attributes = args[:session_attributes] if args.key?(:session_attributes)
  @wbraid = args[:wbraid] if args.key?(:wbraid)
end