Class: Google::Apis::DatamanagerV1::AddressInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::AddressInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Address information for the user.
Instance Attribute Summary collapse
-
#address_line ⇒ String
Optional.
-
#administrative_area ⇒ String
Optional.
-
#city ⇒ String
Optional.
-
#family_name ⇒ String
Required.
-
#given_name ⇒ String
Required.
-
#postal_code ⇒ String
Required.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddressInfo
constructor
A new instance of AddressInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddressInfo
Returns a new instance of AddressInfo.
369 370 371 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_line ⇒ String
Optional. The street and number of the user's address. Used only for Google
Analytics. This field is hashed and possibly encrypted. Normalize the value
before hashing: - Remove symbol characters - Convert to lowercase - Remove
leading and trailing whitespace
Corresponds to the JSON property addressLine
330 331 332 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 330 def address_line @address_line end |
#administrative_area ⇒ String
Optional. The administrative area (state/province) of the user's address. Used
only for Google Analytics. The value should be normalized as such: - Remove
symbol characters - Convert to lowercase - Remove leading and trailing
whitespace
Corresponds to the JSON property administrativeArea
338 339 340 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 338 def administrative_area @administrative_area end |
#city ⇒ String
Optional. The city of the user's address. Used only for Google Analytics. The
value should be normalized as such: - Remove symbol characters - Convert to
lowercase - Remove leading and trailing whitespace
Corresponds to the JSON property city
345 346 347 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 345 def city @city end |
#family_name ⇒ String
Required. Family (last) name of the user, all lowercase, with no punctuation,
no leading or trailing whitespace, and hashed as SHA-256.
Corresponds to the JSON property familyName
351 352 353 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 351 def family_name @family_name end |
#given_name ⇒ String
Required. Given (first) name of the user, all lowercase, with no punctuation,
no leading or trailing whitespace, and hashed as SHA-256.
Corresponds to the JSON property givenName
357 358 359 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 357 def given_name @given_name end |
#postal_code ⇒ String
Required. The postal code of the user's address.
Corresponds to the JSON property postalCode
362 363 364 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 362 def postal_code @postal_code end |
#region_code ⇒ String
Required. The 2-letter region code in ISO-3166-1 alpha-2 of the user's address.
Corresponds to the JSON property regionCode
367 368 369 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 367 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
374 375 376 377 378 379 380 381 382 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 374 def update!(**args) @address_line = args[:address_line] if args.key?(:address_line) @administrative_area = args[:administrative_area] if args.key?(:administrative_area) @city = args[:city] if args.key?(:city) @family_name = args[:family_name] if args.key?(:family_name) @given_name = args[:given_name] if args.key?(:given_name) @postal_code = args[:postal_code] if args.key?(:postal_code) @region_code = args[:region_code] if args.key?(:region_code) end |