Class: Google::Apis::DatamanagerV1::AddressInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Address information for the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressInfo

Returns a new instance of AddressInfo.



346
347
348
# File 'lib/google/apis/datamanager_v1/classes.rb', line 346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#family_nameString

Required. Family (last) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256. Corresponds to the JSON property familyName

Returns:

  • (String)


328
329
330
# File 'lib/google/apis/datamanager_v1/classes.rb', line 328

def family_name
  @family_name
end

#given_nameString

Required. Given (first) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256. Corresponds to the JSON property givenName

Returns:

  • (String)


334
335
336
# File 'lib/google/apis/datamanager_v1/classes.rb', line 334

def given_name
  @given_name
end

#postal_codeString

Required. The postal code of the user's address. Corresponds to the JSON property postalCode

Returns:

  • (String)


339
340
341
# File 'lib/google/apis/datamanager_v1/classes.rb', line 339

def postal_code
  @postal_code
end

#region_codeString

Required. The 2-letter region code in ISO-3166-1 alpha-2 of the user's address. Corresponds to the JSON property regionCode

Returns:

  • (String)


344
345
346
# File 'lib/google/apis/datamanager_v1/classes.rb', line 344

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



351
352
353
354
355
356
# File 'lib/google/apis/datamanager_v1/classes.rb', line 351

def update!(**args)
  @family_name = args[:family_name] if args.key?(:family_name)
  @given_name = args[:given_name] if args.key?(:given_name)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @region_code = args[:region_code] if args.key?(:region_code)
end