Class: Google::Apis::DatamanagerV1::AddressInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Address information for the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressInfo

Returns a new instance of AddressInfo.



97
98
99
# File 'lib/google/apis/datamanager_v1/classes.rb', line 97

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#family_nameString

Required. Family (last) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256. Corresponds to the JSON property familyName

Returns:

  • (String)


79
80
81
# File 'lib/google/apis/datamanager_v1/classes.rb', line 79

def family_name
  @family_name
end

#given_nameString

Required. Given (first) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256. Corresponds to the JSON property givenName

Returns:

  • (String)


85
86
87
# File 'lib/google/apis/datamanager_v1/classes.rb', line 85

def given_name
  @given_name
end

#postal_codeString

Required. The postal code of the user's address. Corresponds to the JSON property postalCode

Returns:

  • (String)


90
91
92
# File 'lib/google/apis/datamanager_v1/classes.rb', line 90

def postal_code
  @postal_code
end

#region_codeString

Required. The 2-letter region code in ISO-3166-1 alpha-2 of the user's address. Corresponds to the JSON property regionCode

Returns:

  • (String)


95
96
97
# File 'lib/google/apis/datamanager_v1/classes.rb', line 95

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



102
103
104
105
106
107
# File 'lib/google/apis/datamanager_v1/classes.rb', line 102

def update!(**args)
  @family_name = args[:family_name] if args.key?(:family_name)
  @given_name = args[:given_name] if args.key?(:given_name)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @region_code = args[:region_code] if args.key?(:region_code)
end