Class: Google::Apis::DatamanagerV1::AudienceMember
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::AudienceMember
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The audience member to be operated on.
Instance Attribute Summary collapse
-
#composite_data ⇒ Google::Apis::DatamanagerV1::CompositeData
Composite data holding identifiers and associated data for a user.
-
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA) consent settings for the user.
-
#destination_references ⇒ Array<String>
Optional.
-
#mobile_data ⇒ Google::Apis::DatamanagerV1::MobileData
Mobile IDs for the audience.
-
#pair_data ⇒ Google::Apis::DatamanagerV1::PairData
PAIR IDs for the audience.
-
#ppid_data ⇒ Google::Apis::DatamanagerV1::PpidData
Publisher provided identifiers data holding the ppids.
-
#user_data ⇒ Google::Apis::DatamanagerV1::UserData
Data that identifies the user.
-
#user_id_data ⇒ Google::Apis::DatamanagerV1::UserIdData
User id data holding the user id.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudienceMember
constructor
A new instance of AudienceMember.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudienceMember
Returns a new instance of AudienceMember.
408 409 410 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 408 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_data ⇒ Google::Apis::DatamanagerV1::CompositeData
Composite data holding identifiers and associated data for a user. At least
one of user_data or ip_data is required.
Corresponds to the JSON property compositeData
367 368 369 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 367 def composite_data @composite_data end |
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA)
consent settings for the user.
Corresponds to the JSON property consent
373 374 375 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 373 def @consent end |
#destination_references ⇒ Array<String>
Optional. Defines which Destination to send the audience member to.
Corresponds to the JSON property destinationReferences
378 379 380 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 378 def destination_references @destination_references end |
#mobile_data ⇒ Google::Apis::DatamanagerV1::MobileData
Mobile IDs for the audience. At least one mobile ID is required.
Corresponds to the JSON property mobileData
383 384 385 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 383 def mobile_data @mobile_data end |
#pair_data ⇒ Google::Apis::DatamanagerV1::PairData
PAIR IDs for the audience.
At least one PAIR ID is required. This feature is only available to data
partners.
Corresponds to the JSON property pairData
390 391 392 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 390 def pair_data @pair_data end |
#ppid_data ⇒ Google::Apis::DatamanagerV1::PpidData
Publisher provided identifiers data holding the ppids. At least one ppid is
required. This feature is only available to data partners.
Corresponds to the JSON property ppidData
396 397 398 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 396 def ppid_data @ppid_data end |
#user_data ⇒ Google::Apis::DatamanagerV1::UserData
Data that identifies the user. At least one identifier is required.
Corresponds to the JSON property userData
401 402 403 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 401 def user_data @user_data end |
#user_id_data ⇒ Google::Apis::DatamanagerV1::UserIdData
User id data holding the user id.
Corresponds to the JSON property userIdData
406 407 408 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 406 def user_id_data @user_id_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
413 414 415 416 417 418 419 420 421 422 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 413 def update!(**args) @composite_data = args[:composite_data] if args.key?(:composite_data) @consent = args[:consent] if args.key?(:consent) @destination_references = args[:destination_references] if args.key?(:destination_references) @mobile_data = args[:mobile_data] if args.key?(:mobile_data) @pair_data = args[:pair_data] if args.key?(:pair_data) @ppid_data = args[:ppid_data] if args.key?(:ppid_data) @user_data = args[:user_data] if args.key?(:user_data) @user_id_data = args[:user_id_data] if args.key?(:user_id_data) end |