Class: Google::Apis::DatamanagerV1::Baseline
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::Baseline
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Baseline criteria against which insights are compared.
Instance Attribute Summary collapse
-
#baseline_location ⇒ Google::Apis::DatamanagerV1::Location
The baseline location of the request.
-
#location_auto_detection_enabled ⇒ Boolean
(also: #location_auto_detection_enabled?)
If set to true, the service will try to automatically detect the baseline location for insights.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Baseline
constructor
A new instance of Baseline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Baseline
Returns a new instance of Baseline.
227 228 229 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#baseline_location ⇒ Google::Apis::DatamanagerV1::Location
The baseline location of the request. Baseline location is on OR-list of ISO
3166-1 alpha-2 region codes of the requested regions.
Corresponds to the JSON property baselineLocation
218 219 220 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 218 def baseline_location @baseline_location end |
#location_auto_detection_enabled ⇒ Boolean Also known as: location_auto_detection_enabled?
If set to true, the service will try to automatically detect the baseline
location for insights.
Corresponds to the JSON property locationAutoDetectionEnabled
224 225 226 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 224 def location_auto_detection_enabled @location_auto_detection_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
232 233 234 235 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 232 def update!(**args) @baseline_location = args[:baseline_location] if args.key?(:baseline_location) @location_auto_detection_enabled = args[:location_auto_detection_enabled] if args.key?(:location_auto_detection_enabled) end |