Class: Google::Apis::DatamanagerV1::CartData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The cart data associated with the event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CartData

Returns a new instance of CartData.



268
269
270
# File 'lib/google/apis/datamanager_v1/classes.rb', line 268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::DatamanagerV1::Item>

Optional. The list of items associated with the event. Corresponds to the JSON property items



245
246
247
# File 'lib/google/apis/datamanager_v1/classes.rb', line 245

def items
  @items
end

#merchant_feed_labelString

Optional. The Merchant Center feed label associated with the feed of the items. Corresponds to the JSON property merchantFeedLabel

Returns:

  • (String)


250
251
252
# File 'lib/google/apis/datamanager_v1/classes.rb', line 250

def merchant_feed_label
  @merchant_feed_label
end

#merchant_feed_language_codeString

Optional. The language code in ISO 639-1 associated with the Merchant Center feed of the items.where your items are uploaded. Corresponds to the JSON property merchantFeedLanguageCode

Returns:

  • (String)


256
257
258
# File 'lib/google/apis/datamanager_v1/classes.rb', line 256

def merchant_feed_language_code
  @merchant_feed_language_code
end

#merchant_idString

Optional. The Merchant Center ID associated with the items. Corresponds to the JSON property merchantId

Returns:

  • (String)


261
262
263
# File 'lib/google/apis/datamanager_v1/classes.rb', line 261

def merchant_id
  @merchant_id
end

#transaction_discountFloat

Optional. The sum of all discounts associated with the transaction. Corresponds to the JSON property transactionDiscount

Returns:

  • (Float)


266
267
268
# File 'lib/google/apis/datamanager_v1/classes.rb', line 266

def transaction_discount
  @transaction_discount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



273
274
275
276
277
278
279
# File 'lib/google/apis/datamanager_v1/classes.rb', line 273

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @merchant_feed_label = args[:merchant_feed_label] if args.key?(:merchant_feed_label)
  @merchant_feed_language_code = args[:merchant_feed_language_code] if args.key?(:merchant_feed_language_code)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @transaction_discount = args[:transaction_discount] if args.key?(:transaction_discount)
end