Class: Google::Apis::DatamanagerV1::CartData
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::CartData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The cart data associated with the event.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::DatamanagerV1::Item>
Optional.
-
#merchant_feed_label ⇒ String
Optional.
-
#merchant_feed_language_code ⇒ String
Optional.
-
#merchant_id ⇒ String
Optional.
-
#transaction_discount ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CartData
constructor
A new instance of CartData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CartData
Returns a new instance of CartData.
268 269 270 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::DatamanagerV1::Item>
Optional. The list of items associated with the event.
Corresponds to the JSON property items
245 246 247 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 245 def items @items end |
#merchant_feed_label ⇒ String
Optional. The Merchant Center feed label associated with the feed of the items.
Corresponds to the JSON property merchantFeedLabel
250 251 252 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 250 def merchant_feed_label @merchant_feed_label end |
#merchant_feed_language_code ⇒ String
Optional. The language code in ISO 639-1 associated with the Merchant Center
feed of the items.where your items are uploaded.
Corresponds to the JSON property merchantFeedLanguageCode
256 257 258 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 256 def merchant_feed_language_code @merchant_feed_language_code end |
#merchant_id ⇒ String
Optional. The Merchant Center ID associated with the items.
Corresponds to the JSON property merchantId
261 262 263 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 261 def merchant_id @merchant_id end |
#transaction_discount ⇒ Float
Optional. The sum of all discounts associated with the transaction.
Corresponds to the JSON property transactionDiscount
266 267 268 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 266 def transaction_discount @transaction_discount end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
273 274 275 276 277 278 279 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 273 def update!(**args) @items = args[:items] if args.key?(:items) @merchant_feed_label = args[:merchant_feed_label] if args.key?(:merchant_feed_label) @merchant_feed_language_code = args[:merchant_feed_language_code] if args.key?(:merchant_feed_language_code) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @transaction_discount = args[:transaction_discount] if args.key?(:transaction_discount) end |