Class: Google::Apis::DatamanagerV1::CompositeData
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::CompositeData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Composite data holding identifiers and associated data for a user. At least
one of user_data or ip_data is required.
Instance Attribute Summary collapse
-
#ip_data ⇒ Array<Google::Apis::DatamanagerV1::IpData>
Optional.
-
#user_data ⇒ Google::Apis::DatamanagerV1::UserData
Data that identifies the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeData
constructor
A new instance of CompositeData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeData
Returns a new instance of CompositeData.
563 564 565 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_data ⇒ Array<Google::Apis::DatamanagerV1::IpData>
Optional. IP address data representing customer interaction used to build the
audience.
Corresponds to the JSON property ipData
556 557 558 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 556 def ip_data @ip_data end |
#user_data ⇒ Google::Apis::DatamanagerV1::UserData
Data that identifies the user. At least one identifier is required.
Corresponds to the JSON property userData
561 562 563 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 561 def user_data @user_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
568 569 570 571 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 568 def update!(**args) @ip_data = args[:ip_data] if args.key?(:ip_data) @user_data = args[:user_data] if args.key?(:user_data) end |