Class: Google::Apis::DatamanagerV1::CustomVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Custom variable for ads conversions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomVariable

Returns a new instance of CustomVariable.



355
356
357
# File 'lib/google/apis/datamanager_v1/classes.rb', line 355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_referencesArray<String>

Optional. Reference string used to determine which of the Event. destination_references the custom variable should be sent to. If empty, the Event.destination_references will be used. Corresponds to the JSON property destinationReferences

Returns:

  • (Array<String>)


342
343
344
# File 'lib/google/apis/datamanager_v1/classes.rb', line 342

def destination_references
  @destination_references
end

#valueString

Optional. The value to store for the custom variable. Corresponds to the JSON property value

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/datamanager_v1/classes.rb', line 347

def value
  @value
end

#variableString

Optional. The name of the custom variable to set. If the variable is not found for the given destination, it will be ignored. Corresponds to the JSON property variable

Returns:

  • (String)


353
354
355
# File 'lib/google/apis/datamanager_v1/classes.rb', line 353

def variable
  @variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



360
361
362
363
364
# File 'lib/google/apis/datamanager_v1/classes.rb', line 360

def update!(**args)
  @destination_references = args[:destination_references] if args.key?(:destination_references)
  @value = args[:value] if args.key?(:value)
  @variable = args[:variable] if args.key?(:variable)
end