Class: Google::Apis::DatamanagerV1::DataManagerService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/datamanager_v1/service.rb

Overview

Data Manager API

A unified ingestion API for data partners, agencies and advertisers to connect first-party data across Google advertising products.

Examples:

require 'google/apis/datamanager_v1'

Datamanager = Google::Apis::DatamanagerV1 # Alias the module
service = Datamanager::DataManagerService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://datamanager.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeDataManagerService

Returns a new instance of DataManagerService.



48
49
50
51
52
53
# File 'lib/google/apis/datamanager_v1/service.rb', line 48

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-datamanager_v1',
        client_version: Google::Apis::DatamanagerV1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



41
42
43
# File 'lib/google/apis/datamanager_v1/service.rb', line 41

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



46
47
48
# File 'lib/google/apis/datamanager_v1/service.rb', line 46

def quota_user
  @quota_user
end

Instance Method Details

Creates a partner link for the given account. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/ loginAccountType/accounts/loginAccountId``

Parameters:

  • parent (String)

    Required. The parent, which owns this collection of partner links. Format: accountTypes/account_type/accounts/account

  • partner_link_object (Google::Apis::DatamanagerV1::PartnerLink) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



124
125
126
127
128
129
130
131
132
133
134
# File 'lib/google/apis/datamanager_v1/service.rb', line 124

def (parent, partner_link_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/partnerLinks', options)
  command.request_representation = Google::Apis::DatamanagerV1::PartnerLink::Representation
  command.request_object = partner_link_object
  command.response_representation = Google::Apis::DatamanagerV1::PartnerLink::Representation
  command.response_class = Google::Apis::DatamanagerV1::PartnerLink
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_account_type_account_user_list(parent, user_list_object = nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList

Creates a UserList. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/loginAccountId * linked-account: (Optional) The resource name of the account with an established product link to the login-account. Format: accountTypes/ linkedAccountType/accounts/linkedAccountId``

Parameters:

  • parent (String)

    Required. The parent account where this user list will be created. Format: accountTypes/account_type/accounts/account

  • user_list_object (Google::Apis::DatamanagerV1::UserList) (defaults to: nil)
  • validate_only (Boolean) (defaults to: nil)

    Optional. If true, the request is validated but not executed.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/google/apis/datamanager_v1/service.rb', line 638

def (parent, user_list_object = nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/userLists', options)
  command.request_representation = Google::Apis::DatamanagerV1::UserList::Representation
  command.request_object = user_list_object
  command.response_representation = Google::Apis::DatamanagerV1::UserList::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserList
  command.params['parent'] = parent unless parent.nil?
  command.query['validateOnly'] = validate_only unless validate_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_account_type_account_user_list_direct_license(parent, user_list_direct_license_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense

Creates a user list direct license. This feature is only available to data partners.

Parameters:

  • parent (String)

    Required. The account that owns the user list being licensed. Should be in the format accountTypes/ACCOUNT_TYPE/accounts/ACCOUNT_ID

  • user_list_direct_license_object (Google::Apis::DatamanagerV1::UserListDirectLicense) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



256
257
258
259
260
261
262
263
264
265
266
# File 'lib/google/apis/datamanager_v1/service.rb', line 256

def (parent, user_list_direct_license_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/userListDirectLicenses', options)
  command.request_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation
  command.request_object = user_list_direct_license_object
  command.response_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserListDirectLicense
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_account_type_account_user_list_global_license(parent, user_list_global_license_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense

Creates a user list global license. This feature is only available to data partners.

Parameters:

  • parent (String)

    Required. The account that owns the user list being licensed. Should be in the format accountTypes/ACCOUNT_TYPE/accounts/ACCOUNT_ID

  • user_list_global_license_object (Google::Apis::DatamanagerV1::UserListGlobalLicense) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



414
415
416
417
418
419
420
421
422
423
424
# File 'lib/google/apis/datamanager_v1/service.rb', line 414

def (parent, user_list_global_license_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/userListGlobalLicenses', options)
  command.request_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation
  command.request_object = user_list_global_license_object
  command.response_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserListGlobalLicense
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

Deletes a partner link for the given account. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/ loginAccountType/accounts/loginAccountId``

Parameters:

  • name (String)

    Required. The resource name of the partner link to delete. Format: accountTypes/account_type/accounts/account/partnerLinks/partner_link

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



162
163
164
165
166
167
168
169
170
# File 'lib/google/apis/datamanager_v1/service.rb', line 162

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DatamanagerV1::Empty::Representation
  command.response_class = Google::Apis::DatamanagerV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_account_type_account_user_list(name, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::Empty

Deletes a UserList. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/loginAccountId * linked-account: (Optional) The resource name of the account with an established product link to the login-account. Format: accountTypes/ linkedAccountType/accounts/linkedAccountId``

Parameters:

  • name (String)

    Required. The name of the user list to delete. Format: accountTypes/ account_type/accounts/account/userLists/user_list

  • validate_only (Boolean) (defaults to: nil)

    Optional. If true, the request is validated but not executed.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



681
682
683
684
685
686
687
688
689
690
# File 'lib/google/apis/datamanager_v1/service.rb', line 681

def (name, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DatamanagerV1::Empty::Representation
  command.response_class = Google::Apis::DatamanagerV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['validateOnly'] = validate_only unless validate_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_type_account_user_list(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList

Gets a UserList. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/loginAccountId * linked-account: (Optional) The resource name of the account with an established product link to the login-account. Format: accountTypes/ linkedAccountType/accounts/linkedAccountId``

Parameters:

  • name (String)

    Required. The resource name of the UserList to retrieve. Format: accountTypes/ account_type/accounts/account/userLists/user_list

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



720
721
722
723
724
725
726
727
728
# File 'lib/google/apis/datamanager_v1/service.rb', line 720

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DatamanagerV1::UserList::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserList
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_type_account_user_list_direct_license(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense

Retrieves a user list direct license. This feature is only available to data partners.

Parameters:

  • name (String)

    Required. The resource name of the user list direct license.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



289
290
291
292
293
294
295
296
297
# File 'lib/google/apis/datamanager_v1/service.rb', line 289

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserListDirectLicense
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_type_account_user_list_global_license(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense

Retrieves a user list global license. This feature is only available to data partners.

Parameters:

  • name (String)

    Required. The resource name of the user list global license.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



447
448
449
450
451
452
453
454
455
# File 'lib/google/apis/datamanager_v1/service.rb', line 447

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserListGlobalLicense
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#ingest_audience_members(ingest_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersResponse

Uploads a list of AudienceMember resources to the provided Destination.

Parameters:

  • ingest_audience_members_request_object (Google::Apis::DatamanagerV1::IngestAudienceMembersRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



855
856
857
858
859
860
861
862
863
864
# File 'lib/google/apis/datamanager_v1/service.rb', line 855

def ingest_audience_members(ingest_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/audienceMembers:ingest', options)
  command.request_representation = Google::Apis::DatamanagerV1::IngestAudienceMembersRequest::Representation
  command.request_object = ingest_audience_members_request_object
  command.response_representation = Google::Apis::DatamanagerV1::IngestAudienceMembersResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::IngestAudienceMembersResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#ingest_events(ingest_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::IngestEventsResponse

Uploads a list of Event resources from the provided Destination.

Parameters:

  • ingest_events_request_object (Google::Apis::DatamanagerV1::IngestEventsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



915
916
917
918
919
920
921
922
923
924
# File 'lib/google/apis/datamanager_v1/service.rb', line 915

def ingest_events(ingest_events_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/events:ingest', options)
  command.request_representation = Google::Apis::DatamanagerV1::IngestEventsRequest::Representation
  command.request_object = ingest_events_request_object
  command.response_representation = Google::Apis::DatamanagerV1::IngestEventsResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::IngestEventsResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_type_account_user_list_direct_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse

Lists all user list direct licenses owned by the parent account. This feature is only available to data partners.

Parameters:

  • parent (String)

    Required. The account whose licenses are being queried. Should be in the format accountTypes/ACCOUNT_TYPE/accounts/ACCOUNT_ID

  • filter (String) (defaults to: nil)

    Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case. Supported Operations: - AND - = - != - > - >= - < - <= Unsupported Fields: - name (use get method instead) - historical_pricings and all its subfields - pricing.start_time - pricing. end_time

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of licenses to return per page. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListUserListDirectLicense call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/google/apis/datamanager_v1/service.rb', line 340

def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/userListDirectLicenses', options)
  command.response_representation = Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_type_account_user_list_global_license_user_list_global_license_customer_infos(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse

Lists all customer info for a user list global license. This feature is only available to data partners.

Parameters:

  • parent (String)

    Required. The global license whose customer info are being queried. Should be in the format accountTypes/ACCOUNT_TYPE/accounts/ACCOUNT_ID/ userListGlobalLicenses/USER_LIST_GLOBAL_LICENSE_ID`. To list all global license customer info under an account, replace the user list global license id with a '-' (for example,accountTypes/DATA_PARTNER/accounts/123/ userListGlobalLicenses/-`)

  • filter (String) (defaults to: nil)

    Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case. Supported Operations: - AND - = - != - > - >= - < - <= Unsupported Fields: - name (use get method instead) - historical_pricings and all its subfields - pricing.start_time - pricing. end_time

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListUserListDirectLicense call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



594
595
596
597
598
599
600
601
602
603
604
605
# File 'lib/google/apis/datamanager_v1/service.rb', line 594

def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/userListGlobalLicenseCustomerInfos', options)
  command.response_representation = Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_type_account_user_list_global_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse

Lists all user list global licenses owned by the parent account. This feature is only available to data partners.

Parameters:

  • parent (String)

    Required. The account whose licenses are being queried. Should be in the format accountTypes/ACCOUNT_TYPE/accounts/ACCOUNT_ID

  • filter (String) (defaults to: nil)

    Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case. Supported Operations: - AND - = - != - > - >= - < - <= Unsupported Fields: - name (use get method instead) - historical_pricings and all its subfields - pricing.start_time - pricing. end_time

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListUserListGlobalLicense call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/google/apis/datamanager_v1/service.rb', line 498

def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/userListGlobalLicenses', options)
  command.response_representation = Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_type_account_user_lists(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListsResponse

Lists UserLists. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/loginAccountId * linked-account: (Optional) The resource name of the account with an established product link to the login-account. Format: accountTypes/ linkedAccountType/accounts/linkedAccountId``

Parameters:

  • parent (String)

    Required. The parent account which owns this collection of user lists. Format: accountTypes/account_type/accounts/account

  • filter (String) (defaults to: nil)

    Optional. A filter string. All fields need to be on the left hand side of each condition (for example: display_name = "list 1" ). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case. Supported operations: - AND - = - != - > - >= - < - <= - : (has) Supported fields: - id - display_name - description - membership_status

    • integration_code - access_reason - ingested_user_list_info. upload_key_types
  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of user lists to return. The service may return fewer than this value. If unspecified, at most 50 user lists will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListUserLists call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListUserLists must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/google/apis/datamanager_v1/service.rb', line 776

def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/userLists', options)
  command.response_representation = Google::Apis::DatamanagerV1::ListUserListsResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::ListUserListsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_type_account_user_list(name, user_list_object = nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList

Updates a UserList. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/loginAccountId * linked-account: (Optional) The resource name of the account with an established product link to the login-account. Format: accountTypes/ linkedAccountType/accounts/linkedAccountId``

Parameters:

  • name (String)

    Identifier. The resource name of the user list. Format: accountTypes/ account_type/accounts/account/userLists/user_list

  • user_list_object (Google::Apis::DatamanagerV1::UserList) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update.

  • validate_only (Boolean) (defaults to: nil)

    Optional. If true, the request is validated but not executed.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



822
823
824
825
826
827
828
829
830
831
832
833
834
# File 'lib/google/apis/datamanager_v1/service.rb', line 822

def (name, user_list_object = nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::DatamanagerV1::UserList::Representation
  command.request_object = user_list_object
  command.response_representation = Google::Apis::DatamanagerV1::UserList::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserList
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['validateOnly'] = validate_only unless validate_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_type_account_user_list_direct_license(name, user_list_direct_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense

Updates a user list direct license. This feature is only available to data partners.

Parameters:

  • name (String)

    Identifier. The resource name of the user list direct license.

  • user_list_direct_license_object (Google::Apis::DatamanagerV1::UserListDirectLicense) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update. The special character * is not supported and an INVALID_UPDATE_MASK error will be thrown if used.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/google/apis/datamanager_v1/service.rb', line 378

def (name, user_list_direct_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation
  command.request_object = user_list_direct_license_object
  command.response_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserListDirectLicense
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_type_account_user_list_global_license(name, user_list_global_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense

Updates a user list global license. This feature is only available to data partners.

Parameters:

  • name (String)

    Identifier. The resource name of the user list global license.

  • user_list_global_license_object (Google::Apis::DatamanagerV1::UserListGlobalLicense) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update. The special character * is not supported and an INVALID_UPDATE_MASK error will be thrown if used.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/google/apis/datamanager_v1/service.rb', line 536

def (name, user_list_global_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation
  command.request_object = user_list_global_license_object
  command.response_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation
  command.response_class = Google::Apis::DatamanagerV1::UserListGlobalLicense
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#remove_audience_members(remove_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse

Removes a list of AudienceMember resources from the provided Destination.

Parameters:

  • remove_audience_members_request_object (Google::Apis::DatamanagerV1::RemoveAudienceMembersRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



885
886
887
888
889
890
891
892
893
894
# File 'lib/google/apis/datamanager_v1/service.rb', line 885

def remove_audience_members(remove_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/audienceMembers:remove', options)
  command.request_representation = Google::Apis::DatamanagerV1::RemoveAudienceMembersRequest::Representation
  command.request_object = remove_audience_members_request_object
  command.response_representation = Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#retrieve_insights(parent, retrieve_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RetrieveInsightsResponse

Retrieves marketing data insights for a given user list. This feature is only available to data partners. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/ loginAccountId* `linked-account`: (Optional) The resource name of the account with an established product link to the `login-account`. Format: ` accountTypes/`linkedAccountType`/accounts/`linkedAccountId

Parameters:

  • parent (String)

    Required. The parent account that owns the user list. Format: accountTypes/ account_type/accounts/account``

  • retrieve_insights_request_object (Google::Apis::DatamanagerV1::RetrieveInsightsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/google/apis/datamanager_v1/service.rb', line 85

def retrieve_insights(parent, retrieve_insights_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/insights:retrieve', options)
  command.request_representation = Google::Apis::DatamanagerV1::RetrieveInsightsRequest::Representation
  command.request_object = retrieve_insights_request_object
  command.response_representation = Google::Apis::DatamanagerV1::RetrieveInsightsResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::RetrieveInsightsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#retrieve_request_status(request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse

Gets the status of a request given request id.

Parameters:

  • request_id (String) (defaults to: nil)

    Required. Required. The request ID of the Data Manager API request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



946
947
948
949
950
951
952
953
954
# File 'lib/google/apis/datamanager_v1/service.rb', line 946

def retrieve_request_status(request_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/requestStatus:retrieve', options)
  command.response_representation = Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse
  command.query['requestId'] = request_id unless request_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

Searches for all partner links to and from a given account. Authorization Headers: This method supports the following optional headers to define how the API authorizes access for the request: * login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/loginAccountType/accounts/loginAccountId``

Parameters:

  • parent (String)

    Required. Account to search for partner links. If no filter is specified, all partner links where this account is either the owning_account or partner_account are returned. Format: accountTypes/account_type/accounts/ account``

  • filter (String) (defaults to: nil)

    Optional. A filter string. All fields need to be on the left hand side of each condition (for example: partner_link_id = 123456789). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case. Supported operations: - AND - = - != Supported fields: - partner_link_id - owning_account.account_type - owning_account.account_id

    • partner_account.account_type - partner_account.account_id Example: owning_account.account_type = "GOOGLE_ADS" AND partner_account.account_id = 987654321
  • page_size (Fixnum) (defaults to: nil)

    The maximum number of partner links to return. The service may return fewer than this value. If unspecified, at most 10 partner links will be returned. The maximum value is 100; values above 100 will be coerced to 100.

  • page_token (String) (defaults to: nil)

    A page token, received from a previous SearchPartnerLinks call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to SearchPartnerLinks must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/google/apis/datamanager_v1/service.rb', line 220

def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/partnerLinks:search', options)
  command.response_representation = Google::Apis::DatamanagerV1::SearchPartnerLinksResponse::Representation
  command.response_class = Google::Apis::DatamanagerV1::SearchPartnerLinksResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end