Class: Google::Apis::DatamanagerV1::DataManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DatamanagerV1::DataManagerService
- Defined in:
- lib/google/apis/datamanager_v1/service.rb
Overview
Data Manager API
A unified ingestion API for data partners, agencies and advertisers to connect first-party data across Google advertising products.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://datamanager.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_account_type_account_partner_link(parent, partner_link_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::PartnerLink
Creates a partner link for the given account.
-
#create_account_type_account_user_list(parent, user_list_object = nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList
Creates a UserList.
-
#create_account_type_account_user_list_direct_license(parent, user_list_direct_license_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense
Creates a user list direct license.
-
#create_account_type_account_user_list_global_license(parent, user_list_global_license_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense
Creates a user list global license.
-
#delete_account_type_account_partner_link(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::Empty
Deletes a partner link for the given account.
-
#delete_account_type_account_user_list(name, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::Empty
Deletes a UserList.
-
#get_account_type_account_user_list(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList
Gets a UserList.
-
#get_account_type_account_user_list_direct_license(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense
Retrieves a user list direct license.
-
#get_account_type_account_user_list_global_license(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense
Retrieves a user list global license.
-
#ingest_audience_members(ingest_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersResponse
Uploads a list of AudienceMember resources to the provided Destination.
-
#ingest_events(ingest_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::IngestEventsResponse
Uploads a list of Event resources from the provided Destination.
-
#initialize ⇒ DataManagerService
constructor
A new instance of DataManagerService.
-
#list_account_type_account_user_list_direct_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse
Lists all user list direct licenses owned by the parent account.
-
#list_account_type_account_user_list_global_license_user_list_global_license_customer_infos(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse
Lists all customer info for a user list global license.
-
#list_account_type_account_user_list_global_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse
Lists all user list global licenses owned by the parent account.
-
#list_account_type_account_user_lists(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListsResponse
Lists UserLists.
-
#patch_account_type_account_user_list(name, user_list_object = nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList
Updates a UserList.
-
#patch_account_type_account_user_list_direct_license(name, user_list_direct_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense
Updates a user list direct license.
-
#patch_account_type_account_user_list_global_license(name, user_list_global_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense
Updates a user list global license.
-
#remove_audience_members(remove_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse
Removes a list of AudienceMember resources from the provided Destination.
-
#retrieve_insights(parent, retrieve_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RetrieveInsightsResponse
Retrieves marketing data insights for a given user list.
-
#retrieve_request_status(request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse
Gets the status of a request given request id.
-
#search_account_type_account_partner_links(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::SearchPartnerLinksResponse
Searches for all partner links to and from a given account.
Constructor Details
#initialize ⇒ DataManagerService
Returns a new instance of DataManagerService.
48 49 50 51 52 53 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-datamanager_v1', client_version: Google::Apis::DatamanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_account_type_account_partner_link(parent, partner_link_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::PartnerLink
Creates a partner link for the given account. Authorization Headers: This
method supports the following optional headers to define how the API
authorizes access for the request: * login-account: (Optional) The resource
name of the account where the Google Account of the credentials is a user. If
not set, defaults to the account of the request. Format: accountTypes/
loginAccountType/accounts/loginAccountId``
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 124 def create_account_type_account_partner_link(parent, partner_link_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/partnerLinks', ) command.request_representation = Google::Apis::DatamanagerV1::PartnerLink::Representation command.request_object = partner_link_object command.response_representation = Google::Apis::DatamanagerV1::PartnerLink::Representation command.response_class = Google::Apis::DatamanagerV1::PartnerLink command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_account_type_account_user_list(parent, user_list_object = nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList
Creates a UserList. Authorization Headers: This method supports the following
optional headers to define how the API authorizes access for the request: *
login-account: (Optional) The resource name of the account where the Google
Account of the credentials is a user. If not set, defaults to the account of
the request. Format: accountTypes/loginAccountType/accounts/loginAccountId
* linked-account: (Optional) The resource name of the account with an
established product link to the login-account. Format: accountTypes/
linkedAccountType/accounts/linkedAccountId``
638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 638 def create_account_type_account_user_list(parent, user_list_object = nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/userLists', ) command.request_representation = Google::Apis::DatamanagerV1::UserList::Representation command.request_object = user_list_object command.response_representation = Google::Apis::DatamanagerV1::UserList::Representation command.response_class = Google::Apis::DatamanagerV1::UserList command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_account_type_account_user_list_direct_license(parent, user_list_direct_license_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense
Creates a user list direct license. This feature is only available to data partners.
256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 256 def create_account_type_account_user_list_direct_license(parent, user_list_direct_license_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/userListDirectLicenses', ) command.request_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation command.request_object = user_list_direct_license_object command.response_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation command.response_class = Google::Apis::DatamanagerV1::UserListDirectLicense command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_account_type_account_user_list_global_license(parent, user_list_global_license_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense
Creates a user list global license. This feature is only available to data partners.
414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 414 def create_account_type_account_user_list_global_license(parent, user_list_global_license_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/userListGlobalLicenses', ) command.request_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation command.request_object = user_list_global_license_object command.response_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation command.response_class = Google::Apis::DatamanagerV1::UserListGlobalLicense command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_account_type_account_partner_link(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::Empty
Deletes a partner link for the given account. Authorization Headers: This
method supports the following optional headers to define how the API
authorizes access for the request: * login-account: (Optional) The resource
name of the account where the Google Account of the credentials is a user. If
not set, defaults to the account of the request. Format: accountTypes/
loginAccountType/accounts/loginAccountId``
162 163 164 165 166 167 168 169 170 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 162 def delete_account_type_account_partner_link(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatamanagerV1::Empty::Representation command.response_class = Google::Apis::DatamanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_account_type_account_user_list(name, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::Empty
Deletes a UserList. Authorization Headers: This method supports the following
optional headers to define how the API authorizes access for the request: *
login-account: (Optional) The resource name of the account where the Google
Account of the credentials is a user. If not set, defaults to the account of
the request. Format: accountTypes/loginAccountType/accounts/loginAccountId
* linked-account: (Optional) The resource name of the account with an
established product link to the login-account. Format: accountTypes/
linkedAccountType/accounts/linkedAccountId``
681 682 683 684 685 686 687 688 689 690 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 681 def delete_account_type_account_user_list(name, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatamanagerV1::Empty::Representation command.response_class = Google::Apis::DatamanagerV1::Empty command.params['name'] = name unless name.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_account_type_account_user_list(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList
Gets a UserList. Authorization Headers: This method supports the following
optional headers to define how the API authorizes access for the request: *
login-account: (Optional) The resource name of the account where the Google
Account of the credentials is a user. If not set, defaults to the account of
the request. Format: accountTypes/loginAccountType/accounts/loginAccountId
* linked-account: (Optional) The resource name of the account with an
established product link to the login-account. Format: accountTypes/
linkedAccountType/accounts/linkedAccountId``
720 721 722 723 724 725 726 727 728 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 720 def get_account_type_account_user_list(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatamanagerV1::UserList::Representation command.response_class = Google::Apis::DatamanagerV1::UserList command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_account_type_account_user_list_direct_license(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense
Retrieves a user list direct license. This feature is only available to data partners.
289 290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 289 def get_account_type_account_user_list_direct_license(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation command.response_class = Google::Apis::DatamanagerV1::UserListDirectLicense command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_account_type_account_user_list_global_license(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense
Retrieves a user list global license. This feature is only available to data partners.
447 448 449 450 451 452 453 454 455 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 447 def get_account_type_account_user_list_global_license(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation command.response_class = Google::Apis::DatamanagerV1::UserListGlobalLicense command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#ingest_audience_members(ingest_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersResponse
Uploads a list of AudienceMember resources to the provided Destination.
855 856 857 858 859 860 861 862 863 864 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 855 def ingest_audience_members(ingest_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/audienceMembers:ingest', ) command.request_representation = Google::Apis::DatamanagerV1::IngestAudienceMembersRequest::Representation command.request_object = ingest_audience_members_request_object command.response_representation = Google::Apis::DatamanagerV1::IngestAudienceMembersResponse::Representation command.response_class = Google::Apis::DatamanagerV1::IngestAudienceMembersResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#ingest_events(ingest_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::IngestEventsResponse
Uploads a list of Event resources from the provided Destination.
915 916 917 918 919 920 921 922 923 924 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 915 def ingest_events(ingest_events_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/events:ingest', ) command.request_representation = Google::Apis::DatamanagerV1::IngestEventsRequest::Representation command.request_object = ingest_events_request_object command.response_representation = Google::Apis::DatamanagerV1::IngestEventsResponse::Representation command.response_class = Google::Apis::DatamanagerV1::IngestEventsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_account_type_account_user_list_direct_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse
Lists all user list direct licenses owned by the parent account. This feature is only available to data partners.
340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 340 def list_account_type_account_user_list_direct_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/userListDirectLicenses', ) command.response_representation = Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse::Representation command.response_class = Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_account_type_account_user_list_global_license_user_list_global_license_customer_infos(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse
Lists all customer info for a user list global license. This feature is only available to data partners.
594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 594 def list_account_type_account_user_list_global_license_user_list_global_license_customer_infos(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/userListGlobalLicenseCustomerInfos', ) command.response_representation = Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse::Representation command.response_class = Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_account_type_account_user_list_global_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse
Lists all user list global licenses owned by the parent account. This feature is only available to data partners.
498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 498 def list_account_type_account_user_list_global_licenses(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/userListGlobalLicenses', ) command.response_representation = Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse::Representation command.response_class = Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_account_type_account_user_lists(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::ListUserListsResponse
Lists UserLists. Authorization Headers: This method supports the following
optional headers to define how the API authorizes access for the request: *
login-account: (Optional) The resource name of the account where the Google
Account of the credentials is a user. If not set, defaults to the account of
the request. Format: accountTypes/loginAccountType/accounts/loginAccountId
* linked-account: (Optional) The resource name of the account with an
established product link to the login-account. Format: accountTypes/
linkedAccountType/accounts/linkedAccountId``
776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 776 def list_account_type_account_user_lists(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/userLists', ) command.response_representation = Google::Apis::DatamanagerV1::ListUserListsResponse::Representation command.response_class = Google::Apis::DatamanagerV1::ListUserListsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_account_type_account_user_list(name, user_list_object = nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserList
Updates a UserList. Authorization Headers: This method supports the following
optional headers to define how the API authorizes access for the request: *
login-account: (Optional) The resource name of the account where the Google
Account of the credentials is a user. If not set, defaults to the account of
the request. Format: accountTypes/loginAccountType/accounts/loginAccountId
* linked-account: (Optional) The resource name of the account with an
established product link to the login-account. Format: accountTypes/
linkedAccountType/accounts/linkedAccountId``
822 823 824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 822 def patch_account_type_account_user_list(name, user_list_object = nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatamanagerV1::UserList::Representation command.request_object = user_list_object command.response_representation = Google::Apis::DatamanagerV1::UserList::Representation command.response_class = Google::Apis::DatamanagerV1::UserList command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_account_type_account_user_list_direct_license(name, user_list_direct_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListDirectLicense
Updates a user list direct license. This feature is only available to data partners.
378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 378 def patch_account_type_account_user_list_direct_license(name, user_list_direct_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation command.request_object = user_list_direct_license_object command.response_representation = Google::Apis::DatamanagerV1::UserListDirectLicense::Representation command.response_class = Google::Apis::DatamanagerV1::UserListDirectLicense command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_account_type_account_user_list_global_license(name, user_list_global_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::UserListGlobalLicense
Updates a user list global license. This feature is only available to data partners.
536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 536 def patch_account_type_account_user_list_global_license(name, user_list_global_license_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation command.request_object = user_list_global_license_object command.response_representation = Google::Apis::DatamanagerV1::UserListGlobalLicense::Representation command.response_class = Google::Apis::DatamanagerV1::UserListGlobalLicense command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_audience_members(remove_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse
Removes a list of AudienceMember resources from the provided Destination.
885 886 887 888 889 890 891 892 893 894 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 885 def remove_audience_members(remove_audience_members_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/audienceMembers:remove', ) command.request_representation = Google::Apis::DatamanagerV1::RemoveAudienceMembersRequest::Representation command.request_object = remove_audience_members_request_object command.response_representation = Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse::Representation command.response_class = Google::Apis::DatamanagerV1::RemoveAudienceMembersResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_insights(parent, retrieve_insights_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RetrieveInsightsResponse
Retrieves marketing data insights for a given user list. This feature is only
available to data partners. Authorization Headers: This method supports the
following optional headers to define how the API authorizes access for the
request: * login-account: (Optional) The resource name of the account where
the Google Account of the credentials is a user. If not set, defaults to the
account of the request. Format: accountTypes/loginAccountType/accounts/
loginAccountId* `linked-account`: (Optional) The resource name of the
account with an established product link to the `login-account`. Format: `
accountTypes/`linkedAccountType`/accounts/`linkedAccountId
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 85 def retrieve_insights(parent, retrieve_insights_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/insights:retrieve', ) command.request_representation = Google::Apis::DatamanagerV1::RetrieveInsightsRequest::Representation command.request_object = retrieve_insights_request_object command.response_representation = Google::Apis::DatamanagerV1::RetrieveInsightsResponse::Representation command.response_class = Google::Apis::DatamanagerV1::RetrieveInsightsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_request_status(request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse
Gets the status of a request given request id.
946 947 948 949 950 951 952 953 954 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 946 def retrieve_request_status(request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/requestStatus:retrieve', ) command.response_representation = Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse::Representation command.response_class = Google::Apis::DatamanagerV1::RetrieveRequestStatusResponse command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_account_type_account_partner_links(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatamanagerV1::SearchPartnerLinksResponse
Searches for all partner links to and from a given account. Authorization
Headers: This method supports the following optional headers to define how the
API authorizes access for the request: * login-account: (Optional) The
resource name of the account where the Google Account of the credentials is a
user. If not set, defaults to the account of the request. Format:
accountTypes/loginAccountType/accounts/loginAccountId``
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/datamanager_v1/service.rb', line 220 def search_account_type_account_partner_links(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/partnerLinks:search', ) command.response_representation = Google::Apis::DatamanagerV1::SearchPartnerLinksResponse::Representation command.response_class = Google::Apis::DatamanagerV1::SearchPartnerLinksResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |