Class: Google::Apis::DatamanagerV1::Destination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The Google product you're sending data to. For example, a Google Ads account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Destination

Returns a new instance of Destination.



736
737
738
# File 'lib/google/apis/datamanager_v1/classes.rb', line 736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#linked_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property linkedAccount



710
711
712
# File 'lib/google/apis/datamanager_v1/classes.rb', line 710

def 
  @linked_account
end

#login_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property loginAccount



715
716
717
# File 'lib/google/apis/datamanager_v1/classes.rb', line 715

def 
  @login_account
end

#operating_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property operatingAccount



720
721
722
# File 'lib/google/apis/datamanager_v1/classes.rb', line 720

def 
  @operating_account
end

#product_destination_idString

Required. The object within the product account to ingest into. For example, a Google Ads audience ID, a Display & Video 360 audience ID or a Google Ads conversion action ID. Corresponds to the JSON property productDestinationId

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/datamanager_v1/classes.rb', line 727

def product_destination_id
  @product_destination_id
end

#referenceString

Optional. ID for this Destination resource, unique within the request. Use to reference this Destination in the IngestEventsRequest and IngestAudienceMembersRequest. Corresponds to the JSON property reference

Returns:

  • (String)


734
735
736
# File 'lib/google/apis/datamanager_v1/classes.rb', line 734

def reference
  @reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



741
742
743
744
745
746
747
# File 'lib/google/apis/datamanager_v1/classes.rb', line 741

def update!(**args)
  @linked_account = args[:linked_account] if args.key?(:linked_account)
  @login_account = args[:login_account] if args.key?(:login_account)
  @operating_account = args[:operating_account] if args.key?(:operating_account)
  @product_destination_id = args[:product_destination_id] if args.key?(:product_destination_id)
  @reference = args[:reference] if args.key?(:reference)
end