Class: Google::Apis::DatamanagerV1::Destination
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::Destination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The Google product you're sending data to. For example, a Google Ads account.
Instance Attribute Summary collapse
-
#linked_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
-
#login_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
-
#operating_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
-
#product_destination_id ⇒ String
Required.
-
#reference ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Destination
constructor
A new instance of Destination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Destination
Returns a new instance of Destination.
400 401 402 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#linked_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
Corresponds to the JSON property linkedAccount
374 375 376 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 374 def linked_account @linked_account end |
#login_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
Corresponds to the JSON property loginAccount
379 380 381 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 379 def login_account @login_account end |
#operating_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
Corresponds to the JSON property operatingAccount
384 385 386 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 384 def @operating_account end |
#product_destination_id ⇒ String
Required. The object within the product account to ingest into. For example, a
Google Ads audience ID, a Display & Video 360 audience ID or a Google Ads
conversion action ID.
Corresponds to the JSON property productDestinationId
391 392 393 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 391 def product_destination_id @product_destination_id end |
#reference ⇒ String
Optional. ID for this Destination resource, unique within the request. Use
to reference this Destination in the IngestEventsRequest and
IngestAudienceMembersRequest.
Corresponds to the JSON property reference
398 399 400 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 398 def reference @reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
405 406 407 408 409 410 411 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 405 def update!(**args) @linked_account = args[:linked_account] if args.key?(:linked_account) @login_account = args[:login_account] if args.key?(:login_account) @operating_account = args[:operating_account] if args.key?(:operating_account) @product_destination_id = args[:product_destination_id] if args.key?(:product_destination_id) @reference = args[:reference] if args.key?(:reference) end |