Class: Google::Apis::DatamanagerV1::DeviceInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::DeviceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Information about the device being used (if any) when the event happened.
Instance Attribute Summary collapse
-
#brand ⇒ String
Optional.
-
#browser ⇒ String
Optional.
-
#browser_version ⇒ String
Optional.
-
#category ⇒ String
Optional.
-
#ip_address ⇒ String
Optional.
-
#language_code ⇒ String
Optional.
-
#model ⇒ String
Optional.
-
#operating_system ⇒ String
Optional.
-
#operating_system_version ⇒ String
Optional.
-
#screen_height ⇒ Fixnum
Optional.
-
#screen_width ⇒ Fixnum
Optional.
-
#user_agent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceInfo
constructor
A new instance of DeviceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceInfo
Returns a new instance of DeviceInfo.
856 857 858 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brand ⇒ String
Optional. The brand of the device.
Corresponds to the JSON property brand
797 798 799 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 797 def brand @brand end |
#browser ⇒ String
Optional. The brand or type of the browser.
Corresponds to the JSON property browser
802 803 804 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 802 def browser @browser end |
#browser_version ⇒ String
Optional. The version of the browser.
Corresponds to the JSON property browserVersion
807 808 809 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 807 def browser_version @browser_version end |
#category ⇒ String
Optional. The category of device. For example, “desktop”, “tablet”, “mobile”, “
smart TV”.
Corresponds to the JSON property category
813 814 815 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 813 def category @category end |
#ip_address ⇒ String
Optional. The IP address of the device for the given context. Required when
used in an AdEvent.
Corresponds to the JSON property ipAddress
819 820 821 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 819 def ip_address @ip_address end |
#language_code ⇒ String
Optional. The language the device uses in ISO 639-1 format.
Corresponds to the JSON property languageCode
824 825 826 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 824 def language_code @language_code end |
#model ⇒ String
Optional. The model of the device.
Corresponds to the JSON property model
829 830 831 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 829 def model @model end |
#operating_system ⇒ String
Optional. The operating system or platform of the device.
Corresponds to the JSON property operatingSystem
834 835 836 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 834 def @operating_system end |
#operating_system_version ⇒ String
Optional. The version of the operating system or platform.
Corresponds to the JSON property operatingSystemVersion
839 840 841 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 839 def @operating_system_version end |
#screen_height ⇒ Fixnum
Optional. The height of the screen in pixels.
Corresponds to the JSON property screenHeight
844 845 846 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 844 def screen_height @screen_height end |
#screen_width ⇒ Fixnum
Optional. The width of the screen in pixels.
Corresponds to the JSON property screenWidth
849 850 851 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 849 def screen_width @screen_width end |
#user_agent ⇒ String
Optional. The user-agent string of the device for the given context.
Corresponds to the JSON property userAgent
854 855 856 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 854 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 861 def update!(**args) @brand = args[:brand] if args.key?(:brand) @browser = args[:browser] if args.key?(:browser) @browser_version = args[:browser_version] if args.key?(:browser_version) @category = args[:category] if args.key?(:category) @ip_address = args[:ip_address] if args.key?(:ip_address) @language_code = args[:language_code] if args.key?(:language_code) @model = args[:model] if args.key?(:model) @operating_system = args[:operating_system] if args.key?(:operating_system) @operating_system_version = args[:operating_system_version] if args.key?(:operating_system_version) @screen_height = args[:screen_height] if args.key?(:screen_height) @screen_width = args[:screen_width] if args.key?(:screen_width) @user_agent = args[:user_agent] if args.key?(:user_agent) end |