Class: Google::Apis::DatamanagerV1::DeviceInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::DeviceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Information about the device being used (if any) when the event happened.
Instance Attribute Summary collapse
-
#brand ⇒ String
Optional.
-
#browser ⇒ String
Optional.
-
#browser_version ⇒ String
Optional.
-
#category ⇒ String
Optional.
-
#ip_address ⇒ String
Optional.
-
#language_code ⇒ String
Optional.
-
#model ⇒ String
Optional.
-
#operating_system ⇒ String
Optional.
-
#operating_system_version ⇒ String
Optional.
-
#screen_height ⇒ Fixnum
Optional.
-
#screen_width ⇒ Fixnum
Optional.
-
#user_agent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceInfo
constructor
A new instance of DeviceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceInfo
Returns a new instance of DeviceInfo.
823 824 825 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brand ⇒ String
Optional. The brand of the device.
Corresponds to the JSON property brand
757 758 759 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 757 def brand @brand end |
#browser ⇒ String
Optional. The brand or type of the browser.
Corresponds to the JSON property browser
762 763 764 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 762 def browser @browser end |
#browser_version ⇒ String
Optional. The version of the browser.
Corresponds to the JSON property browserVersion
767 768 769 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 767 def browser_version @browser_version end |
#category ⇒ String
Optional. The category of device. For example, “desktop”, “tablet”, “mobile”, “
smart TV”.
Corresponds to the JSON property category
773 774 775 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 773 def category @category end |
#ip_address ⇒ String
Optional. The IP address of the device for the given context. Note: Google
Ads does not support IP address matching for end users in the European
Economic Area (EEA), United Kingdom (UK), or Switzerland (CH). Add logic to
conditionally exclude sharing IP addresses from users from these regions and
ensure that you provide users with clear and comprehensive information about
the data you collect on your sites, apps, and other properties and get consent
where required by law or any applicable Google policies. See the About
offline conversion imports page for more details.
Corresponds to the JSON property ipAddress
786 787 788 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 786 def ip_address @ip_address end |
#language_code ⇒ String
Optional. The language the device uses in ISO 639-1 format.
Corresponds to the JSON property languageCode
791 792 793 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 791 def language_code @language_code end |
#model ⇒ String
Optional. The model of the device.
Corresponds to the JSON property model
796 797 798 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 796 def model @model end |
#operating_system ⇒ String
Optional. The operating system or platform of the device.
Corresponds to the JSON property operatingSystem
801 802 803 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 801 def @operating_system end |
#operating_system_version ⇒ String
Optional. The version of the operating system or platform.
Corresponds to the JSON property operatingSystemVersion
806 807 808 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 806 def @operating_system_version end |
#screen_height ⇒ Fixnum
Optional. The height of the screen in pixels.
Corresponds to the JSON property screenHeight
811 812 813 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 811 def screen_height @screen_height end |
#screen_width ⇒ Fixnum
Optional. The width of the screen in pixels.
Corresponds to the JSON property screenWidth
816 817 818 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 816 def screen_width @screen_width end |
#user_agent ⇒ String
Optional. The user-agent string of the device for the given context.
Corresponds to the JSON property userAgent
821 822 823 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 821 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
828 829 830 831 832 833 834 835 836 837 838 839 840 841 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 828 def update!(**args) @brand = args[:brand] if args.key?(:brand) @browser = args[:browser] if args.key?(:browser) @browser_version = args[:browser_version] if args.key?(:browser_version) @category = args[:category] if args.key?(:category) @ip_address = args[:ip_address] if args.key?(:ip_address) @language_code = args[:language_code] if args.key?(:language_code) @model = args[:model] if args.key?(:model) @operating_system = args[:operating_system] if args.key?(:operating_system) @operating_system_version = args[:operating_system_version] if args.key?(:operating_system_version) @screen_height = args[:screen_height] if args.key?(:screen_height) @screen_width = args[:screen_width] if args.key?(:screen_width) @user_agent = args[:user_agent] if args.key?(:user_agent) end |