Class: Google::Apis::DatamanagerV1::DeviceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Information about the device being used (if any) when the event happened.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceInfo

Returns a new instance of DeviceInfo.



436
437
438
# File 'lib/google/apis/datamanager_v1/classes.rb', line 436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

Optional. The IP address of the device for the given context. Note: Google Ads does not support IP address matching for end users in the European Economic Area (EEA), United Kingdom (UK), or Switzerland (CH). Add logic to conditionally exclude sharing IP addresses from users from these regions and ensure that you provide users with clear and comprehensive information about the data you collect on your sites, apps, and other properties and get consent where required by law or any applicable Google policies. See the About offline conversion imports page for more details. Corresponds to the JSON property ipAddress

Returns:

  • (String)


429
430
431
# File 'lib/google/apis/datamanager_v1/classes.rb', line 429

def ip_address
  @ip_address
end

#user_agentString

Optional. The user-agent string of the device for the given context. Corresponds to the JSON property userAgent

Returns:

  • (String)


434
435
436
# File 'lib/google/apis/datamanager_v1/classes.rb', line 434

def user_agent
  @user_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



441
442
443
444
# File 'lib/google/apis/datamanager_v1/classes.rb', line 441

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
end