Class: Google::Apis::DatamanagerV1::EncryptedUserId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user identifier issued to be used for attribution. All fields are required if this is used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptedUserId

Returns a new instance of EncryptedUserId.



888
889
890
# File 'lib/google/apis/datamanager_v1/classes.rb', line 888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_idString

Required. The alphanumeric encrypted id. Corresponds to the JSON property encryptedId

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/datamanager_v1/classes.rb', line 868

def encrypted_id
  @encrypted_id
end

#entity_idFixnum

Required. The encryption entity ID. This should match the encryption configuration for ad serving or Data Transfer. Corresponds to the JSON property entityId

Returns:

  • (Fixnum)


874
875
876
# File 'lib/google/apis/datamanager_v1/classes.rb', line 874

def entity_id
  @entity_id
end

#entity_typeString

Required. The encryption entity type. This should match the encryption configuration for ad serving or Data Transfer. Corresponds to the JSON property entityType

Returns:

  • (String)


880
881
882
# File 'lib/google/apis/datamanager_v1/classes.rb', line 880

def entity_type
  @entity_type
end

#sourceString

Required. Describes whether the encrypted cookie was received from ad serving ( the %m macro) or from Data Transfer. Corresponds to the JSON property source

Returns:

  • (String)


886
887
888
# File 'lib/google/apis/datamanager_v1/classes.rb', line 886

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



893
894
895
896
897
898
# File 'lib/google/apis/datamanager_v1/classes.rb', line 893

def update!(**args)
  @encrypted_id = args[:encrypted_id] if args.key?(:encrypted_id)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @source = args[:source] if args.key?(:source)
end