Class: Google::Apis::DatamanagerV1::ErrorCount
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::ErrorCount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The error count for a given error reason.
Instance Attribute Summary collapse
-
#reason ⇒ String
The error reason of the failed records.
-
#record_count ⇒ Fixnum
The count of records that failed to upload for a given reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorCount
constructor
A new instance of ErrorCount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorCount
Returns a new instance of ErrorCount.
579 580 581 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
The error reason of the failed records.
Corresponds to the JSON property reason
572 573 574 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 572 def reason @reason end |
#record_count ⇒ Fixnum
The count of records that failed to upload for a given reason.
Corresponds to the JSON property recordCount
577 578 579 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 577 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
584 585 586 587 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 584 def update!(**args) @reason = args[:reason] if args.key?(:reason) @record_count = args[:record_count] if args.key?(:record_count) end |