Class: Google::Apis::DatamanagerV1::Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

An event representing a user interaction with an advertiser's website or app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Event

Returns a new instance of Event.



1151
1152
1153
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_identifiersGoogle::Apis::DatamanagerV1::AdIdentifiers

Identifiers and other information used to match the conversion event with other online activity (such as ad clicks). Corresponds to the JSON property adIdentifiers



1025
1026
1027
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1025

def ad_identifiers
  @ad_identifiers
end

#additional_event_parametersArray<Google::Apis::DatamanagerV1::EventParameter>

Optional. A bucket of any event parameters to be included within the event that were not already specified using other structured fields. Corresponds to the JSON property additionalEventParameters



1032
1033
1034
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1032

def additional_event_parameters
  @additional_event_parameters
end

#app_instance_idString

Optional. A unique identifier for the user instance of an app client for this GA4 app stream. Corresponds to the JSON property appInstanceId

Returns:

  • (String)


1038
1039
1040
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1038

def app_instance_id
  @app_instance_id
end

#cart_dataGoogle::Apis::DatamanagerV1::CartData

The cart data associated with the event. Corresponds to the JSON property cartData



1043
1044
1045
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1043

def cart_data
  @cart_data
end

#client_idString

Optional. A unique identifier for the user instance of a web client for this GA4 web stream. Corresponds to the JSON property clientId

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1049

def client_id
  @client_id
end

Digital Markets Act (DMA) consent settings for the user. Corresponds to the JSON property consent



1055
1056
1057
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1055

def consent
  @consent
end

#conversion_countFloat

Optional. The conversion quantity associated with the event, for counting- based conversions. Corresponds to the JSON property conversionCount

Returns:

  • (Float)


1061
1062
1063
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1061

def conversion_count
  @conversion_count
end

#conversion_valueFloat

Optional. The conversion value associated with the event, for value-based conversions. Corresponds to the JSON property conversionValue

Returns:

  • (Float)


1067
1068
1069
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1067

def conversion_value
  @conversion_value
end

#currencyString

Optional. The currency code associated with all monetary values within this event. Corresponds to the JSON property currency

Returns:

  • (String)


1073
1074
1075
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1073

def currency
  @currency
end

#custom_variablesArray<Google::Apis::DatamanagerV1::CustomVariable>

Optional. Additional key/value pair information to send to the conversion containers (conversion action or FL activity). Corresponds to the JSON property customVariables



1079
1080
1081
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1079

def custom_variables
  @custom_variables
end

#destination_referencesArray<String>

Optional. Reference string used to determine the destination. If empty, the event will be sent to all destinations in the request. Corresponds to the JSON property destinationReferences

Returns:

  • (Array<String>)


1085
1086
1087
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1085

def destination_references
  @destination_references
end

#event_device_infoGoogle::Apis::DatamanagerV1::DeviceInfo

Information about the device being used (if any) when the event happened. Corresponds to the JSON property eventDeviceInfo



1090
1091
1092
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1090

def event_device_info
  @event_device_info
end

#event_locationGoogle::Apis::DatamanagerV1::EventLocation

The location where the event occurred. Corresponds to the JSON property eventLocation



1095
1096
1097
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1095

def event_location
  @event_location
end

#event_nameString

Optional. The name of the event. Required for GA4 events. Corresponds to the JSON property eventName

Returns:

  • (String)


1100
1101
1102
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1100

def event_name
  @event_name
end

#event_sourceString

Optional. Signal for where the event happened (web, app, in-store, etc.). Corresponds to the JSON property eventSource

Returns:

  • (String)


1105
1106
1107
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1105

def event_source
  @event_source
end

#event_timestampString

Required. The time the event occurred. Corresponds to the JSON property eventTimestamp

Returns:

  • (String)


1110
1111
1112
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1110

def event_timestamp
  @event_timestamp
end

#experimental_fieldsArray<Google::Apis::DatamanagerV1::ExperimentalField>

Optional. A list of key/value pairs for experimental fields that may eventually be promoted to be part of the API. Corresponds to the JSON property experimentalFields



1116
1117
1118
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1116

def experimental_fields
  @experimental_fields
end

#last_updated_timestampString

Optional. The last time the event was updated. Corresponds to the JSON property lastUpdatedTimestamp

Returns:

  • (String)


1121
1122
1123
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1121

def last_updated_timestamp
  @last_updated_timestamp
end

#third_party_user_dataGoogle::Apis::DatamanagerV1::UserData

Data that identifies the user. At least one identifier is required. Corresponds to the JSON property thirdPartyUserData



1126
1127
1128
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1126

def third_party_user_data
  @third_party_user_data
end

#transaction_idString

Optional. The unique identifier for this event. Required for events sent as an additional data source for tag conversions. Corresponds to the JSON property transactionId

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1132

def transaction_id
  @transaction_id
end

#user_dataGoogle::Apis::DatamanagerV1::UserData

Data that identifies the user. At least one identifier is required. Corresponds to the JSON property userData



1137
1138
1139
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1137

def user_data
  @user_data
end

#user_idString

Optional. A unique identifier for a user, as defined by the advertiser. Corresponds to the JSON property userId

Returns:

  • (String)


1142
1143
1144
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1142

def user_id
  @user_id
end

#user_propertiesGoogle::Apis::DatamanagerV1::UserProperties

Advertiser-assessed information about the user at the time that the event happened. See https://support.google.com/google-ads/answer/14007601 for more details. Corresponds to the JSON property userProperties



1149
1150
1151
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1149

def user_properties
  @user_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1156

def update!(**args)
  @ad_identifiers = args[:ad_identifiers] if args.key?(:ad_identifiers)
  @additional_event_parameters = args[:additional_event_parameters] if args.key?(:additional_event_parameters)
  @app_instance_id = args[:app_instance_id] if args.key?(:app_instance_id)
  @cart_data = args[:cart_data] if args.key?(:cart_data)
  @client_id = args[:client_id] if args.key?(:client_id)
  @consent = args[:consent] if args.key?(:consent)
  @conversion_count = args[:conversion_count] if args.key?(:conversion_count)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @currency = args[:currency] if args.key?(:currency)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @destination_references = args[:destination_references] if args.key?(:destination_references)
  @event_device_info = args[:event_device_info] if args.key?(:event_device_info)
  @event_location = args[:event_location] if args.key?(:event_location)
  @event_name = args[:event_name] if args.key?(:event_name)
  @event_source = args[:event_source] if args.key?(:event_source)
  @event_timestamp = args[:event_timestamp] if args.key?(:event_timestamp)
  @experimental_fields = args[:experimental_fields] if args.key?(:experimental_fields)
  @last_updated_timestamp = args[:last_updated_timestamp] if args.key?(:last_updated_timestamp)
  @third_party_user_data = args[:third_party_user_data] if args.key?(:third_party_user_data)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @user_data = args[:user_data] if args.key?(:user_data)
  @user_id = args[:user_id] if args.key?(:user_id)
  @user_properties = args[:user_properties] if args.key?(:user_properties)
end