Class: Google::Apis::DatamanagerV1::Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

An event representing a user interaction with an advertiser's website or app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Event

Returns a new instance of Event.



1111
1112
1113
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_identifiersGoogle::Apis::DatamanagerV1::AdIdentifiers

Identifiers and other information used to match the conversion event with other online activity (such as ad clicks). Corresponds to the JSON property adIdentifiers



985
986
987
# File 'lib/google/apis/datamanager_v1/classes.rb', line 985

def ad_identifiers
  @ad_identifiers
end

#additional_event_parametersArray<Google::Apis::DatamanagerV1::EventParameter>

Optional. A bucket of any event parameters to be included within the event that were not already specified using other structured fields. Corresponds to the JSON property additionalEventParameters



992
993
994
# File 'lib/google/apis/datamanager_v1/classes.rb', line 992

def additional_event_parameters
  @additional_event_parameters
end

#app_instance_idString

Optional. A unique identifier for the user instance of an app client for this GA4 app stream. Corresponds to the JSON property appInstanceId

Returns:

  • (String)


998
999
1000
# File 'lib/google/apis/datamanager_v1/classes.rb', line 998

def app_instance_id
  @app_instance_id
end

#cart_dataGoogle::Apis::DatamanagerV1::CartData

The cart data associated with the event. Corresponds to the JSON property cartData



1003
1004
1005
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1003

def cart_data
  @cart_data
end

#client_idString

Optional. A unique identifier for the user instance of a web client for this GA4 web stream. Corresponds to the JSON property clientId

Returns:

  • (String)


1009
1010
1011
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1009

def client_id
  @client_id
end

Digital Markets Act (DMA) consent settings for the user. Corresponds to the JSON property consent



1015
1016
1017
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1015

def consent
  @consent
end

#conversion_countFloat

Optional. The conversion quantity associated with the event, for counting- based conversions. Corresponds to the JSON property conversionCount

Returns:

  • (Float)


1021
1022
1023
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1021

def conversion_count
  @conversion_count
end

#conversion_valueFloat

Optional. The conversion value associated with the event, for value-based conversions. Corresponds to the JSON property conversionValue

Returns:

  • (Float)


1027
1028
1029
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1027

def conversion_value
  @conversion_value
end

#currencyString

Optional. The currency code associated with all monetary values within this event. Corresponds to the JSON property currency

Returns:

  • (String)


1033
1034
1035
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1033

def currency
  @currency
end

#custom_variablesArray<Google::Apis::DatamanagerV1::CustomVariable>

Optional. Additional key/value pair information to send to the conversion containers (conversion action or FL activity). Corresponds to the JSON property customVariables



1039
1040
1041
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1039

def custom_variables
  @custom_variables
end

#destination_referencesArray<String>

Optional. Reference string used to determine the destination. If empty, the event will be sent to all destinations in the request. Corresponds to the JSON property destinationReferences

Returns:

  • (Array<String>)


1045
1046
1047
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1045

def destination_references
  @destination_references
end

#event_device_infoGoogle::Apis::DatamanagerV1::DeviceInfo

Information about the device being used (if any) when the event happened. Corresponds to the JSON property eventDeviceInfo



1050
1051
1052
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1050

def event_device_info
  @event_device_info
end

#event_locationGoogle::Apis::DatamanagerV1::EventLocation

The location where the event occurred. Corresponds to the JSON property eventLocation



1055
1056
1057
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1055

def event_location
  @event_location
end

#event_nameString

Optional. The name of the event. Required for GA4 events. Corresponds to the JSON property eventName

Returns:

  • (String)


1060
1061
1062
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1060

def event_name
  @event_name
end

#event_sourceString

Optional. Signal for where the event happened (web, app, in-store, etc.). Corresponds to the JSON property eventSource

Returns:

  • (String)


1065
1066
1067
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1065

def event_source
  @event_source
end

#event_timestampString

Required. The time the event occurred. Corresponds to the JSON property eventTimestamp

Returns:

  • (String)


1070
1071
1072
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1070

def event_timestamp
  @event_timestamp
end

#experimental_fieldsArray<Google::Apis::DatamanagerV1::ExperimentalField>

Optional. A list of key/value pairs for experimental fields that may eventually be promoted to be part of the API. Corresponds to the JSON property experimentalFields



1076
1077
1078
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1076

def experimental_fields
  @experimental_fields
end

#last_updated_timestampString

Optional. The last time the event was updated. Corresponds to the JSON property lastUpdatedTimestamp

Returns:

  • (String)


1081
1082
1083
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1081

def last_updated_timestamp
  @last_updated_timestamp
end

#third_party_user_dataGoogle::Apis::DatamanagerV1::UserData

Data that identifies the user. At least one identifier is required. Corresponds to the JSON property thirdPartyUserData



1086
1087
1088
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1086

def third_party_user_data
  @third_party_user_data
end

#transaction_idString

Optional. The unique identifier for this event. Required for events sent as an additional data source for tag conversions. Corresponds to the JSON property transactionId

Returns:

  • (String)


1092
1093
1094
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1092

def transaction_id
  @transaction_id
end

#user_dataGoogle::Apis::DatamanagerV1::UserData

Data that identifies the user. At least one identifier is required. Corresponds to the JSON property userData



1097
1098
1099
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1097

def user_data
  @user_data
end

#user_idString

Optional. A unique identifier for a user, as defined by the advertiser. Corresponds to the JSON property userId

Returns:

  • (String)


1102
1103
1104
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1102

def user_id
  @user_id
end

#user_propertiesGoogle::Apis::DatamanagerV1::UserProperties

Advertiser-assessed information about the user at the time that the event happened. See https://support.google.com/google-ads/answer/14007601 for more details. Corresponds to the JSON property userProperties



1109
1110
1111
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1109

def user_properties
  @user_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1116

def update!(**args)
  @ad_identifiers = args[:ad_identifiers] if args.key?(:ad_identifiers)
  @additional_event_parameters = args[:additional_event_parameters] if args.key?(:additional_event_parameters)
  @app_instance_id = args[:app_instance_id] if args.key?(:app_instance_id)
  @cart_data = args[:cart_data] if args.key?(:cart_data)
  @client_id = args[:client_id] if args.key?(:client_id)
  @consent = args[:consent] if args.key?(:consent)
  @conversion_count = args[:conversion_count] if args.key?(:conversion_count)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @currency = args[:currency] if args.key?(:currency)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @destination_references = args[:destination_references] if args.key?(:destination_references)
  @event_device_info = args[:event_device_info] if args.key?(:event_device_info)
  @event_location = args[:event_location] if args.key?(:event_location)
  @event_name = args[:event_name] if args.key?(:event_name)
  @event_source = args[:event_source] if args.key?(:event_source)
  @event_timestamp = args[:event_timestamp] if args.key?(:event_timestamp)
  @experimental_fields = args[:experimental_fields] if args.key?(:experimental_fields)
  @last_updated_timestamp = args[:last_updated_timestamp] if args.key?(:last_updated_timestamp)
  @third_party_user_data = args[:third_party_user_data] if args.key?(:third_party_user_data)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @user_data = args[:user_data] if args.key?(:user_data)
  @user_id = args[:user_id] if args.key?(:user_id)
  @user_properties = args[:user_properties] if args.key?(:user_properties)
end