Class: Google::Apis::DatamanagerV1::Event
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
An event representing a user interaction with an advertiser's website or app.
Instance Attribute Summary collapse
-
#ad_identifiers ⇒ Google::Apis::DatamanagerV1::AdIdentifiers
Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
-
#additional_event_parameters ⇒ Array<Google::Apis::DatamanagerV1::EventParameter>
Optional.
-
#cart_data ⇒ Google::Apis::DatamanagerV1::CartData
The cart data associated with the event.
-
#client_id ⇒ String
Optional.
-
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA) consent settings for the user.
-
#conversion_value ⇒ Float
Optional.
-
#currency ⇒ String
Optional.
-
#custom_variables ⇒ Array<Google::Apis::DatamanagerV1::CustomVariable>
Optional.
-
#destination_references ⇒ Array<String>
Optional.
-
#event_device_info ⇒ Google::Apis::DatamanagerV1::DeviceInfo
Information about the device being used (if any) when the event happened.
-
#event_name ⇒ String
Optional.
-
#event_source ⇒ String
Optional.
-
#event_timestamp ⇒ String
Required.
-
#experimental_fields ⇒ Array<Google::Apis::DatamanagerV1::ExperimentalField>
Optional.
-
#last_updated_timestamp ⇒ String
Optional.
-
#transaction_id ⇒ String
Optional.
-
#user_data ⇒ Google::Apis::DatamanagerV1::UserData
Data that identifies the user.
-
#user_id ⇒ String
Optional.
-
#user_properties ⇒ Google::Apis::DatamanagerV1::UserProperties
Advertiser-assessed information about the user at the time that the event happened.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Event
constructor
A new instance of Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Event
Returns a new instance of Event.
645 646 647 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_identifiers ⇒ Google::Apis::DatamanagerV1::AdIdentifiers
Identifiers and other information used to match the conversion event with
other online activity (such as ad clicks).
Corresponds to the JSON property adIdentifiers
541 542 543 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 541 def ad_identifiers @ad_identifiers end |
#additional_event_parameters ⇒ Array<Google::Apis::DatamanagerV1::EventParameter>
Optional. A bucket of any event parameters to be included
within the event that were not already specified using other structured fields.
Corresponds to the JSON property additionalEventParameters
548 549 550 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 548 def additional_event_parameters @additional_event_parameters end |
#cart_data ⇒ Google::Apis::DatamanagerV1::CartData
The cart data associated with the event.
Corresponds to the JSON property cartData
553 554 555 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 553 def cart_data @cart_data end |
#client_id ⇒ String
Optional. A unique identifier for the user instance of a web client for this
GA4 web stream.
Corresponds to the JSON property clientId
559 560 561 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 559 def client_id @client_id end |
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA)
consent settings for the user.
Corresponds to the JSON property consent
565 566 567 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 565 def @consent end |
#conversion_value ⇒ Float
Optional. The conversion value associated with the event, for value-based
conversions.
Corresponds to the JSON property conversionValue
571 572 573 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 571 def conversion_value @conversion_value end |
#currency ⇒ String
Optional. The currency code associated with all monetary values within this
event.
Corresponds to the JSON property currency
577 578 579 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 577 def currency @currency end |
#custom_variables ⇒ Array<Google::Apis::DatamanagerV1::CustomVariable>
Optional. Additional key/value pair information to send to the conversion
containers (conversion action or FL activity).
Corresponds to the JSON property customVariables
583 584 585 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 583 def custom_variables @custom_variables end |
#destination_references ⇒ Array<String>
Optional. Reference string used to determine the destination. If empty, the
event will be sent to all destinations in the request.
Corresponds to the JSON property destinationReferences
589 590 591 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 589 def destination_references @destination_references end |
#event_device_info ⇒ Google::Apis::DatamanagerV1::DeviceInfo
Information about the device being used (if any) when the event happened.
Corresponds to the JSON property eventDeviceInfo
594 595 596 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 594 def event_device_info @event_device_info end |
#event_name ⇒ String
Optional. The name of the event. Required for GA4 events.
Corresponds to the JSON property eventName
599 600 601 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 599 def event_name @event_name end |
#event_source ⇒ String
Optional. Signal for where the event happened (web, app, in-store, etc.).
Corresponds to the JSON property eventSource
604 605 606 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 604 def event_source @event_source end |
#event_timestamp ⇒ String
Required. The time the event occurred.
Corresponds to the JSON property eventTimestamp
609 610 611 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 609 def @event_timestamp end |
#experimental_fields ⇒ Array<Google::Apis::DatamanagerV1::ExperimentalField>
Optional. A list of key/value pairs for experimental fields that may
eventually be promoted to be part of the API.
Corresponds to the JSON property experimentalFields
615 616 617 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 615 def experimental_fields @experimental_fields end |
#last_updated_timestamp ⇒ String
Optional. The last time the event was updated.
Corresponds to the JSON property lastUpdatedTimestamp
620 621 622 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 620 def @last_updated_timestamp end |
#transaction_id ⇒ String
Optional. The unique identifier for this event. Required for conversions using
multiple data sources.
Corresponds to the JSON property transactionId
626 627 628 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 626 def transaction_id @transaction_id end |
#user_data ⇒ Google::Apis::DatamanagerV1::UserData
Data that identifies the user. At least one identifier is required.
Corresponds to the JSON property userData
631 632 633 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 631 def user_data @user_data end |
#user_id ⇒ String
Optional. A unique identifier for a user, as defined by the advertiser.
Corresponds to the JSON property userId
636 637 638 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 636 def user_id @user_id end |
#user_properties ⇒ Google::Apis::DatamanagerV1::UserProperties
Advertiser-assessed information about the user at the time that the event
happened. See https://support.google.com/google-ads/answer/14007601 for more
details.
Corresponds to the JSON property userProperties
643 644 645 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 643 def user_properties @user_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 650 def update!(**args) @ad_identifiers = args[:ad_identifiers] if args.key?(:ad_identifiers) @additional_event_parameters = args[:additional_event_parameters] if args.key?(:additional_event_parameters) @cart_data = args[:cart_data] if args.key?(:cart_data) @client_id = args[:client_id] if args.key?(:client_id) @consent = args[:consent] if args.key?(:consent) @conversion_value = args[:conversion_value] if args.key?(:conversion_value) @currency = args[:currency] if args.key?(:currency) @custom_variables = args[:custom_variables] if args.key?(:custom_variables) @destination_references = args[:destination_references] if args.key?(:destination_references) @event_device_info = args[:event_device_info] if args.key?(:event_device_info) @event_name = args[:event_name] if args.key?(:event_name) @event_source = args[:event_source] if args.key?(:event_source) @event_timestamp = args[:event_timestamp] if args.key?(:event_timestamp) @experimental_fields = args[:experimental_fields] if args.key?(:experimental_fields) @last_updated_timestamp = args[:last_updated_timestamp] if args.key?(:last_updated_timestamp) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) @user_data = args[:user_data] if args.key?(:user_data) @user_id = args[:user_id] if args.key?(:user_id) @user_properties = args[:user_properties] if args.key?(:user_properties) end |