Class: Google::Apis::DatamanagerV1::GcpWrappedKeyInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::GcpWrappedKeyInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Information about the Google Cloud Platform wrapped key.
Instance Attribute Summary collapse
-
#encrypted_dek ⇒ String
Required.
-
#kek_uri ⇒ String
Required.
-
#key_type ⇒ String
Required.
-
#wip_provider ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpWrappedKeyInfo
constructor
A new instance of GcpWrappedKeyInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpWrappedKeyInfo
Returns a new instance of GcpWrappedKeyInfo.
1272 1273 1274 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encrypted_dek ⇒ String
Required. The base64 encoded encrypted data encryption key.
Corresponds to the JSON property encryptedDek
1250 1251 1252 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1250 def encrypted_dek @encrypted_dek end |
#kek_uri ⇒ String
Required. Google Cloud Platform Cloud Key Management Service resource ID. Should be in the format of
projects/project/locations/location/keyRings/key_ring/cryptoKeys/key
or `gcp-kms://projects/`project`/locations/`location`/keyRings/`key_ring`/
cryptoKeys/`key
Corresponds to the JSON property kekUri
1259 1260 1261 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1259 def kek_uri @kek_uri end |
#key_type ⇒ String
Required. The type of algorithm used to encrypt the data.
Corresponds to the JSON property keyType
1264 1265 1266 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1264 def key_type @key_type end |
#wip_provider ⇒ String
Required. The Workload Identity pool provider required to use KEK.
Corresponds to the JSON property wipProvider
1270 1271 1272 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1270 def wip_provider @wip_provider end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1277 1278 1279 1280 1281 1282 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1277 def update!(**args) @encrypted_dek = args[:encrypted_dek] if args.key?(:encrypted_dek) @kek_uri = args[:kek_uri] if args.key?(:kek_uri) @key_type = args[:key_type] if args.key?(:key_type) @wip_provider = args[:wip_provider] if args.key?(:wip_provider) end |