Class: Google::Apis::DatamanagerV1::GcpWrappedKeyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Information about the Google Cloud Platform wrapped key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpWrappedKeyInfo

Returns a new instance of GcpWrappedKeyInfo.



898
899
900
# File 'lib/google/apis/datamanager_v1/classes.rb', line 898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_dekString

Required. The base64 encoded encrypted data encryption key. Corresponds to the JSON property encryptedDek

Returns:

  • (String)


876
877
878
# File 'lib/google/apis/datamanager_v1/classes.rb', line 876

def encrypted_dek
  @encrypted_dek
end

#kek_uriString

Required. Google Cloud Platform Cloud Key Management Service resource ID. Should be in the format of projects/project/locations/location/keyRings/key_ring/cryptoKeys/key or `gcp-kms://projects/`project`/locations/`location`/keyRings/`key_ring`/ cryptoKeys/`key Corresponds to the JSON property kekUri

Returns:

  • (String)


885
886
887
# File 'lib/google/apis/datamanager_v1/classes.rb', line 885

def kek_uri
  @kek_uri
end

#key_typeString

Required. The type of algorithm used to encrypt the data. Corresponds to the JSON property keyType

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/datamanager_v1/classes.rb', line 890

def key_type
  @key_type
end

#wip_providerString

Required. The Workload Identity pool provider required to use KEK. Corresponds to the JSON property wipProvider

Returns:

  • (String)


896
897
898
# File 'lib/google/apis/datamanager_v1/classes.rb', line 896

def wip_provider
  @wip_provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



903
904
905
906
907
908
# File 'lib/google/apis/datamanager_v1/classes.rb', line 903

def update!(**args)
  @encrypted_dek = args[:encrypted_dek] if args.key?(:encrypted_dek)
  @kek_uri = args[:kek_uri] if args.key?(:kek_uri)
  @key_type = args[:key_type] if args.key?(:key_type)
  @wip_provider = args[:wip_provider] if args.key?(:wip_provider)
end