Class: Google::Apis::DatamanagerV1::GcpWrappedKeyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Information about the Google Cloud Platform wrapped key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpWrappedKeyInfo

Returns a new instance of GcpWrappedKeyInfo.



752
753
754
# File 'lib/google/apis/datamanager_v1/classes.rb', line 752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_dekString

Required. The base64 encoded encrypted data encryption key. Corresponds to the JSON property encryptedDek

Returns:

  • (String)


730
731
732
# File 'lib/google/apis/datamanager_v1/classes.rb', line 730

def encrypted_dek
  @encrypted_dek
end

#kek_uriString

Required. Google Cloud Platform Cloud Key Management Service resource ID. Should be in the format of projects/project/locations/location/keyRings/key_ring/cryptoKeys/key or `gcp-kms://projects/`project`/locations/`location`/keyRings/`key_ring`/ cryptoKeys/`key Corresponds to the JSON property kekUri

Returns:

  • (String)


739
740
741
# File 'lib/google/apis/datamanager_v1/classes.rb', line 739

def kek_uri
  @kek_uri
end

#key_typeString

Required. The type of algorithm used to encrypt the data. Corresponds to the JSON property keyType

Returns:

  • (String)


744
745
746
# File 'lib/google/apis/datamanager_v1/classes.rb', line 744

def key_type
  @key_type
end

#wip_providerString

Required. The Workload Identity pool provider required to use KEK. Corresponds to the JSON property wipProvider

Returns:

  • (String)


750
751
752
# File 'lib/google/apis/datamanager_v1/classes.rb', line 750

def wip_provider
  @wip_provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



757
758
759
760
761
762
# File 'lib/google/apis/datamanager_v1/classes.rb', line 757

def update!(**args)
  @encrypted_dek = args[:encrypted_dek] if args.key?(:encrypted_dek)
  @kek_uri = args[:kek_uri] if args.key?(:kek_uri)
  @key_type = args[:key_type] if args.key?(:key_type)
  @wip_provider = args[:wip_provider] if args.key?(:wip_provider)
end