Class: Google::Apis::DatamanagerV1::IngestAudienceMembersRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestAudienceMembersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Request to upload audience members to the provided destinations. Returns an IngestAudienceMembersResponse.
Instance Attribute Summary collapse
-
#audience_members ⇒ Array<Google::Apis::DatamanagerV1::AudienceMember>
Required.
-
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA) consent settings for the user.
-
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required.
-
#encoding ⇒ String
Optional.
-
#encryption_info ⇒ Google::Apis::DatamanagerV1::EncryptionInfo
Encryption information for the data being ingested.
-
#terms_of_service ⇒ Google::Apis::DatamanagerV1::TermsOfService
The terms of service that the user has accepted/rejected.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestAudienceMembersRequest
constructor
A new instance of IngestAudienceMembersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestAudienceMembersRequest
Returns a new instance of IngestAudienceMembersRequest.
1465 1466 1467 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_members ⇒ Array<Google::Apis::DatamanagerV1::AudienceMember>
Required. The list of users to send to the specified destinations. At most
10000 AudienceMember resources can be sent in a single request.
Corresponds to the JSON property audienceMembers
1424 1425 1426 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1424 def audience_members @audience_members end |
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA)
consent settings for the user.
Corresponds to the JSON property consent
1430 1431 1432 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1430 def @consent end |
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required. The list of destinations to send the audience members to.
Corresponds to the JSON property destinations
1435 1436 1437 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1435 def destinations @destinations end |
#encoding ⇒ String
Optional. Required for UserData uploads. The encoding type of the user
identifiers. For hashed user identifiers, this is the encoding type of the
hashed string. For encrypted hashed user identifiers, this is the encoding
type of the outer encrypted string, but not necessarily the inner hashed
string, meaning the inner hashed string could be encoded in a different way
than the outer encrypted string. For non UserData uploads, this field is
ignored.
Corresponds to the JSON property encoding
1446 1447 1448 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1446 def encoding @encoding end |
#encryption_info ⇒ Google::Apis::DatamanagerV1::EncryptionInfo
Encryption information for the data being ingested.
Corresponds to the JSON property encryptionInfo
1451 1452 1453 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1451 def encryption_info @encryption_info end |
#terms_of_service ⇒ Google::Apis::DatamanagerV1::TermsOfService
The terms of service that the user has accepted/rejected.
Corresponds to the JSON property termsOfService
1456 1457 1458 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1456 def terms_of_service @terms_of_service end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. For testing purposes. If true, the request is validated but not
executed. Only errors are returned, not results.
Corresponds to the JSON property validateOnly
1462 1463 1464 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1462 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1470 1471 1472 1473 1474 1475 1476 1477 1478 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1470 def update!(**args) @audience_members = args[:audience_members] if args.key?(:audience_members) @consent = args[:consent] if args.key?(:consent) @destinations = args[:destinations] if args.key?(:destinations) @encoding = args[:encoding] if args.key?(:encoding) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @terms_of_service = args[:terms_of_service] if args.key?(:terms_of_service) @validate_only = args[:validate_only] if args.key?(:validate_only) end |