Class: Google::Apis::DatamanagerV1::IngestAudienceMembersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Request to upload audience members to the provided destinations. Returns an IngestAudienceMembersResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestAudienceMembersRequest

Returns a new instance of IngestAudienceMembersRequest.



1380
1381
1382
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_membersArray<Google::Apis::DatamanagerV1::AudienceMember>

Required. The list of users to send to the specified destinations. At most 10000 AudienceMember resources can be sent in a single request. Corresponds to the JSON property audienceMembers



1339
1340
1341
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1339

def audience_members
  @audience_members
end

Digital Markets Act (DMA) consent settings for the user. Corresponds to the JSON property consent



1345
1346
1347
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1345

def consent
  @consent
end

#destinationsArray<Google::Apis::DatamanagerV1::Destination>

Required. The list of destinations to send the audience members to. Corresponds to the JSON property destinations



1350
1351
1352
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1350

def destinations
  @destinations
end

#encodingString

Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored. Corresponds to the JSON property encoding

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1361

def encoding
  @encoding
end

#encryption_infoGoogle::Apis::DatamanagerV1::EncryptionInfo

Encryption information for the data being ingested. Corresponds to the JSON property encryptionInfo



1366
1367
1368
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1366

def encryption_info
  @encryption_info
end

#terms_of_serviceGoogle::Apis::DatamanagerV1::TermsOfService

The terms of service that the user has accepted/rejected. Corresponds to the JSON property termsOfService



1371
1372
1373
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1371

def terms_of_service
  @terms_of_service
end

#validate_onlyBoolean Also known as: validate_only?

Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1377
1378
1379
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1377

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1385

def update!(**args)
  @audience_members = args[:audience_members] if args.key?(:audience_members)
  @consent = args[:consent] if args.key?(:consent)
  @destinations = args[:destinations] if args.key?(:destinations)
  @encoding = args[:encoding] if args.key?(:encoding)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @terms_of_service = args[:terms_of_service] if args.key?(:terms_of_service)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end