Class: Google::Apis::DatamanagerV1::IngestAudienceMembersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Request to upload audience members to the provided destinations. Returns an IngestAudienceMembersResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestAudienceMembersRequest

Returns a new instance of IngestAudienceMembersRequest.



815
816
817
# File 'lib/google/apis/datamanager_v1/classes.rb', line 815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_membersArray<Google::Apis::DatamanagerV1::AudienceMember>

Required. The list of users to send to the specified destinations. At most 10000 AudienceMember resources can be sent in a single request. Corresponds to the JSON property audienceMembers



774
775
776
# File 'lib/google/apis/datamanager_v1/classes.rb', line 774

def audience_members
  @audience_members
end

Digital Markets Act (DMA) consent settings for the user. Corresponds to the JSON property consent



780
781
782
# File 'lib/google/apis/datamanager_v1/classes.rb', line 780

def consent
  @consent
end

#destinationsArray<Google::Apis::DatamanagerV1::Destination>

Required. The list of destinations to send the audience members to. Corresponds to the JSON property destinations



785
786
787
# File 'lib/google/apis/datamanager_v1/classes.rb', line 785

def destinations
  @destinations
end

#encodingString

Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored. Corresponds to the JSON property encoding

Returns:

  • (String)


796
797
798
# File 'lib/google/apis/datamanager_v1/classes.rb', line 796

def encoding
  @encoding
end

#encryption_infoGoogle::Apis::DatamanagerV1::EncryptionInfo

Encryption information for the data being ingested. Corresponds to the JSON property encryptionInfo



801
802
803
# File 'lib/google/apis/datamanager_v1/classes.rb', line 801

def encryption_info
  @encryption_info
end

#terms_of_serviceGoogle::Apis::DatamanagerV1::TermsOfService

The terms of service that the user has accepted/rejected. Corresponds to the JSON property termsOfService



806
807
808
# File 'lib/google/apis/datamanager_v1/classes.rb', line 806

def terms_of_service
  @terms_of_service
end

#validate_onlyBoolean Also known as: validate_only?

Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


812
813
814
# File 'lib/google/apis/datamanager_v1/classes.rb', line 812

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



820
821
822
823
824
825
826
827
828
# File 'lib/google/apis/datamanager_v1/classes.rb', line 820

def update!(**args)
  @audience_members = args[:audience_members] if args.key?(:audience_members)
  @consent = args[:consent] if args.key?(:consent)
  @destinations = args[:destinations] if args.key?(:destinations)
  @encoding = args[:encoding] if args.key?(:encoding)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @terms_of_service = args[:terms_of_service] if args.key?(:terms_of_service)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end