Class: Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the ingest audience members request.
Instance Attribute Summary collapse
-
#composite_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestCompositeDataStatus
The status of the composite data ingestion to the destination containing stats related to the ingestion.
-
#google_user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestGoogleUserIdDataStatus
The status of the google user id data ingestion to the destination containing stats related to the ingestion.
-
#mobile_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats related to the ingestion.
-
#pair_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats related to the ingestion.
-
#partner_provided_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPartnerProvidedIdDataStatus
The status of the partner provided id data ingestion to the destination containing stats related to the ingestion.
-
#ppid_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats related to the ingestion.
-
#user_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserDataStatus
The status of the user data ingestion to the destination containing stats related to the ingestion.
-
#user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats related to the ingestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestAudienceMembersStatus
constructor
A new instance of IngestAudienceMembersStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestAudienceMembersStatus
Returns a new instance of IngestAudienceMembersStatus.
1565 1566 1567 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestCompositeDataStatus
The status of the composite data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property compositeDataIngestionStatus
1521 1522 1523 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1521 def composite_data_ingestion_status @composite_data_ingestion_status end |
#google_user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestGoogleUserIdDataStatus
The status of the google user id data ingestion to the destination containing
stats related to the ingestion.
Corresponds to the JSON property googleUserIdDataIngestionStatus
1527 1528 1529 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1527 def google_user_id_data_ingestion_status @google_user_id_data_ingestion_status end |
#mobile_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property mobileDataIngestionStatus
1533 1534 1535 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1533 def mobile_data_ingestion_status @mobile_data_ingestion_status end |
#pair_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property pairDataIngestionStatus
1539 1540 1541 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1539 def pair_data_ingestion_status @pair_data_ingestion_status end |
#partner_provided_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPartnerProvidedIdDataStatus
The status of the partner provided id data ingestion to the destination
containing stats related to the ingestion.
Corresponds to the JSON property partnerProvidedIdDataIngestionStatus
1545 1546 1547 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1545 def partner_provided_id_data_ingestion_status @partner_provided_id_data_ingestion_status end |
#ppid_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property ppidDataIngestionStatus
1551 1552 1553 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1551 def ppid_data_ingestion_status @ppid_data_ingestion_status end |
#user_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserDataStatus
The status of the user data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property userDataIngestionStatus
1557 1558 1559 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1557 def user_data_ingestion_status @user_data_ingestion_status end |
#user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property userIdDataIngestionStatus
1563 1564 1565 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1563 def user_id_data_ingestion_status @user_id_data_ingestion_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1570 def update!(**args) @composite_data_ingestion_status = args[:composite_data_ingestion_status] if args.key?(:composite_data_ingestion_status) @google_user_id_data_ingestion_status = args[:google_user_id_data_ingestion_status] if args.key?(:google_user_id_data_ingestion_status) @mobile_data_ingestion_status = args[:mobile_data_ingestion_status] if args.key?(:mobile_data_ingestion_status) @pair_data_ingestion_status = args[:pair_data_ingestion_status] if args.key?(:pair_data_ingestion_status) @partner_provided_id_data_ingestion_status = args[:partner_provided_id_data_ingestion_status] if args.key?(:partner_provided_id_data_ingestion_status) @ppid_data_ingestion_status = args[:ppid_data_ingestion_status] if args.key?(:ppid_data_ingestion_status) @user_data_ingestion_status = args[:user_data_ingestion_status] if args.key?(:user_data_ingestion_status) @user_id_data_ingestion_status = args[:user_id_data_ingestion_status] if args.key?(:user_id_data_ingestion_status) end |