Class: Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the ingest audience members request.
Instance Attribute Summary collapse
-
#composite_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestCompositeDataStatus
The status of the composite data ingestion to the destination containing stats related to the ingestion.
-
#mobile_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats related to the ingestion.
-
#pair_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats related to the ingestion.
-
#ppid_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats related to the ingestion.
-
#user_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserDataStatus
The status of the user data ingestion to the destination containing stats related to the ingestion.
-
#user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats related to the ingestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestAudienceMembersStatus
constructor
A new instance of IngestAudienceMembersStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestAudienceMembersStatus
Returns a new instance of IngestAudienceMembersStatus.
1455 1456 1457 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestCompositeDataStatus
The status of the composite data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property compositeDataIngestionStatus
1423 1424 1425 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1423 def composite_data_ingestion_status @composite_data_ingestion_status end |
#mobile_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property mobileDataIngestionStatus
1429 1430 1431 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1429 def mobile_data_ingestion_status @mobile_data_ingestion_status end |
#pair_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property pairDataIngestionStatus
1435 1436 1437 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1435 def pair_data_ingestion_status @pair_data_ingestion_status end |
#ppid_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property ppidDataIngestionStatus
1441 1442 1443 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1441 def ppid_data_ingestion_status @ppid_data_ingestion_status end |
#user_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserDataStatus
The status of the user data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property userDataIngestionStatus
1447 1448 1449 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1447 def user_data_ingestion_status @user_data_ingestion_status end |
#user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property userIdDataIngestionStatus
1453 1454 1455 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1453 def user_id_data_ingestion_status @user_id_data_ingestion_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1460 def update!(**args) @composite_data_ingestion_status = args[:composite_data_ingestion_status] if args.key?(:composite_data_ingestion_status) @mobile_data_ingestion_status = args[:mobile_data_ingestion_status] if args.key?(:mobile_data_ingestion_status) @pair_data_ingestion_status = args[:pair_data_ingestion_status] if args.key?(:pair_data_ingestion_status) @ppid_data_ingestion_status = args[:ppid_data_ingestion_status] if args.key?(:ppid_data_ingestion_status) @user_data_ingestion_status = args[:user_data_ingestion_status] if args.key?(:user_data_ingestion_status) @user_id_data_ingestion_status = args[:user_id_data_ingestion_status] if args.key?(:user_id_data_ingestion_status) end |