Class: Google::Apis::DatamanagerV1::IngestAudienceMembersStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the ingest audience members request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestAudienceMembersStatus

Returns a new instance of IngestAudienceMembersStatus.



1030
1031
1032
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mobile_data_ingestion_statusGoogle::Apis::DatamanagerV1::IngestMobileDataStatus

The status of the mobile data ingestion to the destination containing stats related to the ingestion. Corresponds to the JSON property mobileDataIngestionStatus



1004
1005
1006
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1004

def mobile_data_ingestion_status
  @mobile_data_ingestion_status
end

#pair_data_ingestion_statusGoogle::Apis::DatamanagerV1::IngestPairDataStatus

The status of the pair data ingestion to the destination containing stats related to the ingestion. Corresponds to the JSON property pairDataIngestionStatus



1010
1011
1012
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1010

def pair_data_ingestion_status
  @pair_data_ingestion_status
end

#ppid_data_ingestion_statusGoogle::Apis::DatamanagerV1::IngestPpidDataStatus

The status of the ppid data ingestion to the destination containing stats related to the ingestion. Corresponds to the JSON property ppidDataIngestionStatus



1016
1017
1018
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1016

def ppid_data_ingestion_status
  @ppid_data_ingestion_status
end

#user_data_ingestion_statusGoogle::Apis::DatamanagerV1::IngestUserDataStatus

The status of the user data ingestion to the destination containing stats related to the ingestion. Corresponds to the JSON property userDataIngestionStatus



1022
1023
1024
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1022

def user_data_ingestion_status
  @user_data_ingestion_status
end

#user_id_data_ingestion_statusGoogle::Apis::DatamanagerV1::IngestUserIdDataStatus

The status of the user id data ingestion to the destination containing stats related to the ingestion. Corresponds to the JSON property userIdDataIngestionStatus



1028
1029
1030
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1028

def user_id_data_ingestion_status
  @user_id_data_ingestion_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1035
1036
1037
1038
1039
1040
1041
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1035

def update!(**args)
  @mobile_data_ingestion_status = args[:mobile_data_ingestion_status] if args.key?(:mobile_data_ingestion_status)
  @pair_data_ingestion_status = args[:pair_data_ingestion_status] if args.key?(:pair_data_ingestion_status)
  @ppid_data_ingestion_status = args[:ppid_data_ingestion_status] if args.key?(:ppid_data_ingestion_status)
  @user_data_ingestion_status = args[:user_data_ingestion_status] if args.key?(:user_data_ingestion_status)
  @user_id_data_ingestion_status = args[:user_id_data_ingestion_status] if args.key?(:user_id_data_ingestion_status)
end