Class: Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the ingest audience members request.
Instance Attribute Summary collapse
-
#mobile_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats related to the ingestion.
-
#pair_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats related to the ingestion.
-
#ppid_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats related to the ingestion.
-
#user_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserDataStatus
The status of the user data ingestion to the destination containing stats related to the ingestion.
-
#user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats related to the ingestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestAudienceMembersStatus
constructor
A new instance of IngestAudienceMembersStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestAudienceMembersStatus
Returns a new instance of IngestAudienceMembersStatus.
884 885 886 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mobile_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property mobileDataIngestionStatus
858 859 860 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 858 def mobile_data_ingestion_status @mobile_data_ingestion_status end |
#pair_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property pairDataIngestionStatus
864 865 866 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 864 def pair_data_ingestion_status @pair_data_ingestion_status end |
#ppid_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property ppidDataIngestionStatus
870 871 872 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 870 def ppid_data_ingestion_status @ppid_data_ingestion_status end |
#user_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserDataStatus
The status of the user data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property userDataIngestionStatus
876 877 878 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 876 def user_data_ingestion_status @user_data_ingestion_status end |
#user_id_data_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats
related to the ingestion.
Corresponds to the JSON property userIdDataIngestionStatus
882 883 884 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 882 def user_id_data_ingestion_status @user_id_data_ingestion_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
889 890 891 892 893 894 895 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 889 def update!(**args) @mobile_data_ingestion_status = args[:mobile_data_ingestion_status] if args.key?(:mobile_data_ingestion_status) @pair_data_ingestion_status = args[:pair_data_ingestion_status] if args.key?(:pair_data_ingestion_status) @ppid_data_ingestion_status = args[:ppid_data_ingestion_status] if args.key?(:ppid_data_ingestion_status) @user_data_ingestion_status = args[:user_data_ingestion_status] if args.key?(:user_data_ingestion_status) @user_id_data_ingestion_status = args[:user_id_data_ingestion_status] if args.key?(:user_id_data_ingestion_status) end |