Class: Google::Apis::DatamanagerV1::IngestCompositeDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the composite data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestCompositeDataStatus

Returns a new instance of IngestCompositeDataStatus.



1494
1495
1496
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_type_countsArray<Google::Apis::DatamanagerV1::DataTypeCount>

The total count of data types sent in the upload request for the destination, broken down by data type. Includes all data types in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property dataTypeCounts



1480
1481
1482
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1480

def data_type_counts
  @data_type_counts
end

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1487
1488
1489
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1487

def record_count
  @record_count
end

#upload_match_rate_rangeString

The match rate range of the upload. Corresponds to the JSON property uploadMatchRateRange

Returns:

  • (String)


1492
1493
1494
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1492

def upload_match_rate_range
  @upload_match_rate_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1499
1500
1501
1502
1503
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1499

def update!(**args)
  @data_type_counts = args[:data_type_counts] if args.key?(:data_type_counts)
  @record_count = args[:record_count] if args.key?(:record_count)
  @upload_match_rate_range = args[:upload_match_rate_range] if args.key?(:upload_match_rate_range)
end