Class: Google::Apis::DatamanagerV1::IngestEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Request to upload audience members to the provided destinations. Returns an IngestEventsResponse.
Instance Attribute Summary collapse
-
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA) consent settings for the user.
-
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required.
-
#encoding ⇒ String
Optional.
-
#encryption_info ⇒ Google::Apis::DatamanagerV1::EncryptionInfo
Encryption information for the data being ingested.
-
#events ⇒ Array<Google::Apis::DatamanagerV1::Event>
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestEventsRequest
constructor
A new instance of IngestEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestEventsRequest
Returns a new instance of IngestEventsRequest.
1551 1552 1553 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent ⇒ Google::Apis::DatamanagerV1::Consent
Digital Markets Act (DMA)
consent settings for the user.
Corresponds to the JSON property consent
1515 1516 1517 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1515 def @consent end |
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required. The list of destinations to send the events to.
Corresponds to the JSON property destinations
1520 1521 1522 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1520 def destinations @destinations end |
#encoding ⇒ String
Optional. Required for UserData uploads. The encoding type of the user
identifiers. For hashed user identifiers, this is the encoding type of the
hashed string. For encrypted hashed user identifiers, this is the encoding
type of the outer encrypted string, but not necessarily the inner hashed
string, meaning the inner hashed string could be encoded in a different way
than the outer encrypted string. For non UserData uploads, this field is
ignored.
Corresponds to the JSON property encoding
1531 1532 1533 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1531 def encoding @encoding end |
#encryption_info ⇒ Google::Apis::DatamanagerV1::EncryptionInfo
Encryption information for the data being ingested.
Corresponds to the JSON property encryptionInfo
1536 1537 1538 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1536 def encryption_info @encryption_info end |
#events ⇒ Array<Google::Apis::DatamanagerV1::Event>
Required. The list of events to send to the specified destinations. At most
2000 Event resources can be sent in a single request.
Corresponds to the JSON property events
1542 1543 1544 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1542 def events @events end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. For testing purposes. If true, the request is validated but not
executed. Only errors are returned, not results.
Corresponds to the JSON property validateOnly
1548 1549 1550 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1548 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1556 1557 1558 1559 1560 1561 1562 1563 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1556 def update!(**args) @consent = args[:consent] if args.key?(:consent) @destinations = args[:destinations] if args.key?(:destinations) @encoding = args[:encoding] if args.key?(:encoding) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @events = args[:events] if args.key?(:events) @validate_only = args[:validate_only] if args.key?(:validate_only) end |