Class: Google::Apis::DatamanagerV1::IngestEventsStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestEventsStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the events ingestion to the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ Fixnum
The total count of events sent in the upload request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestEventsStatus
constructor
A new instance of IngestEventsStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestEventsStatus
Returns a new instance of IngestEventsStatus.
1133 1134 1135 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#record_count ⇒ Fixnum
The total count of events sent in the upload request. Includes all events in
the request, regardless of whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1131 1132 1133 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1131 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1138 1139 1140 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1138 def update!(**args) @record_count = args[:record_count] if args.key?(:record_count) end |