Class: Google::Apis::DatamanagerV1::IngestGoogleUserIdDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the google user id data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestGoogleUserIdDataStatus

Returns a new instance of IngestGoogleUserIdDataStatus.



1742
1743
1744
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_user_id_countFixnum

The total count of google user ids sent in the upload request for the destination. Includes all google user ids in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property googleUserIdCount

Returns:

  • (Fixnum)


1733
1734
1735
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1733

def google_user_id_count
  @google_user_id_count
end

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1740
1741
1742
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1740

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1747
1748
1749
1750
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1747

def update!(**args)
  @google_user_id_count = args[:google_user_id_count] if args.key?(:google_user_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end