Class: Google::Apis::DatamanagerV1::IngestMobileDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the mobile data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestMobileDataStatus

Returns a new instance of IngestMobileDataStatus.



1772
1773
1774
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mobile_id_countFixnum

The total count of mobile ids sent in the upload request for the destination. Includes all mobile ids in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property mobileIdCount

Returns:

  • (Fixnum)


1763
1764
1765
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1763

def mobile_id_count
  @mobile_id_count
end

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1770
1771
1772
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1770

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1777
1778
1779
1780
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1777

def update!(**args)
  @mobile_id_count = args[:mobile_id_count] if args.key?(:mobile_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end