Class: Google::Apis::DatamanagerV1::IngestMobileDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestMobileDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the mobile data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#mobile_id_count ⇒ Fixnum
The total count of mobile ids sent in the upload request for the destination.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestMobileDataStatus
constructor
A new instance of IngestMobileDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestMobileDataStatus
Returns a new instance of IngestMobileDataStatus.
1162 1163 1164 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mobile_id_count ⇒ Fixnum
The total count of mobile ids sent in the upload request for the destination.
Includes all mobile ids in the request, regardless of whether they were
successfully ingested or not.
Corresponds to the JSON property mobileIdCount
1153 1154 1155 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1153 def mobile_id_count @mobile_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the
destination. Includes all audience members in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1160 1161 1162 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1160 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1167 1168 1169 1170 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1167 def update!(**args) @mobile_id_count = args[:mobile_id_count] if args.key?(:mobile_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |