Class: Google::Apis::DatamanagerV1::IngestPairDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the pair data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestPairDataStatus

Returns a new instance of IngestPairDataStatus.



1654
1655
1656
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pair_id_countFixnum

The total count of pair ids sent in the upload request for the destination. Includes all pair ids in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property pairIdCount

Returns:

  • (Fixnum)


1645
1646
1647
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1645

def pair_id_count
  @pair_id_count
end

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1652
1653
1654
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1652

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1659
1660
1661
1662
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1659

def update!(**args)
  @pair_id_count = args[:pair_id_count] if args.key?(:pair_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end