Class: Google::Apis::DatamanagerV1::IngestPartnerProvidedIdDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the partner provided id data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestPartnerProvidedIdDataStatus

Returns a new instance of IngestPartnerProvidedIdDataStatus.



1832
1833
1834
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partner_provided_id_countFixnum

The total count of partner provided ids sent in the upload request for the destination. Includes all partner provided ids in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property partnerProvidedIdCount

Returns:

  • (Fixnum)


1823
1824
1825
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1823

def partner_provided_id_count
  @partner_provided_id_count
end

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1830
1831
1832
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1830

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1837
1838
1839
1840
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1837

def update!(**args)
  @partner_provided_id_count = args[:partner_provided_id_count] if args.key?(:partner_provided_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end