Class: Google::Apis::DatamanagerV1::IngestPpidDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::IngestPpidDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the ppid data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#ppid_count ⇒ Fixnum
The total count of ppids sent in the upload request for the destination.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestPpidDataStatus
constructor
A new instance of IngestPpidDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestPpidDataStatus
Returns a new instance of IngestPpidDataStatus.
1222 1223 1224 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ppid_count ⇒ Fixnum
The total count of ppids sent in the upload request for the destination.
Includes all ppids in the request, regardless of whether they were
successfully ingested or not.
Corresponds to the JSON property ppidCount
1213 1214 1215 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1213 def ppid_count @ppid_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the upload request for the
destination. Includes all audience members in the request, regardless of
whether they were successfully ingested or not.
Corresponds to the JSON property recordCount
1220 1221 1222 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1220 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1227 1228 1229 1230 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1227 def update!(**args) @ppid_count = args[:ppid_count] if args.key?(:ppid_count) @record_count = args[:record_count] if args.key?(:record_count) end |