Class: Google::Apis::DatamanagerV1::IngestPpidDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the ppid data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestPpidDataStatus

Returns a new instance of IngestPpidDataStatus.



1076
1077
1078
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ppid_countFixnum

The total count of ppids sent in the upload request for the destination. Includes all ppids in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property ppidCount

Returns:

  • (Fixnum)


1067
1068
1069
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1067

def ppid_count
  @ppid_count
end

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1074
1075
1076
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1074

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1081
1082
1083
1084
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1081

def update!(**args)
  @ppid_count = args[:ppid_count] if args.key?(:ppid_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end