Class: Google::Apis::DatamanagerV1::IngestUserDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the user data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestUserDataStatus

Returns a new instance of IngestUserDataStatus.



1897
1898
1899
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1883
1884
1885
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1883

def record_count
  @record_count
end

#upload_match_rate_rangeString

The match rate range of the upload. Corresponds to the JSON property uploadMatchRateRange

Returns:

  • (String)


1888
1889
1890
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1888

def upload_match_rate_range
  @upload_match_rate_range
end

#user_identifier_countFixnum

The total count of user identifiers sent in the upload request for the destination. Includes all user identifiers in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property userIdentifierCount

Returns:

  • (Fixnum)


1895
1896
1897
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1895

def user_identifier_count
  @user_identifier_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1902
1903
1904
1905
1906
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1902

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
  @upload_match_rate_range = args[:upload_match_rate_range] if args.key?(:upload_match_rate_range)
  @user_identifier_count = args[:user_identifier_count] if args.key?(:user_identifier_count)
end