Class: Google::Apis::DatamanagerV1::IngestUserDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the user data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestUserDataStatus

Returns a new instance of IngestUserDataStatus.



1257
1258
1259
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1243
1244
1245
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1243

def record_count
  @record_count
end

#upload_match_rate_rangeString

The match rate range of the upload. Corresponds to the JSON property uploadMatchRateRange

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1248

def upload_match_rate_range
  @upload_match_rate_range
end

#user_identifier_countFixnum

The total count of user identifiers sent in the upload request for the destination. Includes all user identifiers in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property userIdentifierCount

Returns:

  • (Fixnum)


1255
1256
1257
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1255

def user_identifier_count
  @user_identifier_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1262
1263
1264
1265
1266
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1262

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
  @upload_match_rate_range = args[:upload_match_rate_range] if args.key?(:upload_match_rate_range)
  @user_identifier_count = args[:user_identifier_count] if args.key?(:user_identifier_count)
end