Class: Google::Apis::DatamanagerV1::IngestUserDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the user data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestUserDataStatus

Returns a new instance of IngestUserDataStatus.



1111
1112
1113
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1097
1098
1099
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1097

def record_count
  @record_count
end

#upload_match_rate_rangeString

The match rate range of the upload. Corresponds to the JSON property uploadMatchRateRange

Returns:

  • (String)


1102
1103
1104
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1102

def upload_match_rate_range
  @upload_match_rate_range
end

#user_identifier_countFixnum

The total count of user identifiers sent in the upload request for the destination. Includes all user identifiers in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property userIdentifierCount

Returns:

  • (Fixnum)


1109
1110
1111
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1109

def user_identifier_count
  @user_identifier_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1116
1117
1118
1119
1120
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1116

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
  @upload_match_rate_range = args[:upload_match_rate_range] if args.key?(:upload_match_rate_range)
  @user_identifier_count = args[:user_identifier_count] if args.key?(:user_identifier_count)
end