Class: Google::Apis::DatamanagerV1::IngestUserIdDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the user id data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestUserIdDataStatus

Returns a new instance of IngestUserIdDataStatus.



1288
1289
1290
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1279
1280
1281
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1279

def record_count
  @record_count
end

#user_id_countFixnum

The total count of user ids sent in the upload request for the destination. Includes all user ids in the request, regardless of whether they were successfully ingested or not. Corresponds to the JSON property userIdCount

Returns:

  • (Fixnum)


1286
1287
1288
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1286

def user_id_count
  @user_id_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1293
1294
1295
1296
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1293

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
  @user_id_count = args[:user_id_count] if args.key?(:user_id_count)
end