Class: Google::Apis::DatamanagerV1::ItemParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemParameter

Returns a new instance of ItemParameter.



2166
2167
2168
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_nameString

Required. The name of the parameter to use. Corresponds to the JSON property parameterName

Returns:

  • (String)


2159
2160
2161
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2159

def parameter_name
  @parameter_name
end

#valueString

Required. The string representation of the value of the parameter to set. Corresponds to the JSON property value

Returns:

  • (String)


2164
2165
2166
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2164

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2171
2172
2173
2174
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2171

def update!(**args)
  @parameter_name = args[:parameter_name] if args.key?(:parameter_name)
  @value = args[:value] if args.key?(:value)
end