Class: Google::Apis::DatamanagerV1::ItemParameter
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::ItemParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.
Instance Attribute Summary collapse
-
#parameter_name ⇒ String
Required.
-
#value ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ItemParameter
constructor
A new instance of ItemParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ItemParameter
Returns a new instance of ItemParameter.
1274 1275 1276 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameter_name ⇒ String
Required. The name of the parameter to use.
Corresponds to the JSON property parameterName
1267 1268 1269 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1267 def parameter_name @parameter_name end |
#value ⇒ String
Required. The string representation of the value of the parameter to set.
Corresponds to the JSON property value
1272 1273 1274 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1272 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1279 1280 1281 1282 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1279 def update!(**args) @parameter_name = args[:parameter_name] if args.key?(:parameter_name) @value = args[:value] if args.key?(:value) end |