Class: Google::Apis::DatamanagerV1::ListUserListDirectLicensesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Response from the ListUserListDirectLicensesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUserListDirectLicensesResponse

Returns a new instance of ListUserListDirectLicensesResponse.



1300
1301
1302
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1293
1294
1295
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1293

def next_page_token
  @next_page_token
end

#user_list_direct_licensesArray<Google::Apis::DatamanagerV1::UserListDirectLicense>

The licenses for the given user list in the request. Corresponds to the JSON property userListDirectLicenses



1298
1299
1300
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1298

def user_list_direct_licenses
  @user_list_direct_licenses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1305
1306
1307
1308
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1305

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @user_list_direct_licenses = args[:user_list_direct_licenses] if args.key?(:user_list_direct_licenses)
end