Class: Google::Apis::DatamanagerV1::ListUserListGlobalLicenseCustomerInfosResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Response from the ListUserListGlobalLicensesCustomerInfoRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUserListGlobalLicenseCustomerInfosResponse

Returns a new instance of ListUserListGlobalLicenseCustomerInfosResponse.



1545
1546
1547
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1538
1539
1540
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1538

def next_page_token
  @next_page_token
end

#user_list_global_license_customer_infosArray<Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo>

The customer information for the given license in the request. Corresponds to the JSON property userListGlobalLicenseCustomerInfos



1543
1544
1545
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1543

def user_list_global_license_customer_infos
  @user_list_global_license_customer_infos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1550
1551
1552
1553
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1550

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @user_list_global_license_customer_infos = args[:user_list_global_license_customer_infos] if args.key?(:user_list_global_license_customer_infos)
end