Class: Google::Apis::DatamanagerV1::ListUserListGlobalLicensesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Response from the ListUserListGlobalLicensesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUserListGlobalLicensesResponse

Returns a new instance of ListUserListGlobalLicensesResponse.



1352
1353
1354
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1345

def next_page_token
  @next_page_token
end

#user_list_global_licensesArray<Google::Apis::DatamanagerV1::UserListGlobalLicense>

The licenses for the given user list in the request. Corresponds to the JSON property userListGlobalLicenses



1350
1351
1352
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1350

def user_list_global_licenses
  @user_list_global_licenses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1357
1358
1359
1360
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1357

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @user_list_global_licenses = args[:user_list_global_licenses] if args.key?(:user_list_global_licenses)
end