Class: Google::Apis::DatamanagerV1::MarketingDataInsightsAttribute
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::MarketingDataInsightsAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Insights for a collection of related attributes of the same dimension.
Instance Attribute Summary collapse
-
#age_range ⇒ String
Age range of the audience for which the lift is provided.
-
#gender ⇒ String
Gender of the audience for which the lift is provided.
-
#lift ⇒ Float
Measure of lift that the audience has for the attribute value as compared to the baseline.
-
#user_interest_id ⇒ Fixnum
The user interest ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MarketingDataInsightsAttribute
constructor
A new instance of MarketingDataInsightsAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MarketingDataInsightsAttribute
Returns a new instance of MarketingDataInsightsAttribute.
2173 2174 2175 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_range ⇒ String
Age range of the audience for which the lift is provided.
Corresponds to the JSON property ageRange
2155 2156 2157 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2155 def age_range @age_range end |
#gender ⇒ String
Gender of the audience for which the lift is provided.
Corresponds to the JSON property gender
2160 2161 2162 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2160 def gender @gender end |
#lift ⇒ Float
Measure of lift that the audience has for the attribute value as compared to
the baseline. Range [0-1].
Corresponds to the JSON property lift
2166 2167 2168 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2166 def lift @lift end |
#user_interest_id ⇒ Fixnum
The user interest ID.
Corresponds to the JSON property userInterestId
2171 2172 2173 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2171 def user_interest_id @user_interest_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2178 2179 2180 2181 2182 2183 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2178 def update!(**args) @age_range = args[:age_range] if args.key?(:age_range) @gender = args[:gender] if args.key?(:gender) @lift = args[:lift] if args.key?(:lift) @user_interest_id = args[:user_interest_id] if args.key?(:user_interest_id) end |