Class: Google::Apis::DatamanagerV1::MarketingDataInsightsAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Insights for a collection of related attributes of the same dimension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MarketingDataInsightsAttribute

Returns a new instance of MarketingDataInsightsAttribute.



1678
1679
1680
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeString

Age range of the audience for which the lift is provided. Corresponds to the JSON property ageRange

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1660

def age_range
  @age_range
end

#genderString

Gender of the audience for which the lift is provided. Corresponds to the JSON property gender

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1665

def gender
  @gender
end

#liftFloat

Measure of lift that the audience has for the attribute value as compared to the baseline. Range [0-1]. Corresponds to the JSON property lift

Returns:

  • (Float)


1671
1672
1673
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1671

def lift
  @lift
end

#user_interest_idFixnum

The user interest ID. Corresponds to the JSON property userInterestId

Returns:

  • (Fixnum)


1676
1677
1678
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1676

def user_interest_id
  @user_interest_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1683
1684
1685
1686
1687
1688
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1683

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @gender = args[:gender] if args.key?(:gender)
  @lift = args[:lift] if args.key?(:lift)
  @user_interest_id = args[:user_interest_id] if args.key?(:user_interest_id)
end