Class: Google::Apis::DatamanagerV1::MarketingDataInsightsAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Insights for a collection of related attributes of the same dimension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MarketingDataInsightsAttribute

Returns a new instance of MarketingDataInsightsAttribute.



1459
1460
1461
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeString

Age range of the audience for which the lift is provided. Corresponds to the JSON property ageRange

Returns:

  • (String)


1441
1442
1443
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1441

def age_range
  @age_range
end

#genderString

Gender of the audience for which the lift is provided. Corresponds to the JSON property gender

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1446

def gender
  @gender
end

#liftFloat

Measure of lift that the audience has for the attribute value as compared to the baseline. Range [0-1]. Corresponds to the JSON property lift

Returns:

  • (Float)


1452
1453
1454
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1452

def lift
  @lift
end

#user_interest_idFixnum

The user interest ID. Corresponds to the JSON property userInterestId

Returns:

  • (Fixnum)


1457
1458
1459
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1457

def user_interest_id
  @user_interest_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1464
1465
1466
1467
1468
1469
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1464

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @gender = args[:gender] if args.key?(:gender)
  @lift = args[:lift] if args.key?(:lift)
  @user_interest_id = args[:user_interest_id] if args.key?(:user_interest_id)
end