Class: Google::Apis::DatamanagerV1::PairIdInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::PairIdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Additional information when PAIR_ID is one of the upload_key_types. This
feature is only available to data partners.
Instance Attribute Summary collapse
-
#advertiser_identifier_count ⇒ Fixnum
Optional.
-
#clean_room_identifier ⇒ String
Required.
-
#match_rate_percentage ⇒ Fixnum
Required.
-
#publisher_id ⇒ Fixnum
Required.
-
#publisher_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PairIdInfo
constructor
A new instance of PairIdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PairIdInfo
Returns a new instance of PairIdInfo.
1806 1807 1808 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_identifier_count ⇒ Fixnum
Optional. The count of the advertiser's first party data records that have
been uploaded to a clean room provider. This does not signify the size of a
PAIR user list.
Corresponds to the JSON property advertiserIdentifierCount
1777 1778 1779 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1777 def advertiser_identifier_count @advertiser_identifier_count end |
#clean_room_identifier ⇒ String
Required. Immutable. Identifies a unique advertiser to publisher relationship
with one clean room provider or across multiple clean room providers.
Corresponds to the JSON property cleanRoomIdentifier
1783 1784 1785 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1783 def clean_room_identifier @clean_room_identifier end |
#match_rate_percentage ⇒ Fixnum
Required. This field denotes the percentage of membership match of this user
list with the corresponding publisher's first party data. Must be between 0
and 100 inclusive.
Corresponds to the JSON property matchRatePercentage
1790 1791 1792 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1790 def match_rate_percentage @match_rate_percentage end |
#publisher_id ⇒ Fixnum
Required. Immutable. Identifies the publisher that the Publisher Advertiser
Identity Reconciliation user list is reconciled with. This field is provided
by the cleanroom provider and is only unique in the scope of that cleanroom.
This cannot be used as a global identifier across multiple cleanrooms.
Corresponds to the JSON property publisherId
1798 1799 1800 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1798 def publisher_id @publisher_id end |
#publisher_name ⇒ String
Required. Descriptive name of the publisher to be displayed in the UI for a
better targeting experience.
Corresponds to the JSON property publisherName
1804 1805 1806 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1804 def publisher_name @publisher_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1811 1812 1813 1814 1815 1816 1817 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1811 def update!(**args) @advertiser_identifier_count = args[:advertiser_identifier_count] if args.key?(:advertiser_identifier_count) @clean_room_identifier = args[:clean_room_identifier] if args.key?(:clean_room_identifier) @match_rate_percentage = args[:match_rate_percentage] if args.key?(:match_rate_percentage) @publisher_id = args[:publisher_id] if args.key?(:publisher_id) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) end |