Class: Google::Apis::DatamanagerV1::PartnerLink
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::PartnerLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A partner link between an owning account and a partner account.
Instance Attribute Summary collapse
-
#feature_set ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#owning_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
-
#partner_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
-
#partner_customer_account ⇒ Google::Apis::DatamanagerV1::PartnerCustomerAccount
Represents a customer account in the partner's system.
-
#partner_link_id ⇒ String
Output only.
-
#partner_link_metadata ⇒ Google::Apis::DatamanagerV1::PartnerLinkMetadata
Represents metadata associated with a partner link.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartnerLink
constructor
A new instance of PartnerLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartnerLink
Returns a new instance of PartnerLink.
2596 2597 2598 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_set ⇒ String
Optional. Immutable. The set of features supported for the partner link. If
not specified, the system behavior defaults to
FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT.
Corresponds to the JSON property featureSet
2563 2564 2565 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2563 def feature_set @feature_set end |
#name ⇒ String
Identifier. The name of the partner link. Format: accountTypes/account_type/
accounts/account/partnerLinks/partner_link
Corresponds to the JSON property name
2569 2570 2571 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2569 def name @name end |
#owning_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
Corresponds to the JSON property owningAccount
2574 2575 2576 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2574 def owning_account @owning_account end |
#partner_account ⇒ Google::Apis::DatamanagerV1::ProductAccount
Represents a specific account.
Corresponds to the JSON property partnerAccount
2579 2580 2581 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2579 def partner_account @partner_account end |
#partner_customer_account ⇒ Google::Apis::DatamanagerV1::PartnerCustomerAccount
Represents a customer account in the partner's system.
Corresponds to the JSON property partnerCustomerAccount
2584 2585 2586 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2584 def partner_customer_account @partner_customer_account end |
#partner_link_id ⇒ String
Output only. The partner link ID.
Corresponds to the JSON property partnerLinkId
2589 2590 2591 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2589 def partner_link_id @partner_link_id end |
#partner_link_metadata ⇒ Google::Apis::DatamanagerV1::PartnerLinkMetadata
Represents metadata associated with a partner link.
Corresponds to the JSON property partnerLinkMetadata
2594 2595 2596 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2594 def @partner_link_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2601 2602 2603 2604 2605 2606 2607 2608 2609 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2601 def update!(**args) @feature_set = args[:feature_set] if args.key?(:feature_set) @name = args[:name] if args.key?(:name) @owning_account = args[:owning_account] if args.key?(:owning_account) @partner_account = args[:partner_account] if args.key?(:partner_account) @partner_customer_account = args[:partner_customer_account] if args.key?(:partner_customer_account) @partner_link_id = args[:partner_link_id] if args.key?(:partner_link_id) @partner_link_metadata = args[:partner_link_metadata] if args.key?(:partner_link_metadata) end |