Class: Google::Apis::DatamanagerV1::PartnerLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A partner link between an owning account and a partner account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerLink

Returns a new instance of PartnerLink.



2416
2417
2418
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_setString

Optional. Immutable. The set of features supported for the partner link. If not specified, the system behavior defaults to FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT. Corresponds to the JSON property featureSet

Returns:

  • (String)


2383
2384
2385
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2383

def feature_set
  @feature_set
end

#nameString

Identifier. The name of the partner link. Format: accountTypes/account_type/ accounts/account/partnerLinks/partner_link Corresponds to the JSON property name

Returns:

  • (String)


2389
2390
2391
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2389

def name
  @name
end

#owning_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property owningAccount



2394
2395
2396
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2394

def 
  @owning_account
end

#partner_accountGoogle::Apis::DatamanagerV1::ProductAccount

Represents a specific account. Corresponds to the JSON property partnerAccount



2399
2400
2401
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2399

def 
  @partner_account
end

#partner_customer_accountGoogle::Apis::DatamanagerV1::PartnerCustomerAccount

Represents a customer account in the partner's system. Corresponds to the JSON property partnerCustomerAccount



2404
2405
2406
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2404

def 
  @partner_customer_account
end

Output only. The partner link ID. Corresponds to the JSON property partnerLinkId

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2409

def partner_link_id
  @partner_link_id
end

Represents metadata associated with a partner link. Corresponds to the JSON property partnerLinkMetadata



2414
2415
2416
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2414

def 
  @partner_link_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2421

def update!(**args)
  @feature_set = args[:feature_set] if args.key?(:feature_set)
  @name = args[:name] if args.key?(:name)
  @owning_account = args[:owning_account] if args.key?(:owning_account)
  @partner_account = args[:partner_account] if args.key?(:partner_account)
  @partner_customer_account = args[:partner_customer_account] if args.key?(:partner_customer_account)
  @partner_link_id = args[:partner_link_id] if args.key?(:partner_link_id)
  @partner_link_metadata = args[:partner_link_metadata] if args.key?(:partner_link_metadata)
end