Class: Google::Apis::DatamanagerV1::RemoveAllAudienceMembersRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveAllAudienceMembersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Request to remove all users from an audience in the provided destinations. Returns a RemoveAllAudienceMembersResponse.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required.
-
#remove_as_of_time ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAllAudienceMembersRequest
constructor
A new instance of RemoveAllAudienceMembersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAllAudienceMembersRequest
Returns a new instance of RemoveAllAudienceMembersRequest.
2746 2747 2748 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required. The list of destinations to remove the users from.
Corresponds to the JSON property destinations
2730 2731 2732 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2730 def destinations @destinations end |
#remove_as_of_time ⇒ String
Optional. The remove as of time. If set, only audience members last added
before this time will be removed. If not set, it defaults to current time. The
remove as of time must not be in the future.
Corresponds to the JSON property removeAsOfTime
2737 2738 2739 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2737 def remove_as_of_time @remove_as_of_time end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. For testing purposes. If true, the request is validated but not
executed. Only errors are returned, not results.
Corresponds to the JSON property validateOnly
2743 2744 2745 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2743 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2751 2752 2753 2754 2755 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2751 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @remove_as_of_time = args[:remove_as_of_time] if args.key?(:remove_as_of_time) @validate_only = args[:validate_only] if args.key?(:validate_only) end |