Class: Google::Apis::DatamanagerV1::RemoveAudienceMembersRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveAudienceMembersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Request to remove users from an audience in the provided destinations. Returns a RemoveAudienceMembersResponse.
Instance Attribute Summary collapse
-
#audience_members ⇒ Array<Google::Apis::DatamanagerV1::AudienceMember>
Required.
-
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required.
-
#encoding ⇒ String
Optional.
-
#encryption_info ⇒ Google::Apis::DatamanagerV1::EncryptionInfo
Encryption information for the data being ingested.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAudienceMembersRequest
constructor
A new instance of RemoveAudienceMembersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAudienceMembersRequest
Returns a new instance of RemoveAudienceMembersRequest.
1778 1779 1780 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_members ⇒ Array<Google::Apis::DatamanagerV1::AudienceMember>
Required. The list of users to remove.
Corresponds to the JSON property audienceMembers
1752 1753 1754 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1752 def audience_members @audience_members end |
#destinations ⇒ Array<Google::Apis::DatamanagerV1::Destination>
Required. The list of destinations to remove the users from.
Corresponds to the JSON property destinations
1757 1758 1759 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1757 def destinations @destinations end |
#encoding ⇒ String
Optional. Required for UserData uploads. The encoding type of the user
identifiers. Applies to only the outer encoding for encrypted user identifiers.
For non UserData uploads, this field is ignored.
Corresponds to the JSON property encoding
1764 1765 1766 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1764 def encoding @encoding end |
#encryption_info ⇒ Google::Apis::DatamanagerV1::EncryptionInfo
Encryption information for the data being ingested.
Corresponds to the JSON property encryptionInfo
1769 1770 1771 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1769 def encryption_info @encryption_info end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. For testing purposes. If true, the request is validated but not
executed. Only errors are returned, not results.
Corresponds to the JSON property validateOnly
1775 1776 1777 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1775 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1783 1784 1785 1786 1787 1788 1789 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1783 def update!(**args) @audience_members = args[:audience_members] if args.key?(:audience_members) @destinations = args[:destinations] if args.key?(:destinations) @encoding = args[:encoding] if args.key?(:encoding) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @validate_only = args[:validate_only] if args.key?(:validate_only) end |