Class: Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the remove audience members request.
Instance Attribute Summary collapse
-
#composite_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveCompositeDataStatus
The status of the composite data removal from the destination.
-
#google_user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveGoogleUserIdDataStatus
The status of the google user id data removal from the destination.
-
#mobile_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
-
#pair_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePairDataStatus
The status of the pair data removal from the destination.
-
#partner_provided_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePartnerProvidedIdDataStatus
The status of the partner provided id data removal from the destination.
-
#ppid_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePpidDataStatus
The status of the ppid data removal from the destination.
-
#user_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserDataStatus
The status of the user data removal from the destination.
-
#user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
The status of the user id data removal from the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAudienceMembersStatus
constructor
A new instance of RemoveAudienceMembersStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAudienceMembersStatus
Returns a new instance of RemoveAudienceMembersStatus.
2908 2909 2910 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveCompositeDataStatus
The status of the composite data removal from the destination.
Corresponds to the JSON property compositeDataRemovalStatus
2871 2872 2873 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2871 def composite_data_removal_status @composite_data_removal_status end |
#google_user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveGoogleUserIdDataStatus
The status of the google user id data removal from the destination.
Corresponds to the JSON property googleUserIdDataRemovalStatus
2876 2877 2878 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2876 def google_user_id_data_removal_status @google_user_id_data_removal_status end |
#mobile_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
Corresponds to the JSON property mobileDataRemovalStatus
2881 2882 2883 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2881 def mobile_data_removal_status @mobile_data_removal_status end |
#pair_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePairDataStatus
The status of the pair data removal from the destination.
Corresponds to the JSON property pairDataRemovalStatus
2886 2887 2888 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2886 def pair_data_removal_status @pair_data_removal_status end |
#partner_provided_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePartnerProvidedIdDataStatus
The status of the partner provided id data removal from the destination.
Corresponds to the JSON property partnerProvidedIdDataRemovalStatus
2891 2892 2893 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2891 def partner_provided_id_data_removal_status @partner_provided_id_data_removal_status end |
#ppid_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePpidDataStatus
The status of the ppid data removal from the destination.
Corresponds to the JSON property ppidDataRemovalStatus
2896 2897 2898 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2896 def ppid_data_removal_status @ppid_data_removal_status end |
#user_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserDataStatus
The status of the user data removal from the destination.
Corresponds to the JSON property userDataRemovalStatus
2901 2902 2903 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2901 def user_data_removal_status @user_data_removal_status end |
#user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
The status of the user id data removal from the destination.
Corresponds to the JSON property userIdDataRemovalStatus
2906 2907 2908 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2906 def user_id_data_removal_status @user_id_data_removal_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2913 def update!(**args) @composite_data_removal_status = args[:composite_data_removal_status] if args.key?(:composite_data_removal_status) @google_user_id_data_removal_status = args[:google_user_id_data_removal_status] if args.key?(:google_user_id_data_removal_status) @mobile_data_removal_status = args[:mobile_data_removal_status] if args.key?(:mobile_data_removal_status) @pair_data_removal_status = args[:pair_data_removal_status] if args.key?(:pair_data_removal_status) @partner_provided_id_data_removal_status = args[:partner_provided_id_data_removal_status] if args.key?(:partner_provided_id_data_removal_status) @ppid_data_removal_status = args[:ppid_data_removal_status] if args.key?(:ppid_data_removal_status) @user_data_removal_status = args[:user_data_removal_status] if args.key?(:user_data_removal_status) @user_id_data_removal_status = args[:user_id_data_removal_status] if args.key?(:user_id_data_removal_status) end |