Class: Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the remove audience members request.
Instance Attribute Summary collapse
-
#composite_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveCompositeDataStatus
The status of the composite data removal from the destination.
-
#mobile_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
-
#pair_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePairDataStatus
The status of the pair data removal from the destination.
-
#ppid_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePpidDataStatus
The status of the ppid data removal from the destination.
-
#user_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserDataStatus
The status of the user data removal from the destination.
-
#user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
The status of the user id data removal from the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAudienceMembersStatus
constructor
A new instance of RemoveAudienceMembersStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAudienceMembersStatus
Returns a new instance of RemoveAudienceMembersStatus.
2630 2631 2632 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveCompositeDataStatus
The status of the composite data removal from the destination.
Corresponds to the JSON property compositeDataRemovalStatus
2603 2604 2605 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2603 def composite_data_removal_status @composite_data_removal_status end |
#mobile_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
Corresponds to the JSON property mobileDataRemovalStatus
2608 2609 2610 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2608 def mobile_data_removal_status @mobile_data_removal_status end |
#pair_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePairDataStatus
The status of the pair data removal from the destination.
Corresponds to the JSON property pairDataRemovalStatus
2613 2614 2615 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2613 def pair_data_removal_status @pair_data_removal_status end |
#ppid_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePpidDataStatus
The status of the ppid data removal from the destination.
Corresponds to the JSON property ppidDataRemovalStatus
2618 2619 2620 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2618 def ppid_data_removal_status @ppid_data_removal_status end |
#user_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserDataStatus
The status of the user data removal from the destination.
Corresponds to the JSON property userDataRemovalStatus
2623 2624 2625 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2623 def user_data_removal_status @user_data_removal_status end |
#user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
The status of the user id data removal from the destination.
Corresponds to the JSON property userIdDataRemovalStatus
2628 2629 2630 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2628 def user_id_data_removal_status @user_id_data_removal_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2635 2636 2637 2638 2639 2640 2641 2642 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2635 def update!(**args) @composite_data_removal_status = args[:composite_data_removal_status] if args.key?(:composite_data_removal_status) @mobile_data_removal_status = args[:mobile_data_removal_status] if args.key?(:mobile_data_removal_status) @pair_data_removal_status = args[:pair_data_removal_status] if args.key?(:pair_data_removal_status) @ppid_data_removal_status = args[:ppid_data_removal_status] if args.key?(:ppid_data_removal_status) @user_data_removal_status = args[:user_data_removal_status] if args.key?(:user_data_removal_status) @user_id_data_removal_status = args[:user_id_data_removal_status] if args.key?(:user_id_data_removal_status) end |