Class: Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the remove audience members request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveAudienceMembersStatus

Returns a new instance of RemoveAudienceMembersStatus.



2059
2060
2061
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mobile_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveMobileDataStatus

The status of the mobile data removal from the destination. Corresponds to the JSON property mobileDataRemovalStatus



2037
2038
2039
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2037

def mobile_data_removal_status
  @mobile_data_removal_status
end

#pair_data_removal_statusGoogle::Apis::DatamanagerV1::RemovePairDataStatus

The status of the pair data removal from the destination. Corresponds to the JSON property pairDataRemovalStatus



2042
2043
2044
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2042

def pair_data_removal_status
  @pair_data_removal_status
end

#ppid_data_removal_statusGoogle::Apis::DatamanagerV1::RemovePpidDataStatus

The status of the ppid data removal from the destination. Corresponds to the JSON property ppidDataRemovalStatus



2047
2048
2049
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2047

def ppid_data_removal_status
  @ppid_data_removal_status
end

#user_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveUserDataStatus

The status of the user data removal from the destination. Corresponds to the JSON property userDataRemovalStatus



2052
2053
2054
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2052

def user_data_removal_status
  @user_data_removal_status
end

#user_id_data_removal_statusGoogle::Apis::DatamanagerV1::RemoveUserIdDataStatus

The status of the user id data removal from the destination. Corresponds to the JSON property userIdDataRemovalStatus



2057
2058
2059
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2057

def user_id_data_removal_status
  @user_id_data_removal_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2064
2065
2066
2067
2068
2069
2070
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2064

def update!(**args)
  @mobile_data_removal_status = args[:mobile_data_removal_status] if args.key?(:mobile_data_removal_status)
  @pair_data_removal_status = args[:pair_data_removal_status] if args.key?(:pair_data_removal_status)
  @ppid_data_removal_status = args[:ppid_data_removal_status] if args.key?(:ppid_data_removal_status)
  @user_data_removal_status = args[:user_data_removal_status] if args.key?(:user_data_removal_status)
  @user_id_data_removal_status = args[:user_id_data_removal_status] if args.key?(:user_id_data_removal_status)
end