Class: Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the remove audience members request.
Instance Attribute Summary collapse
-
#mobile_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
-
#pair_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePairDataStatus
The status of the pair data removal from the destination.
-
#ppid_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePpidDataStatus
The status of the ppid data removal from the destination.
-
#user_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserDataStatus
The status of the user data removal from the destination.
-
#user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
The status of the user id data removal from the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAudienceMembersStatus
constructor
A new instance of RemoveAudienceMembersStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAudienceMembersStatus
Returns a new instance of RemoveAudienceMembersStatus.
1840 1841 1842 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mobile_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
Corresponds to the JSON property mobileDataRemovalStatus
1818 1819 1820 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1818 def mobile_data_removal_status @mobile_data_removal_status end |
#pair_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePairDataStatus
The status of the pair data removal from the destination.
Corresponds to the JSON property pairDataRemovalStatus
1823 1824 1825 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1823 def pair_data_removal_status @pair_data_removal_status end |
#ppid_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemovePpidDataStatus
The status of the ppid data removal from the destination.
Corresponds to the JSON property ppidDataRemovalStatus
1828 1829 1830 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1828 def ppid_data_removal_status @ppid_data_removal_status end |
#user_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserDataStatus
The status of the user data removal from the destination.
Corresponds to the JSON property userDataRemovalStatus
1833 1834 1835 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1833 def user_data_removal_status @user_data_removal_status end |
#user_id_data_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
The status of the user id data removal from the destination.
Corresponds to the JSON property userIdDataRemovalStatus
1838 1839 1840 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1838 def user_id_data_removal_status @user_id_data_removal_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1845 1846 1847 1848 1849 1850 1851 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1845 def update!(**args) @mobile_data_removal_status = args[:mobile_data_removal_status] if args.key?(:mobile_data_removal_status) @pair_data_removal_status = args[:pair_data_removal_status] if args.key?(:pair_data_removal_status) @ppid_data_removal_status = args[:ppid_data_removal_status] if args.key?(:ppid_data_removal_status) @user_data_removal_status = args[:user_data_removal_status] if args.key?(:user_data_removal_status) @user_id_data_removal_status = args[:user_id_data_removal_status] if args.key?(:user_id_data_removal_status) end |