Class: Google::Apis::DatamanagerV1::RemoveCompositeDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveCompositeDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the composite data removal from the destination.
Instance Attribute Summary collapse
-
#data_type_counts ⇒ Array<Google::Apis::DatamanagerV1::DataTypeCount>
The total count of data types sent in the removal request, broken down by data type.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveCompositeDataStatus
constructor
A new instance of RemoveCompositeDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveCompositeDataStatus
Returns a new instance of RemoveCompositeDataStatus.
2943 2944 2945 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_type_counts ⇒ Array<Google::Apis::DatamanagerV1::DataTypeCount>
The total count of data types sent in the removal request, broken down by data
type. Includes all data types in the request, regardless of whether they were
successfully removed or not.
Corresponds to the JSON property dataTypeCounts
2934 2935 2936 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2934 def data_type_counts @data_type_counts end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2941 2942 2943 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2941 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2948 2949 2950 2951 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2948 def update!(**args) @data_type_counts = args[:data_type_counts] if args.key?(:data_type_counts) @record_count = args[:record_count] if args.key?(:record_count) end |