Class: Google::Apis::DatamanagerV1::RemoveGoogleUserIdDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveGoogleUserIdDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the google user id data removal from the destination.
Instance Attribute Summary collapse
-
#google_user_id_count ⇒ Fixnum
The total count of google user ids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveGoogleUserIdDataStatus
constructor
A new instance of RemoveGoogleUserIdDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveGoogleUserIdDataStatus
Returns a new instance of RemoveGoogleUserIdDataStatus.
2972 2973 2974 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_user_id_count ⇒ Fixnum
The total count of google user ids sent in the removal request. Includes all
google user ids in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property googleUserIdCount
2963 2964 2965 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2963 def google_user_id_count @google_user_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2970 2971 2972 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2970 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2977 2978 2979 2980 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2977 def update!(**args) @google_user_id_count = args[:google_user_id_count] if args.key?(:google_user_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |