Class: Google::Apis::DatamanagerV1::RemoveMobileDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveMobileDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the mobile data removal from the destination.
Instance Attribute Summary collapse
-
#mobile_id_count ⇒ Fixnum
The total count of mobile Ids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveMobileDataStatus
constructor
A new instance of RemoveMobileDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveMobileDataStatus
Returns a new instance of RemoveMobileDataStatus.
2692 2693 2694 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mobile_id_count ⇒ Fixnum
The total count of mobile Ids sent in the removal request. Includes all mobile
ids in the request, regardless of whether they were successfully removed or
not.
Corresponds to the JSON property mobileIdCount
2683 2684 2685 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2683 def mobile_id_count @mobile_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2690 2691 2692 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2690 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2697 2698 2699 2700 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2697 def update!(**args) @mobile_id_count = args[:mobile_id_count] if args.key?(:mobile_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |