Class: Google::Apis::DatamanagerV1::RemoveMobileDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the mobile data removal from the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveMobileDataStatus

Returns a new instance of RemoveMobileDataStatus.



2091
2092
2093
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mobile_id_countFixnum

The total count of mobile Ids sent in the removal request. Includes all mobile ids in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property mobileIdCount

Returns:

  • (Fixnum)


2082
2083
2084
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2082

def mobile_id_count
  @mobile_id_count
end

#record_countFixnum

The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


2089
2090
2091
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2089

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2096
2097
2098
2099
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2096

def update!(**args)
  @mobile_id_count = args[:mobile_id_count] if args.key?(:mobile_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end