Class: Google::Apis::DatamanagerV1::RemovePairDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemovePairDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the pair data removal from the destination.
Instance Attribute Summary collapse
-
#pair_id_count ⇒ Fixnum
The total count of pair ids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemovePairDataStatus
constructor
A new instance of RemovePairDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemovePairDataStatus
Returns a new instance of RemovePairDataStatus.
2720 2721 2722 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pair_id_count ⇒ Fixnum
The total count of pair ids sent in the removal request. Includes all pair ids
in the request, regardless of whether they were successfully removed or not.
Corresponds to the JSON property pairIdCount
2711 2712 2713 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2711 def pair_id_count @pair_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2718 2719 2720 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2718 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2725 2726 2727 2728 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2725 def update!(**args) @pair_id_count = args[:pair_id_count] if args.key?(:pair_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |