Class: Google::Apis::DatamanagerV1::RemovePairDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemovePairDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the pair data removal from the destination.
Instance Attribute Summary collapse
-
#pair_id_count ⇒ Fixnum
The total count of pair ids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemovePairDataStatus
constructor
A new instance of RemovePairDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemovePairDataStatus
Returns a new instance of RemovePairDataStatus.
2119 2120 2121 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pair_id_count ⇒ Fixnum
The total count of pair ids sent in the removal request. Includes all pair ids
in the request, regardless of whether they were successfully removed or not.
Corresponds to the JSON property pairIdCount
2110 2111 2112 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2110 def pair_id_count @pair_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2117 2118 2119 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2117 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2124 2125 2126 2127 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2124 def update!(**args) @pair_id_count = args[:pair_id_count] if args.key?(:pair_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |