Class: Google::Apis::DatamanagerV1::RemovePartnerProvidedIdDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemovePartnerProvidedIdDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the partner provided id data removal from the destination.
Instance Attribute Summary collapse
-
#partner_provided_id_count ⇒ Fixnum
The total count of partner provided ids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemovePartnerProvidedIdDataStatus
constructor
A new instance of RemovePartnerProvidedIdDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemovePartnerProvidedIdDataStatus
Returns a new instance of RemovePartnerProvidedIdDataStatus.
3051 3052 3053 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partner_provided_id_count ⇒ Fixnum
The total count of partner provided ids sent in the removal request. Includes
all partner provided ids in the request, regardless of whether they were
successfully removed or not.
Corresponds to the JSON property partnerProvidedIdCount
3042 3043 3044 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3042 def partner_provided_id_count @partner_provided_id_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
3049 3050 3051 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3049 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3056 3057 3058 3059 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3056 def update!(**args) @partner_provided_id_count = args[:partner_provided_id_count] if args.key?(:partner_provided_id_count) @record_count = args[:record_count] if args.key?(:record_count) end |