Class: Google::Apis::DatamanagerV1::RemovePartnerProvidedIdDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the partner provided id data removal from the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemovePartnerProvidedIdDataStatus

Returns a new instance of RemovePartnerProvidedIdDataStatus.



3058
3059
3060
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partner_provided_id_countFixnum

The total count of partner provided ids sent in the removal request. Includes all partner provided ids in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property partnerProvidedIdCount

Returns:

  • (Fixnum)


3049
3050
3051
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3049

def partner_provided_id_count
  @partner_provided_id_count
end

#record_countFixnum

The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


3056
3057
3058
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3056

def record_count
  @record_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3063
3064
3065
3066
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3063

def update!(**args)
  @partner_provided_id_count = args[:partner_provided_id_count] if args.key?(:partner_provided_id_count)
  @record_count = args[:record_count] if args.key?(:record_count)
end