Class: Google::Apis::DatamanagerV1::RemovePpidDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemovePpidDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the ppid data removal from the destination.
Instance Attribute Summary collapse
-
#ppid_count ⇒ Fixnum
The total count of ppids sent in the removal request.
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemovePpidDataStatus
constructor
A new instance of RemovePpidDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemovePpidDataStatus
Returns a new instance of RemovePpidDataStatus.
2147 2148 2149 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ppid_count ⇒ Fixnum
The total count of ppids sent in the removal request. Includes all ppids in
the request, regardless of whether they were successfully removed or not.
Corresponds to the JSON property ppidCount
2138 2139 2140 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2138 def ppid_count @ppid_count end |
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2145 2146 2147 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2145 def record_count @record_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2152 2153 2154 2155 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2152 def update!(**args) @ppid_count = args[:ppid_count] if args.key?(:ppid_count) @record_count = args[:record_count] if args.key?(:record_count) end |