Class: Google::Apis::DatamanagerV1::RemoveUserDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveUserDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the user data removal from the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
-
#user_identifier_count ⇒ Fixnum
The total count of user identifiers sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveUserDataStatus
constructor
A new instance of RemoveUserDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveUserDataStatus
Returns a new instance of RemoveUserDataStatus.
3115 3116 3117 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
3106 3107 3108 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3106 def record_count @record_count end |
#user_identifier_count ⇒ Fixnum
The total count of user identifiers sent in the removal request. Includes all
user identifiers in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property userIdentifierCount
3113 3114 3115 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3113 def user_identifier_count @user_identifier_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3120 3121 3122 3123 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3120 def update!(**args) @record_count = args[:record_count] if args.key?(:record_count) @user_identifier_count = args[:user_identifier_count] if args.key?(:user_identifier_count) end |