Class: Google::Apis::DatamanagerV1::RemoveUserDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the user data removal from the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveUserDataStatus

Returns a new instance of RemoveUserDataStatus.



2777
2778
2779
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


2768
2769
2770
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2768

def record_count
  @record_count
end

#user_identifier_countFixnum

The total count of user identifiers sent in the removal request. Includes all user identifiers in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property userIdentifierCount

Returns:

  • (Fixnum)


2775
2776
2777
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2775

def user_identifier_count
  @user_identifier_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2782
2783
2784
2785
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2782

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
  @user_identifier_count = args[:user_identifier_count] if args.key?(:user_identifier_count)
end