Class: Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RemoveUserIdDataStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The status of the user id data removal from the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request.
-
#user_id_count ⇒ Fixnum
The total count of user ids sent in the removal request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveUserIdDataStatus
constructor
A new instance of RemoveUserIdDataStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveUserIdDataStatus
Returns a new instance of RemoveUserIdDataStatus.
2805 2806 2807 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#record_count ⇒ Fixnum
The total count of audience members sent in the removal request. Includes all
audience members in the request, regardless of whether they were successfully
removed or not.
Corresponds to the JSON property recordCount
2797 2798 2799 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2797 def record_count @record_count end |
#user_id_count ⇒ Fixnum
The total count of user ids sent in the removal request. Includes all user ids
in the request, regardless of whether they were successfully removed or not.
Corresponds to the JSON property userIdCount
2803 2804 2805 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2803 def user_id_count @user_id_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2810 2811 2812 2813 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2810 def update!(**args) @record_count = args[:record_count] if args.key?(:record_count) @user_id_count = args[:user_id_count] if args.key?(:user_id_count) end |