Class: Google::Apis::DatamanagerV1::RemoveUserIdDataStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

The status of the user id data removal from the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveUserIdDataStatus

Returns a new instance of RemoveUserIdDataStatus.



1985
1986
1987
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#record_countFixnum

The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property recordCount

Returns:

  • (Fixnum)


1977
1978
1979
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1977

def record_count
  @record_count
end

#user_id_countFixnum

The total count of user ids sent in the removal request. Includes all user ids in the request, regardless of whether they were successfully removed or not. Corresponds to the JSON property userIdCount

Returns:

  • (Fixnum)


1983
1984
1985
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1983

def user_id_count
  @user_id_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1990
1991
1992
1993
# File 'lib/google/apis/datamanager_v1/classes.rb', line 1990

def update!(**args)
  @record_count = args[:record_count] if args.key?(:record_count)
  @user_id_count = args[:user_id_count] if args.key?(:user_id_count)
end