Class: Google::Apis::DatamanagerV1::RequestStatusPerDestination
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::RequestStatusPerDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A request status per destination.
Instance Attribute Summary collapse
-
#audience_members_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
The status of the ingest audience members request.
-
#audience_members_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
The status of the remove audience members request.
-
#destination ⇒ Google::Apis::DatamanagerV1::Destination
The Google product you're sending data to.
-
#error_info ⇒ Google::Apis::DatamanagerV1::ErrorInfo
Error counts for each type of error.
-
#events_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestEventsStatus
The status of the events ingestion to the destination.
-
#request_status ⇒ String
The request status of the destination.
-
#warning_info ⇒ Google::Apis::DatamanagerV1::WarningInfo
Warning counts for each type of warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestStatusPerDestination
constructor
A new instance of RequestStatusPerDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestStatusPerDestination
Returns a new instance of RequestStatusPerDestination.
2035 2036 2037 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_members_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestAudienceMembersStatus
The status of the ingest audience members request.
Corresponds to the JSON property audienceMembersIngestionStatus
2003 2004 2005 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2003 def audience_members_ingestion_status @audience_members_ingestion_status end |
#audience_members_removal_status ⇒ Google::Apis::DatamanagerV1::RemoveAudienceMembersStatus
The status of the remove audience members request.
Corresponds to the JSON property audienceMembersRemovalStatus
2008 2009 2010 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2008 def audience_members_removal_status @audience_members_removal_status end |
#destination ⇒ Google::Apis::DatamanagerV1::Destination
The Google product you're sending data to. For example, a Google Ads account.
Corresponds to the JSON property destination
2013 2014 2015 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2013 def destination @destination end |
#error_info ⇒ Google::Apis::DatamanagerV1::ErrorInfo
Error counts for each type of error.
Corresponds to the JSON property errorInfo
2018 2019 2020 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2018 def error_info @error_info end |
#events_ingestion_status ⇒ Google::Apis::DatamanagerV1::IngestEventsStatus
The status of the events ingestion to the destination.
Corresponds to the JSON property eventsIngestionStatus
2023 2024 2025 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2023 def events_ingestion_status @events_ingestion_status end |
#request_status ⇒ String
The request status of the destination.
Corresponds to the JSON property requestStatus
2028 2029 2030 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2028 def request_status @request_status end |
#warning_info ⇒ Google::Apis::DatamanagerV1::WarningInfo
Warning counts for each type of warning.
Corresponds to the JSON property warningInfo
2033 2034 2035 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2033 def warning_info @warning_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2040 2041 2042 2043 2044 2045 2046 2047 2048 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2040 def update!(**args) @audience_members_ingestion_status = args[:audience_members_ingestion_status] if args.key?(:audience_members_ingestion_status) @audience_members_removal_status = args[:audience_members_removal_status] if args.key?(:audience_members_removal_status) @destination = args[:destination] if args.key?(:destination) @error_info = args[:error_info] if args.key?(:error_info) @events_ingestion_status = args[:events_ingestion_status] if args.key?(:events_ingestion_status) @request_status = args[:request_status] if args.key?(:request_status) @warning_info = args[:warning_info] if args.key?(:warning_info) end |