Class: Google::Apis::DatamanagerV1::TargetNetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Eligibility information for different target networks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetNetworkInfo

Returns a new instance of TargetNetworkInfo.



2223
2224
2225
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligible_for_displayBoolean Also known as: eligible_for_display?

Output only. Indicates this user list is eligible for Google Display Network. Corresponds to the JSON property eligibleForDisplay

Returns:

  • (Boolean)


2214
2215
2216
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2214

def eligible_for_display
  @eligible_for_display
end

#eligible_for_searchBoolean Also known as: eligible_for_search?

Optional. Indicates if this user list is eligible for Google Search Network. Corresponds to the JSON property eligibleForSearch

Returns:

  • (Boolean)


2220
2221
2222
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2220

def eligible_for_search
  @eligible_for_search
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2228
2229
2230
2231
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2228

def update!(**args)
  @eligible_for_display = args[:eligible_for_display] if args.key?(:eligible_for_display)
  @eligible_for_search = args[:eligible_for_search] if args.key?(:eligible_for_search)
end