Class: Google::Apis::DatamanagerV1::TermsOfService
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::TermsOfService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
The terms of service that the user has accepted/rejected.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ TermsOfService
constructor
A new instance of TermsOfService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TermsOfService
Returns a new instance of TermsOfService.
2245 2246 2247 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_match_terms_of_service_status ⇒ String
Optional. The Customer Match terms of service: https://support.google.com/
adspolicy/answer/6299717. This must be accepted when ingesting UserData or
MobileData. This field is not required for Partner Match User list.
Corresponds to the JSON property customerMatchTermsOfServiceStatus
2243 2244 2245 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2243 def customer_match_terms_of_service_status @customer_match_terms_of_service_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2250 2251 2252 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2250 def update!(**args) @customer_match_terms_of_service_status = args[:customer_match_terms_of_service_status] if args.key?(:customer_match_terms_of_service_status) end |