Class: Google::Apis::DatamanagerV1::UserList
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A user list resource.
Instance Attribute Summary collapse
-
#access_reason ⇒ String
Output only.
-
#account_access_status ⇒ String
Optional.
-
#closing_reason ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#id ⇒ Fixnum
Output only.
-
#ingested_user_list_info ⇒ Google::Apis::DatamanagerV1::IngestedUserListInfo
Represents a user list that is populated by user provided data.
-
#integration_code ⇒ String
Optional.
-
#membership_duration ⇒ String
Optional.
-
#membership_status ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#read_only ⇒ Boolean
(also: #read_only?)
Output only.
-
#size_info ⇒ Google::Apis::DatamanagerV1::SizeInfo
Estimated number of members in this user list in different target networks.
-
#target_network_info ⇒ Google::Apis::DatamanagerV1::TargetNetworkInfo
Eligibility information for different target networks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserList
constructor
A new instance of UserList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserList
Returns a new instance of UserList.
3605 3606 3607 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reason ⇒ String
Output only. The reason this account has been granted access to the list.
Corresponds to the JSON property accessReason
3531 3532 3533 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3531 def access_reason @access_reason end |
#account_access_status ⇒ String
Optional. Indicates if this share is still enabled. When a user list is shared
with the account this field is set to ENABLED. Later the user list owner can
decide to revoke the share and make it DISABLED.
Corresponds to the JSON property accountAccessStatus
3538 3539 3540 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3538 def account_access_status @account_access_status end |
#closing_reason ⇒ String
Output only. The reason why this user list membership status is closed.
Corresponds to the JSON property closingReason
3543 3544 3545 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3543 def closing_reason @closing_reason end |
#description ⇒ String
Optional. A description of the user list.
Corresponds to the JSON property description
3548 3549 3550 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3548 def description @description end |
#display_name ⇒ String
Required. The display name of the user list.
Corresponds to the JSON property displayName
3553 3554 3555 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3553 def display_name @display_name end |
#id ⇒ Fixnum
Output only. The unique ID of the user list.
Corresponds to the JSON property id
3558 3559 3560 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3558 def id @id end |
#ingested_user_list_info ⇒ Google::Apis::DatamanagerV1::IngestedUserListInfo
Represents a user list that is populated by user provided data.
Corresponds to the JSON property ingestedUserListInfo
3563 3564 3565 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3563 def ingested_user_list_info @ingested_user_list_info end |
#integration_code ⇒ String
Optional. An ID from external system. It is used by user list sellers to
correlate IDs on their systems.
Corresponds to the JSON property integrationCode
3569 3570 3571 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3569 def integration_code @integration_code end |
#membership_duration ⇒ String
Optional. The duration a user remains in the user list. Valid durations are
exact multiples of 24 hours (86400 seconds). Providing a value that is not an
exact multiple of 24 hours will result in an INVALID_ARGUMENT error.
Corresponds to the JSON property membershipDuration
3576 3577 3578 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3576 def membership_duration @membership_duration end |
#membership_status ⇒ String
Optional. Membership status of this user list.
Corresponds to the JSON property membershipStatus
3581 3582 3583 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3581 def membership_status @membership_status end |
#name ⇒ String
Identifier. The resource name of the user list. Format: accountTypes/
account_type/accounts/account/userLists/user_list
Corresponds to the JSON property name
3587 3588 3589 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3587 def name @name end |
#read_only ⇒ Boolean Also known as: read_only?
Output only. An option that indicates if a user may edit a list.
Corresponds to the JSON property readOnly
3592 3593 3594 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3592 def read_only @read_only end |
#size_info ⇒ Google::Apis::DatamanagerV1::SizeInfo
Estimated number of members in this user list in different target networks.
Corresponds to the JSON property sizeInfo
3598 3599 3600 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3598 def size_info @size_info end |
#target_network_info ⇒ Google::Apis::DatamanagerV1::TargetNetworkInfo
Eligibility information for different target networks.
Corresponds to the JSON property targetNetworkInfo
3603 3604 3605 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3603 def target_network_info @target_network_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3610 def update!(**args) @access_reason = args[:access_reason] if args.key?(:access_reason) @account_access_status = args[:account_access_status] if args.key?(:account_access_status) @closing_reason = args[:closing_reason] if args.key?(:closing_reason) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @ingested_user_list_info = args[:ingested_user_list_info] if args.key?(:ingested_user_list_info) @integration_code = args[:integration_code] if args.key?(:integration_code) @membership_duration = args[:membership_duration] if args.key?(:membership_duration) @membership_status = args[:membership_status] if args.key?(:membership_status) @name = args[:name] if args.key?(:name) @read_only = args[:read_only] if args.key?(:read_only) @size_info = args[:size_info] if args.key?(:size_info) @target_network_info = args[:target_network_info] if args.key?(:target_network_info) end |