Class: Google::Apis::DatamanagerV1::UserList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user list resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserList

Returns a new instance of UserList.



2660
2661
2662
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reasonString

Output only. The reason this account has been granted access to the list. Corresponds to the JSON property accessReason

Returns:

  • (String)


2586
2587
2588
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2586

def access_reason
  @access_reason
end

#account_access_statusString

Optional. Indicates if this share is still enabled. When a user list is shared with the account this field is set to ENABLED. Later the user list owner can decide to revoke the share and make it DISABLED. Corresponds to the JSON property accountAccessStatus

Returns:

  • (String)


2593
2594
2595
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2593

def 
  @account_access_status
end

#closing_reasonString

Output only. The reason why this user list membership status is closed. Corresponds to the JSON property closingReason

Returns:

  • (String)


2598
2599
2600
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2598

def closing_reason
  @closing_reason
end

#descriptionString

Optional. A description of the user list. Corresponds to the JSON property description

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2603

def description
  @description
end

#display_nameString

Required. The display name of the user list. Corresponds to the JSON property displayName

Returns:

  • (String)


2608
2609
2610
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2608

def display_name
  @display_name
end

#idFixnum

Output only. The unique ID of the user list. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2613
2614
2615
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2613

def id
  @id
end

#ingested_user_list_infoGoogle::Apis::DatamanagerV1::IngestedUserListInfo

Represents a user list that is populated by user provided data. Corresponds to the JSON property ingestedUserListInfo



2618
2619
2620
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2618

def ingested_user_list_info
  @ingested_user_list_info
end

#integration_codeString

Optional. An ID from external system. It is used by user list sellers to correlate IDs on their systems. Corresponds to the JSON property integrationCode

Returns:

  • (String)


2624
2625
2626
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2624

def integration_code
  @integration_code
end

#membership_durationString

Optional. The duration a user remains in the user list. Valid durations are exact multiples of 24 hours (86400 seconds). Providing a value that is not an exact multiple of 24 hours will result in an INVALID_ARGUMENT error. Corresponds to the JSON property membershipDuration

Returns:

  • (String)


2631
2632
2633
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2631

def membership_duration
  @membership_duration
end

#membership_statusString

Optional. Membership status of this user list. Corresponds to the JSON property membershipStatus

Returns:

  • (String)


2636
2637
2638
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2636

def membership_status
  @membership_status
end

#nameString

Identifier. The resource name of the user list. Format: accountTypes/ account_type/accounts/account/userLists/user_list Corresponds to the JSON property name

Returns:

  • (String)


2642
2643
2644
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2642

def name
  @name
end

#read_onlyBoolean Also known as: read_only?

Output only. An option that indicates if a user may edit a list. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


2647
2648
2649
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2647

def read_only
  @read_only
end

#size_infoGoogle::Apis::DatamanagerV1::SizeInfo

Estimated number of members in this user list in different target networks. Corresponds to the JSON property sizeInfo



2653
2654
2655
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2653

def size_info
  @size_info
end

#target_network_infoGoogle::Apis::DatamanagerV1::TargetNetworkInfo

Eligibility information for different target networks. Corresponds to the JSON property targetNetworkInfo



2658
2659
2660
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2658

def target_network_info
  @target_network_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2665

def update!(**args)
  @access_reason = args[:access_reason] if args.key?(:access_reason)
  @account_access_status = args[:account_access_status] if args.key?(:account_access_status)
  @closing_reason = args[:closing_reason] if args.key?(:closing_reason)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @ingested_user_list_info = args[:ingested_user_list_info] if args.key?(:ingested_user_list_info)
  @integration_code = args[:integration_code] if args.key?(:integration_code)
  @membership_duration = args[:membership_duration] if args.key?(:membership_duration)
  @membership_status = args[:membership_status] if args.key?(:membership_status)
  @name = args[:name] if args.key?(:name)
  @read_only = args[:read_only] if args.key?(:read_only)
  @size_info = args[:size_info] if args.key?(:size_info)
  @target_network_info = args[:target_network_info] if args.key?(:target_network_info)
end