Class: Google::Apis::DatamanagerV1::UserList
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A user list resource.
Instance Attribute Summary collapse
-
#access_reason ⇒ String
Output only.
-
#account_access_status ⇒ String
Optional.
-
#closing_reason ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#id ⇒ Fixnum
Output only.
-
#ingested_user_list_info ⇒ Google::Apis::DatamanagerV1::IngestedUserListInfo
Represents a user list that is populated by user provided data.
-
#integration_code ⇒ String
Optional.
-
#membership_duration ⇒ String
Optional.
-
#membership_status ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#read_only ⇒ Boolean
(also: #read_only?)
Output only.
-
#size_info ⇒ Google::Apis::DatamanagerV1::SizeInfo
Estimated number of members in this user list in different target networks.
-
#target_network_info ⇒ Google::Apis::DatamanagerV1::TargetNetworkInfo
Eligibility information for different target networks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserList
constructor
A new instance of UserList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserList
Returns a new instance of UserList.
2429 2430 2431 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reason ⇒ String
Output only. The reason this account has been granted access to the list.
Corresponds to the JSON property accessReason
2355 2356 2357 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2355 def access_reason @access_reason end |
#account_access_status ⇒ String
Optional. Indicates if this share is still enabled. When a user list is shared
with the account this field is set to ENABLED. Later the user list owner can
decide to revoke the share and make it DISABLED.
Corresponds to the JSON property accountAccessStatus
2362 2363 2364 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2362 def account_access_status @account_access_status end |
#closing_reason ⇒ String
Output only. The reason why this user list membership status is closed.
Corresponds to the JSON property closingReason
2367 2368 2369 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2367 def closing_reason @closing_reason end |
#description ⇒ String
Optional. A description of the user list.
Corresponds to the JSON property description
2372 2373 2374 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2372 def description @description end |
#display_name ⇒ String
Required. The display name of the user list.
Corresponds to the JSON property displayName
2377 2378 2379 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2377 def display_name @display_name end |
#id ⇒ Fixnum
Output only. The unique ID of the user list.
Corresponds to the JSON property id
2382 2383 2384 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2382 def id @id end |
#ingested_user_list_info ⇒ Google::Apis::DatamanagerV1::IngestedUserListInfo
Represents a user list that is populated by user provided data.
Corresponds to the JSON property ingestedUserListInfo
2387 2388 2389 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2387 def ingested_user_list_info @ingested_user_list_info end |
#integration_code ⇒ String
Optional. An ID from external system. It is used by user list sellers to
correlate IDs on their systems.
Corresponds to the JSON property integrationCode
2393 2394 2395 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2393 def integration_code @integration_code end |
#membership_duration ⇒ String
Optional. The duration a user remains in the user list. Valid durations are
exact multiples of 24 hours (86400 seconds). Providing a value that is not an
exact multiple of 24 hours will result in an INVALID_ARGUMENT error.
Corresponds to the JSON property membershipDuration
2400 2401 2402 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2400 def membership_duration @membership_duration end |
#membership_status ⇒ String
Optional. Membership status of this user list.
Corresponds to the JSON property membershipStatus
2405 2406 2407 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2405 def membership_status @membership_status end |
#name ⇒ String
Identifier. The resource name of the user list. Format: accountTypes/
account_type/accounts/account/userLists/user_list
Corresponds to the JSON property name
2411 2412 2413 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2411 def name @name end |
#read_only ⇒ Boolean Also known as: read_only?
Output only. An option that indicates if a user may edit a list.
Corresponds to the JSON property readOnly
2416 2417 2418 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2416 def read_only @read_only end |
#size_info ⇒ Google::Apis::DatamanagerV1::SizeInfo
Estimated number of members in this user list in different target networks.
Corresponds to the JSON property sizeInfo
2422 2423 2424 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2422 def size_info @size_info end |
#target_network_info ⇒ Google::Apis::DatamanagerV1::TargetNetworkInfo
Eligibility information for different target networks.
Corresponds to the JSON property targetNetworkInfo
2427 2428 2429 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2427 def target_network_info @target_network_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2434 def update!(**args) @access_reason = args[:access_reason] if args.key?(:access_reason) @account_access_status = args[:account_access_status] if args.key?(:account_access_status) @closing_reason = args[:closing_reason] if args.key?(:closing_reason) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @ingested_user_list_info = args[:ingested_user_list_info] if args.key?(:ingested_user_list_info) @integration_code = args[:integration_code] if args.key?(:integration_code) @membership_duration = args[:membership_duration] if args.key?(:membership_duration) @membership_status = args[:membership_status] if args.key?(:membership_status) @name = args[:name] if args.key?(:name) @read_only = args[:read_only] if args.key?(:read_only) @size_info = args[:size_info] if args.key?(:size_info) @target_network_info = args[:target_network_info] if args.key?(:target_network_info) end |