Class: Google::Apis::DatamanagerV1::UserListDirectLicense
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListDirectLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A user list direct license. This feature is only available to data partners.
Instance Attribute Summary collapse
-
#client_account_display_name ⇒ String
Output only.
-
#client_account_id ⇒ Fixnum
Immutable.
-
#client_account_type ⇒ String
Immutable.
-
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only.
-
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
-
#name ⇒ String
Identifier.
-
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
-
#status ⇒ String
Optional.
-
#user_list_display_name ⇒ String
Output only.
-
#user_list_id ⇒ Fixnum
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListDirectLicense
constructor
A new instance of UserListDirectLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListDirectLicense
Returns a new instance of UserListDirectLicense.
3341 3342 3343 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_account_display_name ⇒ String
Output only. Name of client customer which the user list is being licensed to.
This field is read-only.
Corresponds to the JSON property clientAccountDisplayName
3292 3293 3294 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3292 def client_account_display_name @client_account_display_name end |
#client_account_id ⇒ Fixnum
Immutable. ID of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountId
3297 3298 3299 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3297 def client_account_id @client_account_id end |
#client_account_type ⇒ String
Immutable. Account type of client customer which the user list is being
licensed to.
Corresponds to the JSON property clientAccountType
3303 3304 3305 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3303 def client_account_type @client_account_type end |
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only. Pricing history of this user list license. This field is read-
only.
Corresponds to the JSON property historicalPricings
3309 3310 3311 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3309 def historical_pricings @historical_pricings end |
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
Corresponds to the JSON property metrics
3314 3315 3316 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3314 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the user list direct license.
Corresponds to the JSON property name
3319 3320 3321 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3319 def name @name end |
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
Corresponds to the JSON property pricing
3324 3325 3326 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3324 def pricing @pricing end |
#status ⇒ String
Optional. Status of UserListDirectLicense - ENABLED or DISABLED.
Corresponds to the JSON property status
3329 3330 3331 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3329 def status @status end |
#user_list_display_name ⇒ String
Output only. Name of the user list being licensed. This field is read-only.
Corresponds to the JSON property userListDisplayName
3334 3335 3336 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3334 def user_list_display_name @user_list_display_name end |
#user_list_id ⇒ Fixnum
Immutable. ID of the user list being licensed.
Corresponds to the JSON property userListId
3339 3340 3341 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3339 def user_list_id @user_list_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3346 3347 3348 3349 3350 3351 3352 3353 3354 3355 3356 3357 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3346 def update!(**args) @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name) @client_account_id = args[:client_account_id] if args.key?(:client_account_id) @client_account_type = args[:client_account_type] if args.key?(:client_account_type) @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @pricing = args[:pricing] if args.key?(:pricing) @status = args[:status] if args.key?(:status) @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) end |