Class: Google::Apis::DatamanagerV1::UserListDirectLicense
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListDirectLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A user list direct license. This feature is only available to data partners.
Instance Attribute Summary collapse
-
#client_account_display_name ⇒ String
Output only.
-
#client_account_id ⇒ Fixnum
Immutable.
-
#client_account_type ⇒ String
Immutable.
-
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only.
-
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
-
#name ⇒ String
Identifier.
-
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
-
#status ⇒ String
Optional.
-
#user_list_display_name ⇒ String
Output only.
-
#user_list_id ⇒ Fixnum
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListDirectLicense
constructor
A new instance of UserListDirectLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListDirectLicense
Returns a new instance of UserListDirectLicense.
2509 2510 2511 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_account_display_name ⇒ String
Output only. Name of client customer which the user list is being licensed to.
This field is read-only.
Corresponds to the JSON property clientAccountDisplayName
2460 2461 2462 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2460 def client_account_display_name @client_account_display_name end |
#client_account_id ⇒ Fixnum
Immutable. ID of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountId
2465 2466 2467 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2465 def client_account_id @client_account_id end |
#client_account_type ⇒ String
Immutable. Account type of client customer which the user list is being
licensed to.
Corresponds to the JSON property clientAccountType
2471 2472 2473 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2471 def client_account_type @client_account_type end |
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only. Pricing history of this user list license. This field is read-
only.
Corresponds to the JSON property historicalPricings
2477 2478 2479 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2477 def historical_pricings @historical_pricings end |
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
Corresponds to the JSON property metrics
2482 2483 2484 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2482 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the user list direct license.
Corresponds to the JSON property name
2487 2488 2489 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2487 def name @name end |
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
Corresponds to the JSON property pricing
2492 2493 2494 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2492 def pricing @pricing end |
#status ⇒ String
Optional. Status of UserListDirectLicense - ENABLED or DISABLED.
Corresponds to the JSON property status
2497 2498 2499 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2497 def status @status end |
#user_list_display_name ⇒ String
Output only. Name of the user list being licensed. This field is read-only.
Corresponds to the JSON property userListDisplayName
2502 2503 2504 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2502 def user_list_display_name @user_list_display_name end |
#user_list_id ⇒ Fixnum
Immutable. ID of the user list being licensed.
Corresponds to the JSON property userListId
2507 2508 2509 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2507 def user_list_id @user_list_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2514 def update!(**args) @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name) @client_account_id = args[:client_account_id] if args.key?(:client_account_id) @client_account_type = args[:client_account_type] if args.key?(:client_account_type) @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @pricing = args[:pricing] if args.key?(:pricing) @status = args[:status] if args.key?(:status) @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) end |