Class: Google::Apis::DatamanagerV1::UserListGlobalLicense

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user list global license. This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserListGlobalLicense

Returns a new instance of UserListGlobalLicense.



2805
2806
2807
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#historical_pricingsArray<Google::Apis::DatamanagerV1::UserListLicensePricing>

Output only. Pricing history of this user list license. This field is read- only. Corresponds to the JSON property historicalPricings



2767
2768
2769
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2767

def historical_pricings
  @historical_pricings
end

#license_typeString

Immutable. Product type of client customer which the user list is being licensed to. Corresponds to the JSON property licenseType

Returns:

  • (String)


2773
2774
2775
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2773

def license_type
  @license_type
end

#metricsGoogle::Apis::DatamanagerV1::UserListLicenseMetrics

Metrics related to a user list license. Corresponds to the JSON property metrics



2778
2779
2780
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2778

def metrics
  @metrics
end

#nameString

Identifier. The resource name of the user list global license. Corresponds to the JSON property name

Returns:

  • (String)


2783
2784
2785
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2783

def name
  @name
end

#pricingGoogle::Apis::DatamanagerV1::UserListLicensePricing

A user list license pricing. Corresponds to the JSON property pricing



2788
2789
2790
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2788

def pricing
  @pricing
end

#statusString

Optional. Status of UserListGlobalLicense - ENABLED or DISABLED. Corresponds to the JSON property status

Returns:

  • (String)


2793
2794
2795
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2793

def status
  @status
end

#user_list_display_nameString

Output only. Name of the user list being licensed. This field is read-only. Corresponds to the JSON property userListDisplayName

Returns:

  • (String)


2798
2799
2800
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2798

def user_list_display_name
  @user_list_display_name
end

#user_list_idFixnum

Immutable. ID of the user list being licensed. Corresponds to the JSON property userListId

Returns:

  • (Fixnum)


2803
2804
2805
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2803

def user_list_id
  @user_list_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2810

def update!(**args)
  @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings)
  @license_type = args[:license_type] if args.key?(:license_type)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @pricing = args[:pricing] if args.key?(:pricing)
  @status = args[:status] if args.key?(:status)
  @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name)
  @user_list_id = args[:user_list_id] if args.key?(:user_list_id)
end