Class: Google::Apis::DatamanagerV1::UserListGlobalLicense

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user list global license. This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserListGlobalLicense

Returns a new instance of UserListGlobalLicense.



2574
2575
2576
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#historical_pricingsArray<Google::Apis::DatamanagerV1::UserListLicensePricing>

Output only. Pricing history of this user list license. This field is read- only. Corresponds to the JSON property historicalPricings



2536
2537
2538
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2536

def historical_pricings
  @historical_pricings
end

#license_typeString

Immutable. Product type of client customer which the user list is being licensed to. Corresponds to the JSON property licenseType

Returns:

  • (String)


2542
2543
2544
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2542

def license_type
  @license_type
end

#metricsGoogle::Apis::DatamanagerV1::UserListLicenseMetrics

Metrics related to a user list license. Corresponds to the JSON property metrics



2547
2548
2549
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2547

def metrics
  @metrics
end

#nameString

Identifier. The resource name of the user list global license. Corresponds to the JSON property name

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2552

def name
  @name
end

#pricingGoogle::Apis::DatamanagerV1::UserListLicensePricing

A user list license pricing. Corresponds to the JSON property pricing



2557
2558
2559
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2557

def pricing
  @pricing
end

#statusString

Optional. Status of UserListGlobalLicense - ENABLED or DISABLED. Corresponds to the JSON property status

Returns:

  • (String)


2562
2563
2564
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2562

def status
  @status
end

#user_list_display_nameString

Output only. Name of the user list being licensed. This field is read-only. Corresponds to the JSON property userListDisplayName

Returns:

  • (String)


2567
2568
2569
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2567

def user_list_display_name
  @user_list_display_name
end

#user_list_idFixnum

Immutable. ID of the user list being licensed. Corresponds to the JSON property userListId

Returns:

  • (Fixnum)


2572
2573
2574
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2572

def user_list_id
  @user_list_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2579

def update!(**args)
  @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings)
  @license_type = args[:license_type] if args.key?(:license_type)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @pricing = args[:pricing] if args.key?(:pricing)
  @status = args[:status] if args.key?(:status)
  @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name)
  @user_list_id = args[:user_list_id] if args.key?(:user_list_id)
end