Class: Google::Apis::DatamanagerV1::UserListGlobalLicense
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListGlobalLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A user list global license. This feature is only available to data partners.
Instance Attribute Summary collapse
-
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only.
-
#license_type ⇒ String
Immutable.
-
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
-
#name ⇒ String
Identifier.
-
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
-
#status ⇒ String
Optional.
-
#user_list_display_name ⇒ String
Output only.
-
#user_list_id ⇒ Fixnum
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListGlobalLicense
constructor
A new instance of UserListGlobalLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListGlobalLicense
Returns a new instance of UserListGlobalLicense.
2574 2575 2576 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only. Pricing history of this user list license. This field is read-
only.
Corresponds to the JSON property historicalPricings
2536 2537 2538 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2536 def historical_pricings @historical_pricings end |
#license_type ⇒ String
Immutable. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property licenseType
2542 2543 2544 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2542 def license_type @license_type end |
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
Corresponds to the JSON property metrics
2547 2548 2549 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2547 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the user list global license.
Corresponds to the JSON property name
2552 2553 2554 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2552 def name @name end |
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
Corresponds to the JSON property pricing
2557 2558 2559 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2557 def pricing @pricing end |
#status ⇒ String
Optional. Status of UserListGlobalLicense - ENABLED or DISABLED.
Corresponds to the JSON property status
2562 2563 2564 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2562 def status @status end |
#user_list_display_name ⇒ String
Output only. Name of the user list being licensed. This field is read-only.
Corresponds to the JSON property userListDisplayName
2567 2568 2569 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2567 def user_list_display_name @user_list_display_name end |
#user_list_id ⇒ Fixnum
Immutable. ID of the user list being licensed.
Corresponds to the JSON property userListId
2572 2573 2574 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2572 def user_list_id @user_list_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2579 def update!(**args) @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings) @license_type = args[:license_type] if args.key?(:license_type) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @pricing = args[:pricing] if args.key?(:pricing) @status = args[:status] if args.key?(:status) @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) end |