Class: Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

Information about a customer of a user list global license. This will automatically be created by the system when a customer purchases a global license.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo

Returns a new instance of UserListGlobalLicenseCustomerInfo.



3830
3831
3832
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_account_display_nameString

Output only. Name of client customer which the user list is being licensed to. Corresponds to the JSON property clientAccountDisplayName

Returns:

  • (String)


3776
3777
3778
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3776

def 
  @client_account_display_name
end

#client_account_idFixnum

Output only. ID of client customer which the user list is being licensed to. Corresponds to the JSON property clientAccountId

Returns:

  • (Fixnum)


3781
3782
3783
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3781

def 
  @client_account_id
end

#client_account_typeString

Output only. Product type of client customer which the user list is being licensed to. Corresponds to the JSON property clientAccountType

Returns:

  • (String)


3787
3788
3789
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3787

def 
  @client_account_type
end

#historical_pricingsArray<Google::Apis::DatamanagerV1::UserListLicensePricing>

Output only. Pricing history of this user list license. Corresponds to the JSON property historicalPricings



3792
3793
3794
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3792

def historical_pricings
  @historical_pricings
end

#license_typeString

Output only. Product type of client customer which the user list is being licensed to. Corresponds to the JSON property licenseType

Returns:

  • (String)


3798
3799
3800
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3798

def license_type
  @license_type
end

#metricsGoogle::Apis::DatamanagerV1::UserListLicenseMetrics

Metrics related to a user list license. Corresponds to the JSON property metrics



3803
3804
3805
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3803

def metrics
  @metrics
end

#nameString

Identifier. The resource name of the user list global license customer. Corresponds to the JSON property name

Returns:

  • (String)


3808
3809
3810
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3808

def name
  @name
end

#pricingGoogle::Apis::DatamanagerV1::UserListLicensePricing

A user list license pricing. Corresponds to the JSON property pricing



3813
3814
3815
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3813

def pricing
  @pricing
end

#statusString

Output only. Status of UserListDirectLicense - ENABLED or DISABLED. Corresponds to the JSON property status

Returns:

  • (String)


3818
3819
3820
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3818

def status
  @status
end

#user_list_display_nameString

Output only. Name of the user list being licensed. Corresponds to the JSON property userListDisplayName

Returns:

  • (String)


3823
3824
3825
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3823

def user_list_display_name
  @user_list_display_name
end

#user_list_idFixnum

Output only. ID of the user list being licensed. Corresponds to the JSON property userListId

Returns:

  • (Fixnum)


3828
3829
3830
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3828

def user_list_id
  @user_list_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3835

def update!(**args)
  @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name)
  @client_account_id = args[:client_account_id] if args.key?(:client_account_id)
  @client_account_type = args[:client_account_type] if args.key?(:client_account_type)
  @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings)
  @license_type = args[:license_type] if args.key?(:license_type)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @pricing = args[:pricing] if args.key?(:pricing)
  @status = args[:status] if args.key?(:status)
  @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name)
  @user_list_id = args[:user_list_id] if args.key?(:user_list_id)
end