Class: Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Information about a customer of a user list global license. This will automatically be created by the system when a customer purchases a global license.
Instance Attribute Summary collapse
-
#client_account_display_name ⇒ String
Output only.
-
#client_account_id ⇒ Fixnum
Output only.
-
#client_account_type ⇒ String
Output only.
-
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only.
-
#license_type ⇒ String
Output only.
-
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
-
#name ⇒ String
Identifier.
-
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
-
#status ⇒ String
Output only.
-
#user_list_display_name ⇒ String
Output only.
-
#user_list_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo
constructor
A new instance of UserListGlobalLicenseCustomerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo
Returns a new instance of UserListGlobalLicenseCustomerInfo.
3486 3487 3488 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_account_display_name ⇒ String
Output only. Name of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountDisplayName
3432 3433 3434 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3432 def client_account_display_name @client_account_display_name end |
#client_account_id ⇒ Fixnum
Output only. ID of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountId
3437 3438 3439 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3437 def client_account_id @client_account_id end |
#client_account_type ⇒ String
Output only. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property clientAccountType
3443 3444 3445 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3443 def client_account_type @client_account_type end |
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only. Pricing history of this user list license.
Corresponds to the JSON property historicalPricings
3448 3449 3450 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3448 def historical_pricings @historical_pricings end |
#license_type ⇒ String
Output only. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property licenseType
3454 3455 3456 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3454 def license_type @license_type end |
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
Corresponds to the JSON property metrics
3459 3460 3461 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3459 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the user list global license customer.
Corresponds to the JSON property name
3464 3465 3466 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3464 def name @name end |
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
Corresponds to the JSON property pricing
3469 3470 3471 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3469 def pricing @pricing end |
#status ⇒ String
Output only. Status of UserListDirectLicense - ENABLED or DISABLED.
Corresponds to the JSON property status
3474 3475 3476 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3474 def status @status end |
#user_list_display_name ⇒ String
Output only. Name of the user list being licensed.
Corresponds to the JSON property userListDisplayName
3479 3480 3481 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3479 def user_list_display_name @user_list_display_name end |
#user_list_id ⇒ Fixnum
Output only. ID of the user list being licensed.
Corresponds to the JSON property userListId
3484 3485 3486 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3484 def user_list_id @user_list_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3491 def update!(**args) @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name) @client_account_id = args[:client_account_id] if args.key?(:client_account_id) @client_account_type = args[:client_account_type] if args.key?(:client_account_type) @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings) @license_type = args[:license_type] if args.key?(:license_type) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @pricing = args[:pricing] if args.key?(:pricing) @status = args[:status] if args.key?(:status) @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) end |