Class: Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Information about a customer of a user list global license. This will automatically be created by the system when a customer purchases a global license.
Instance Attribute Summary collapse
-
#client_account_display_name ⇒ String
Output only.
-
#client_account_id ⇒ Fixnum
Output only.
-
#client_account_type ⇒ String
Output only.
-
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only.
-
#license_type ⇒ String
Output only.
-
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
-
#name ⇒ String
Identifier.
-
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
-
#status ⇒ String
Output only.
-
#user_list_display_name ⇒ String
Output only.
-
#user_list_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo
constructor
A new instance of UserListGlobalLicenseCustomerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo
Returns a new instance of UserListGlobalLicenseCustomerInfo.
2885 2886 2887 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_account_display_name ⇒ String
Output only. Name of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountDisplayName
2831 2832 2833 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2831 def client_account_display_name @client_account_display_name end |
#client_account_id ⇒ Fixnum
Output only. ID of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountId
2836 2837 2838 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2836 def client_account_id @client_account_id end |
#client_account_type ⇒ String
Output only. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property clientAccountType
2842 2843 2844 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2842 def client_account_type @client_account_type end |
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only. Pricing history of this user list license.
Corresponds to the JSON property historicalPricings
2847 2848 2849 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2847 def historical_pricings @historical_pricings end |
#license_type ⇒ String
Output only. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property licenseType
2853 2854 2855 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2853 def license_type @license_type end |
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
Corresponds to the JSON property metrics
2858 2859 2860 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2858 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the user list global license customer.
Corresponds to the JSON property name
2863 2864 2865 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2863 def name @name end |
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
Corresponds to the JSON property pricing
2868 2869 2870 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2868 def pricing @pricing end |
#status ⇒ String
Output only. Status of UserListDirectLicense - ENABLED or DISABLED.
Corresponds to the JSON property status
2873 2874 2875 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2873 def status @status end |
#user_list_display_name ⇒ String
Output only. Name of the user list being licensed.
Corresponds to the JSON property userListDisplayName
2878 2879 2880 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2878 def user_list_display_name @user_list_display_name end |
#user_list_id ⇒ Fixnum
Output only. ID of the user list being licensed.
Corresponds to the JSON property userListId
2883 2884 2885 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2883 def user_list_id @user_list_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2890 def update!(**args) @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name) @client_account_id = args[:client_account_id] if args.key?(:client_account_id) @client_account_type = args[:client_account_type] if args.key?(:client_account_type) @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings) @license_type = args[:license_type] if args.key?(:license_type) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @pricing = args[:pricing] if args.key?(:pricing) @status = args[:status] if args.key?(:status) @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) end |