Class: Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListGlobalLicenseCustomerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Information about a customer of a user list global license. This will automatically be created by the system when a customer purchases a global license.
Instance Attribute Summary collapse
-
#client_account_display_name ⇒ String
Output only.
-
#client_account_id ⇒ Fixnum
Output only.
-
#client_account_type ⇒ String
Output only.
-
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only.
-
#license_type ⇒ String
Output only.
-
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
-
#name ⇒ String
Identifier.
-
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
-
#status ⇒ String
Output only.
-
#user_list_display_name ⇒ String
Output only.
-
#user_list_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo
constructor
A new instance of UserListGlobalLicenseCustomerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListGlobalLicenseCustomerInfo
Returns a new instance of UserListGlobalLicenseCustomerInfo.
2654 2655 2656 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_account_display_name ⇒ String
Output only. Name of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountDisplayName
2600 2601 2602 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2600 def client_account_display_name @client_account_display_name end |
#client_account_id ⇒ Fixnum
Output only. ID of client customer which the user list is being licensed to.
Corresponds to the JSON property clientAccountId
2605 2606 2607 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2605 def client_account_id @client_account_id end |
#client_account_type ⇒ String
Output only. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property clientAccountType
2611 2612 2613 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2611 def client_account_type @client_account_type end |
#historical_pricings ⇒ Array<Google::Apis::DatamanagerV1::UserListLicensePricing>
Output only. Pricing history of this user list license.
Corresponds to the JSON property historicalPricings
2616 2617 2618 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2616 def historical_pricings @historical_pricings end |
#license_type ⇒ String
Output only. Product type of client customer which the user list is being
licensed to.
Corresponds to the JSON property licenseType
2622 2623 2624 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2622 def license_type @license_type end |
#metrics ⇒ Google::Apis::DatamanagerV1::UserListLicenseMetrics
Metrics related to a user list license.
Corresponds to the JSON property metrics
2627 2628 2629 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2627 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the user list global license customer.
Corresponds to the JSON property name
2632 2633 2634 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2632 def name @name end |
#pricing ⇒ Google::Apis::DatamanagerV1::UserListLicensePricing
A user list license pricing.
Corresponds to the JSON property pricing
2637 2638 2639 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2637 def pricing @pricing end |
#status ⇒ String
Output only. Status of UserListDirectLicense - ENABLED or DISABLED.
Corresponds to the JSON property status
2642 2643 2644 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2642 def status @status end |
#user_list_display_name ⇒ String
Output only. Name of the user list being licensed.
Corresponds to the JSON property userListDisplayName
2647 2648 2649 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2647 def user_list_display_name @user_list_display_name end |
#user_list_id ⇒ Fixnum
Output only. ID of the user list being licensed.
Corresponds to the JSON property userListId
2652 2653 2654 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2652 def user_list_id @user_list_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2659 def update!(**args) @client_account_display_name = args[:client_account_display_name] if args.key?(:client_account_display_name) @client_account_id = args[:client_account_id] if args.key?(:client_account_id) @client_account_type = args[:client_account_type] if args.key?(:client_account_type) @historical_pricings = args[:historical_pricings] if args.key?(:historical_pricings) @license_type = args[:license_type] if args.key?(:license_type) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @pricing = args[:pricing] if args.key?(:pricing) @status = args[:status] if args.key?(:status) @user_list_display_name = args[:user_list_display_name] if args.key?(:user_list_display_name) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) end |