Class: Google::Apis::DatamanagerV1::UserListLicenseMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListLicenseMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Metrics related to a user list license.
Instance Attribute Summary collapse
-
#click_count ⇒ Fixnum
Output only.
-
#end_date ⇒ Fixnum
Output only.
-
#impression_count ⇒ Fixnum
Output only.
-
#revenue_usd_micros ⇒ Fixnum
Output only.
-
#start_date ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListLicenseMetrics
constructor
A new instance of UserListLicenseMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListLicenseMetrics
Returns a new instance of UserListLicenseMetrics.
3543 3544 3545 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#click_count ⇒ Fixnum
Output only. The number of clicks for the user list license.
Corresponds to the JSON property clickCount
3513 3514 3515 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3513 def click_count @click_count end |
#end_date ⇒ Fixnum
Output only. The end date (inclusive) of the metrics in the format YYYYMMDD.
For example, 20260102 represents January 2, 2026. If start_date is used in
the filter, end_date is also required. If neither start_date nor end_date
are included in the filter, the UserListLicenseMetrics fields will not be
populated in the response.
Corresponds to the JSON property endDate
3522 3523 3524 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3522 def end_date @end_date end |
#impression_count ⇒ Fixnum
Output only. The number of impressions for the user list license.
Corresponds to the JSON property impressionCount
3527 3528 3529 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3527 def impression_count @impression_count end |
#revenue_usd_micros ⇒ Fixnum
Output only. The revenue for the user list license in USD micros.
Corresponds to the JSON property revenueUsdMicros
3532 3533 3534 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3532 def revenue_usd_micros @revenue_usd_micros end |
#start_date ⇒ Fixnum
Output only. The start date (inclusive) of the metrics in the format YYYYMMDD.
For example, 20260102 represents January 2, 2026. If end_date is used in the
filter, start_date is also required. If neither start_date nor end_date
are included in the filter, the UserListLicenseMetrics fields will not be
populated in the response.
Corresponds to the JSON property startDate
3541 3542 3543 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3541 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3548 3549 3550 3551 3552 3553 3554 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3548 def update!(**args) @click_count = args[:click_count] if args.key?(:click_count) @end_date = args[:end_date] if args.key?(:end_date) @impression_count = args[:impression_count] if args.key?(:impression_count) @revenue_usd_micros = args[:revenue_usd_micros] if args.key?(:revenue_usd_micros) @start_date = args[:start_date] if args.key?(:start_date) end |