Class: Google::Apis::DatamanagerV1::UserListLicensePricing
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::UserListLicensePricing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
A user list license pricing.
Instance Attribute Summary collapse
-
#buyer_approval_state ⇒ String
Output only.
-
#cost_micros ⇒ Fixnum
Optional.
-
#cost_type ⇒ String
Immutable.
-
#currency_code ⇒ String
Optional.
-
#end_time ⇒ String
Optional.
-
#max_cost_micros ⇒ Fixnum
Optional.
-
#pricing_active ⇒ Boolean
(also: #pricing_active?)
Output only.
-
#pricing_id ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserListLicensePricing
constructor
A new instance of UserListLicensePricing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserListLicensePricing
Returns a new instance of UserListLicensePricing.
3961 3962 3963 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buyer_approval_state ⇒ String
Output only. The buyer approval state of this pricing. This field is read-only.
Corresponds to the JSON property buyerApprovalState
3908 3909 3910 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3908 def buyer_approval_state @buyer_approval_state end |
#cost_micros ⇒ Fixnum
Optional. The cost associated with the model, in micro units (10^-6), in the
currency specified by the currency_code field. For example, 2000000 means $2
if currency_code is USD.
Corresponds to the JSON property costMicros
3915 3916 3917 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3915 def cost_micros @cost_micros end |
#cost_type ⇒ String
Immutable. The cost type of this pricing. Can be set only in the create
operation. Can't be updated for an existing license.
Corresponds to the JSON property costType
3921 3922 3923 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3921 def cost_type @cost_type end |
#currency_code ⇒ String
Optional. The currency in which cost and max_cost is specified. Must be a
three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
3927 3928 3929 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3927 def currency_code @currency_code end |
#end_time ⇒ String
Optional. End time of the pricing.
Corresponds to the JSON property endTime
3932 3933 3934 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3932 def end_time @end_time end |
#max_cost_micros ⇒ Fixnum
Optional. The maximum CPM a commerce audience can be charged when the
MEDIA_SHARE cost type is used. The value is in micro units (10^-6) and in the
currency specified by the currency_code field. For example, 2000000 means $2
if currency_code is USD. This is only relevant when cost_type is
MEDIA_SHARE. When cost_type is not MEDIA_SHARE, and this field is set, a
MAX_COST_NOT_ALLOWED error will be returned. If not set or set to0, there is
no cap.
Corresponds to the JSON property maxCostMicros
3943 3944 3945 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3943 def max_cost_micros @max_cost_micros end |
#pricing_active ⇒ Boolean Also known as: pricing_active?
Output only. Whether this pricing is active.
Corresponds to the JSON property pricingActive
3948 3949 3950 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3948 def pricing_active @pricing_active end |
#pricing_id ⇒ Fixnum
Output only. The ID of this pricing.
Corresponds to the JSON property pricingId
3954 3955 3956 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3954 def pricing_id @pricing_id end |
#start_time ⇒ String
Output only. Start time of the pricing.
Corresponds to the JSON property startTime
3959 3960 3961 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3959 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3966 3967 3968 3969 3970 3971 3972 3973 3974 3975 3976 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3966 def update!(**args) @buyer_approval_state = args[:buyer_approval_state] if args.key?(:buyer_approval_state) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @cost_type = args[:cost_type] if args.key?(:cost_type) @currency_code = args[:currency_code] if args.key?(:currency_code) @end_time = args[:end_time] if args.key?(:end_time) @max_cost_micros = args[:max_cost_micros] if args.key?(:max_cost_micros) @pricing_active = args[:pricing_active] if args.key?(:pricing_active) @pricing_id = args[:pricing_id] if args.key?(:pricing_id) @start_time = args[:start_time] if args.key?(:start_time) end |