Class: Google::Apis::DatamanagerV1::UserListLicensePricing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A user list license pricing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserListLicensePricing

Returns a new instance of UserListLicensePricing.



2785
2786
2787
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buyer_approval_stateString

Output only. The buyer approval state of this pricing. This field is read-only. Corresponds to the JSON property buyerApprovalState

Returns:

  • (String)


2732
2733
2734
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2732

def buyer_approval_state
  @buyer_approval_state
end

#cost_microsFixnum

Optional. The cost associated with the model, in micro units (10^-6), in the currency specified by the currency_code field. For example, 2000000 means $2 if currency_code is USD. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


2739
2740
2741
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2739

def cost_micros
  @cost_micros
end

#cost_typeString

Immutable. The cost type of this pricing. Can be set only in the create operation. Can't be updated for an existing license. Corresponds to the JSON property costType

Returns:

  • (String)


2745
2746
2747
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2745

def cost_type
  @cost_type
end

#currency_codeString

Optional. The currency in which cost and max_cost is specified. Must be a three-letter currency code defined in ISO 4217. Corresponds to the JSON property currencyCode

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2751

def currency_code
  @currency_code
end

#end_timeString

Optional. End time of the pricing. Corresponds to the JSON property endTime

Returns:

  • (String)


2756
2757
2758
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2756

def end_time
  @end_time
end

#max_cost_microsFixnum

Optional. The maximum CPM a commerce audience can be charged when the MEDIA_SHARE cost type is used. The value is in micro units (10^-6) and in the currency specified by the currency_code field. For example, 2000000 means $2 if currency_code is USD. This is only relevant when cost_type is MEDIA_SHARE. When cost_type is not MEDIA_SHARE, and this field is set, a MAX_COST_NOT_ALLOWED error will be returned. If not set or set to0, there is no cap. Corresponds to the JSON property maxCostMicros

Returns:

  • (Fixnum)


2767
2768
2769
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2767

def max_cost_micros
  @max_cost_micros
end

#pricing_activeBoolean Also known as: pricing_active?

Output only. Whether this pricing is active. Corresponds to the JSON property pricingActive

Returns:

  • (Boolean)


2772
2773
2774
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2772

def pricing_active
  @pricing_active
end

#pricing_idFixnum

Output only. The ID of this pricing. Corresponds to the JSON property pricingId

Returns:

  • (Fixnum)


2778
2779
2780
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2778

def pricing_id
  @pricing_id
end

#start_timeString

Output only. Start time of the pricing. Corresponds to the JSON property startTime

Returns:

  • (String)


2783
2784
2785
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2783

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2790

def update!(**args)
  @buyer_approval_state = args[:buyer_approval_state] if args.key?(:buyer_approval_state)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @cost_type = args[:cost_type] if args.key?(:cost_type)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @end_time = args[:end_time] if args.key?(:end_time)
  @max_cost_micros = args[:max_cost_micros] if args.key?(:max_cost_micros)
  @pricing_active = args[:pricing_active] if args.key?(:pricing_active)
  @pricing_id = args[:pricing_id] if args.key?(:pricing_id)
  @start_time = args[:start_time] if args.key?(:start_time)
end