Class: Google::Apis::DatamanagerV1::UserProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A bucket of any additional user properties for the user associated with this event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserProperty

Returns a new instance of UserProperty.



3085
3086
3087
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#property_nameString

Required. The name of the user property to use. Corresponds to the JSON property propertyName

Returns:

  • (String)


3078
3079
3080
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3078

def property_name
  @property_name
end

#valueString

Required. The string representation of the value of the user property to use. Corresponds to the JSON property value

Returns:

  • (String)


3083
3084
3085
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3083

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3090
3091
3092
3093
# File 'lib/google/apis/datamanager_v1/classes.rb', line 3090

def update!(**args)
  @property_name = args[:property_name] if args.key?(:property_name)
  @value = args[:value] if args.key?(:value)
end