Class: Google::Apis::DatamanagerV1::UserProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb

Overview

A bucket of any additional user properties for the user associated with this event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserProperty

Returns a new instance of UserProperty.



2854
2855
2856
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#property_nameString

Required. The name of the user property to use. Corresponds to the JSON property propertyName

Returns:

  • (String)


2847
2848
2849
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2847

def property_name
  @property_name
end

#valueString

Required. The string representation of the value of the user property to use. Corresponds to the JSON property value

Returns:

  • (String)


2852
2853
2854
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2852

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2859
2860
2861
2862
# File 'lib/google/apis/datamanager_v1/classes.rb', line 2859

def update!(**args)
  @property_name = args[:property_name] if args.key?(:property_name)
  @value = args[:value] if args.key?(:value)
end