Class: Google::Apis::DatamanagerV1::ViewabilityInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamanagerV1::ViewabilityInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamanager_v1/classes.rb,
lib/google/apis/datamanager_v1/representations.rb,
lib/google/apis/datamanager_v1/representations.rb
Overview
Details of the viewability of the ad served.
Instance Attribute Summary collapse
-
#media_duration ⇒ String
Optional.
-
#media_quartile ⇒ String
Optional.
-
#media_skippable ⇒ Boolean
(also: #media_skippable?)
Optional.
-
#media_volume_percent ⇒ Fixnum
Optional.
-
#playback_duration ⇒ String
Optional.
-
#view_type ⇒ String
Required.
-
#viewable_duration ⇒ String
Optional.
-
#viewable_percent ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ViewabilityInfo
constructor
A new instance of ViewabilityInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ViewabilityInfo
Returns a new instance of ViewabilityInfo.
4087 4088 4089 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#media_duration ⇒ String
Optional. The duration of the ad media.
Corresponds to the JSON property mediaDuration
4048 4049 4050 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4048 def media_duration @media_duration end |
#media_quartile ⇒ String
Optional. The amount of the media that was played as discrete quartiles.
Corresponds to the JSON property mediaQuartile
4053 4054 4055 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4053 def media_quartile @media_quartile end |
#media_skippable ⇒ Boolean Also known as: media_skippable?
Optional. Whether the ad media was skippable or not.
Corresponds to the JSON property mediaSkippable
4058 4059 4060 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4058 def media_skippable @media_skippable end |
#media_volume_percent ⇒ Fixnum
Optional. The numerical percent (0-100) of the volume of the media playback.
Corresponds to the JSON property mediaVolumePercent
4064 4065 4066 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4064 def media_volume_percent @media_volume_percent end |
#playback_duration ⇒ String
Optional. The duration of playback of the ad media, regardless of whether it
was viewable or not.
Corresponds to the JSON property playbackDuration
4070 4071 4072 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4070 def playback_duration @playback_duration end |
#view_type ⇒ String
Required. The type of the event.
Corresponds to the JSON property viewType
4075 4076 4077 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4075 def view_type @view_type end |
#viewable_duration ⇒ String
Optional. The amount of time the ad was viewable for.
Corresponds to the JSON property viewableDuration
4080 4081 4082 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4080 def viewable_duration @viewable_duration end |
#viewable_percent ⇒ Fixnum
Optional. The numerical percent (0-100) of the pixels that were viewable.
Corresponds to the JSON property viewablePercent
4085 4086 4087 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4085 def viewable_percent @viewable_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/google/apis/datamanager_v1/classes.rb', line 4092 def update!(**args) @media_duration = args[:media_duration] if args.key?(:media_duration) @media_quartile = args[:media_quartile] if args.key?(:media_quartile) @media_skippable = args[:media_skippable] if args.key?(:media_skippable) @media_volume_percent = args[:media_volume_percent] if args.key?(:media_volume_percent) @playback_duration = args[:playback_duration] if args.key?(:playback_duration) @view_type = args[:view_type] if args.key?(:view_type) @viewable_duration = args[:viewable_duration] if args.key?(:viewable_duration) @viewable_percent = args[:viewable_percent] if args.key?(:viewable_percent) end |